@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: addhtmlblob.php 6024 2009-09-21 19:41:17Z ronnyk $
+#$Id: addhtmlblob.php 6213 2010-04-10 13:22:40Z ronnyk $
 
 $CMS_ADMIN_PAGE=1;
 
@@ -30,10 +30,10 @@ check_login();
 $error = "";
 
 $htmlblob = "";
-if (isset($_POST['htmlblob'])) $htmlblob = $_POST['htmlblob'];
+if (isset($_POST['htmlblob'])) $htmlblob = trim($_POST['htmlblob']);
 
 $content = "";
-if (isset($_POST['content'])) $content = $_POST['content'];
+if (isset($_POST['content'])) $content = trim(trim($_POST['content']));
 
 if (isset($_POST["cancel"])) {
 	redirect("listhtmlblobs.php".$urlext);
@@ -68,13 +68,18 @@ if ($access) {
 
 		$validinfo = true;
 		if ($htmlblob == ""){
-			$error .= "<li>".lang('nofieldgiven', array('addhtmlblob'))."</li>";
+			$error .= "<li>".lang('nofieldgiven', array('name'))."</li>";
 			$validinfo = false;
 		}
 		else if ($gcbops->CheckExistingHtmlBlobName($htmlblob)){
 			$error .= "<li>".lang('blobexists')."</li>";
 			$validinfo = false;
 		}
+		else if($content == ""){
+		  $error .= '<li>'.lang('nofieldgiven',array('content')).'</li>';
+		  $validinfo = false;
+		}
+
 
 		if ($validinfo) {
 			global $gCms;
