@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: editcontent.php 5793 2009-06-26 17:23:25Z calguy1000 $
+#$Id: editcontent.php 6360 2010-06-05 22:50:28Z calguy1000 $
 
 $CMS_ADMIN_PAGE=1;
 
@@ -116,6 +116,8 @@ if (!$access)
 
 if ($access)
 {
+  $classname="";
+  if (is_object($contentobj)) $classname=get_class($contentobj);
 	if ($submit || $apply)
 	{
 	  #Fill contentobj with parameters
@@ -162,7 +164,7 @@ if ($access)
 			exit;
 		}
 	}
-	else if ($content_id != -1 && strtolower(get_class($contentobj)) != strtolower($content_type))
+	else if ($content_id != -1 && strtolower($classname) != strtolower($content_type))
 	{
 	  // handle changing content type
 		global $gCms;
@@ -303,7 +305,20 @@ else
 #$contentarray = $contentobj->EditAsArray(true, 0, $adminaccess);
 #$contentarray2 = $contentobj->EditAsArray(true, 1, $adminaccess);
 
-$tabnames = $contentobj->TabNames();
+	$tabnames = $contentobj->TabNames();
+	$numberoftabs = count($tabnames);
+	$tab_contents_array = array();
+	for ($currenttab = 0; $currenttab < $numberoftabs; $currenttab++)
+	  {
+	    $contentarray = $contentobj->EditAsArray(false, $currenttab, $adminaccess);
+	    $tab_contents_array[$currenttab] = $contentarray;
+
+	    if( $tmp = $contentobj->GetError() )
+	      {
+		echo $themeObject->ShowErrors($tmp);
+		break;
+	      }
+	  }
 
 ?>
 
@@ -370,7 +385,6 @@ $submit_buttons .= ' <input type="submit" onclick="return window.Edit_Content_Ap
 $submit_buttons .= '</p></div>';
 
 //echo $submit_buttons;
-		$numberoftabs = count($tabnames);
 		$showtabs = 1;
 		if ($numberoftabs == 0)
 		{
@@ -395,16 +409,19 @@ $submit_buttons .= '</p></div>';
 				<?php
 			}
 
-			$contentarray = $contentobj->EditAsArray(false, $currenttab, $adminaccess);
-			for($i=0;$i<count($contentarray);$i++)
-			{
+			if( isset($tab_contents_array[$currenttab]) )
+			  {
+			    $contentarray =& $tab_contents_array[$currenttab];
+			    for($i=0;$i<count($contentarray);$i++)
+			      {
 				?>
 				<div class="pageoverflow">
 					<div class="pagetext"><?php echo $contentarray[$i][0]; ?></div>
 					<div class="pageinput"><?php echo $contentarray[$i][1]; ?></div>
 				</div>
 				<?php
-			}
+			      }
+			  }
             
 			?>
 			<div style="clear: both;"></div>
