@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: edithtmlblob.php 6024 2009-09-21 19:41:17Z ronnyk $
+#$Id: edithtmlblob.php 6416 2010-06-30 17:35:44Z sjg $
 
 $CMS_ADMIN_PAGE=1;
 
@@ -29,10 +29,10 @@ check_login();
 $error = "";
 
 $htmlblob = "";
-if (isset($_POST['htmlblob'])) $htmlblob = $_POST['htmlblob'];
+if (isset($_POST['htmlblob'])) $htmlblob = trim($_POST['htmlblob']);
 
 $oldhtmlblob = "";
-if (isset($_POST['oldhtmlblob'])) $oldhtmlblob = $_POST['oldhtmlblob'];
+if (isset($_POST['oldhtmlblob'])) $oldhtmlblob = trim($_POST['oldhtmlblob']);
 
 $content = "";
 if (isset($_POST['content'])) $content = $_POST['content'];
@@ -60,6 +60,16 @@ $adminaccess = check_permission($userid, 'Modify Global Content Blocks');
 $isowner = $gcbops->CheckOwnership($htmlblob_id,$userid);
 $access = $adminaccess || $isowner || $gcbops->CheckAuthorship($htmlblob_id, $userid);
 
+$the_blob = '';
+if( $htmlblob_id > 0 )
+  {
+    $the_blob = $gcbops->LoadHtmlBlobById($htmlblob_id);
+  }
+else
+  {
+    $the_blob = new GlobalContent();
+  }
+
 /*
 $htmlarea_flag = false;
 $use_javasyntax = false;
@@ -87,7 +97,7 @@ if ($access)
 		$validinfo = true;
 		if ($htmlblob == "")
 		{
-			$error .= "<li>".lang('nofieldgiven', array(lang('edithtmlblob')))."</li>";
+			$error .= "<li>".lang('nofieldgiven', array(lang('name')))."</li>";
 			$validinfo = false;
 		}
 		else if ($htmlblob != $oldhtmlblob && $gcbops->CheckExistingHtmlBlobName($htmlblob, $htmlblob_id))
@@ -95,23 +105,24 @@ if ($access)
 			$error .= "<li>".lang('blobexists')."</li>";
 			$validinfo = false;
 		}
+		else if($content == ""){
+		  $error .= '<li>'.lang('nofieldgiven',array('content')).'</li>';
+		  $validinfo = false;
+		}
 
 		if ($validinfo)
 		{
-			$blobobj =& new GlobalContent();
-			$blobobj->id = $htmlblob_id;
-			$blobobj->name = $htmlblob;
-			$blobobj->content = $content;
-			$blobobj->owner = $owner_id;
+			$the_blob->id = $htmlblob_id;
+			$the_blob->name = $htmlblob;
+			$the_blob->content = $content;
+			$the_blob->owner = $owner_id;
 
-			$blobobj->ClearAuthors();
 			if (isset($_POST["additional_editors"])) {
-					foreach ($_POST["additional_editors"] as $addt_user_id) {
-						$blobobj->AddAuthor($addt_user_id);
-					}
+			  $the_blob->ClearAuthors();
+			  foreach ($_POST["additional_editors"] as $addt_user_id) {
+			    $the_blob->AddAuthor($addt_user_id);
+			  }
 			}
-			// add this user as an additional editor? why?
-			$blobobj->AddAuthor($userid);
 
 			#Perform the edithtmlblob_pre callback
 			foreach($gCms->modules as $key=>$value)
@@ -123,13 +134,13 @@ if ($access)
 				}
 			}
 			
-			Events::SendEvent('Core', 'EditGlobalContentPre', array('global_content' => &$blobobj));
+			Events::SendEvent('Core', 'EditGlobalContentPre', array('global_content' => &$the_blob));
 
-			$result = $blobobj->save();
+			$result = $the_blob->save();
 
 			if ($result)
 			{
-				audit($blobobj->id, $blobobj->name, 'Edited Global Content Block');
+				audit($the_blob->id, $the_blob->name, 'Edited Global Content Block');
 
 				#Clear cache
 				$smarty = new Smarty_CMS($config);
@@ -142,11 +153,11 @@ if ($access)
 					if ($gCms->modules[$key]['installed'] == true &&
 						$gCms->modules[$key]['active'] == true)
 					{
-						$gCms->modules[$key]['object']->EditHtmlBlobPost($blobobj);
+						$gCms->modules[$key]['object']->EditHtmlBlobPost($the_blob);
 					}
 				}
 				
-				Events::SendEvent('Core', 'EditGlobalContentPost', array('global_content' => &$blobobj));
+				Events::SendEvent('Core', 'EditGlobalContentPost', array('global_content' => &$the_blob));
 
 				if (!isset($_POST['apply'])) {
 					redirect('listhtmlblobs.php'.$urlext);
@@ -180,11 +191,10 @@ if ($access)
 	}
 	else if ($htmlblob_id != -1)
 	{
-		$onehtmlblob = $gcbops->LoadHtmlBlobByID($htmlblob_id);
-		$htmlblob = $onehtmlblob->name;
-		$oldhtmlblob = $onehtmlblob->name;
-		$owner_id = $onehtmlblob->owner;
-		$content = $onehtmlblob->content;
+		$htmlblob = $the_blob->name;
+		$oldhtmlblob = $the_blob->name;
+		$owner_id = $the_blob->owner;
+		$content = $the_blob->content;
 	}
 }
 
