@@ -16,13 +16,12 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: imagefiles.php 6037 2009-10-03 17:16:59Z calguy1000 $
+#$Id: imagefiles.php 6473 2010-07-04 03:21:29Z wishy $
 
 $CMS_ADMIN_PAGE=1;
 
 // in filetypes.inc.php filetypes are defined 
 require_once(dirname(dirname(__FILE__))."/lib/filemanager/filetypes.inc.php");
-require_once(dirname(dirname(__FILE__))."/lib/file.functions.php");
 require_once("../include.php");
 
 $urlext = get_secure_param();
@@ -183,6 +182,7 @@ else if (isset($_GET['action']) && $_GET['action'] == "deletedir")
 }
 
 include_once("header.php");
+$current_language = cms_admin_current_language();
 ?>
 
 
