@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: listcontent.php 5996 2009-09-16 14:04:49Z calguy1000 $
+#$Id: listcontent.php 6461 2010-07-03 03:12:46Z calguy1000 $
 
 $CMS_ADMIN_PAGE=1;
 
@@ -62,7 +62,7 @@ function content_list_ajax()
 
 function check_modify_all($userid)
 {
-  return check_permission($userid, 'Modify Any Page');
+  return check_permission($userid, 'Modify Any Page') || check_permission($userid,'Manage All Content');
 }
 
 function setdefault($contentid)
@@ -1088,6 +1088,13 @@ function display_content_list($themeObject = null)
 	  $headoflist .= ' <a class="pageoptions" href="addcontent.php'.$urlext.'">'.lang("addcontent").'</a>';
 	}
 
+	$headoflist .= '<a style="margin-left: 10px;" href="'.$thisurl.'&amp;expandall=1" onclick="xajax_content_expandall(); return false;">';
+	$headoflist .= $themeObject->DisplayImage('icons/system/expandall.gif', lang('expandall'),'','','systemicon').'</a>';
+	$headoflist .= ' <a class="pageoptions" href="'.$thisurl.'&amp;expandall=1" onclick="xajax_content_expandall(); return false;">'.lang("expandall").'</a>&nbsp;&nbsp;&nbsp;';
+	$headoflist .= ' <a href="'.$thisurl.'&amp;collapseall=1" onclick="xajax_content_collapseall(); return false;">';
+	$headoflist .= $themeObject->DisplayImage('icons/system/contractall.gif', lang('contractall'),'','','systemicon').'</a>';
+	$headoflist .= ' <a class="pageoptions" href="'.$thisurl.'&amp;collapseall=1" onclick="xajax_content_collapseall(); return false;">'.lang("contractall").'</a>';
+
 	if (check_permission($userid, 'Manage All Content'))
 	{
 	  $headoflist .= '&nbsp;&nbsp;&nbsp;<a href="'.$thisurl.'&amp;error=jsdisabled" class="pageoptions" onclick="xajax_reorder_display_list();return false;">';
@@ -1166,21 +1173,21 @@ function display_content_list($themeObject = null)
 	$opts = array();
 	if( check_permission($userid, 'Remove Pages') || check_permission($userid, 'Manage All Content') )
 	  {
-	    $opts['delete'] = lang('delete');
+	    bulkcontentoperations::register_function(lang('delete'),'delete');
 	  }
 	if (check_permission($userid, 'Manage All Content')) 
 	  {
-	    $opts['active'] = lang('active');
-	    $opts['inactive'] = lang('inactive');
-	    $opts['setcachable'] = lang('cachable');
-	    $opts['setnoncachable'] = lang('noncachable');
-	    $opts['showinmenu'] = lang('showinmenu');
-	    $opts['hidefrommenu'] = lang('hidefrommenu');
-	  }
-	if (check_permission($userid, 'Modify Any Page') || check_permission($userid, 'Manage All Content'))
-	  {
-	    $opts['settemplate'] = lang('settemplate');
+	    bulkcontentoperations::register_function(lang('active'),'active');
+	    bulkcontentoperations::register_function(lang('inactive'),'inactive');
+	    bulkcontentoperations::register_function(lang('cachable'),'setcachable');
+	    bulkcontentoperations::register_function(lang('noncachable'),'setnoncachable');
+	    bulkcontentoperations::register_function(lang('showinmenu'),'showinmenu');
+	    bulkcontentoperations::register_function(lang('hidefrommenu'),'hidefrommenu');
+	    bulkcontentoperations::register_function(lang('secure'),'secure');
+	    bulkcontentoperations::register_function(lang('insecure'),'insecure');
+	    bulkcontentoperations::register_function(lang('settemplate'),'settemplate');
 	  }
+	$opts = bulkcontentoperations::get_operation_list();
 	if( !empty($opts) )
 	  {
 	    echo '<div class="pageoptions">'."\n";
@@ -1192,7 +1199,7 @@ function display_content_list($themeObject = null)
 		echo '<option value="'.$key.'">'.$value.'</option>';
 	      }
 	    echo '</select>'."\n";
-            echo '<input type="submit" value="'.lang('submit').'"/></div></div>'."\n";
+            echo '<input type="submit" accesskey="s" value="'.lang('submit').'"/></div></div>'."\n";
 	  }
 	/*    } */
 ?>
