@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: listmodules.php 5338 2008-12-12 17:29:51Z nuno $
+#$Id: listmodules.php 6431 2010-07-02 01:10:52Z calguy1000 $
 
 $CMS_ADMIN_PAGE=1;
 $LOAD_ALL_MODULES=1;
@@ -309,12 +309,14 @@ else if ($action == "showmodulehelp")
 		{
 			$moduleName = substr($moduleName, 1);
 		}
+
 		// Include English translation of titles. (Can't find better way to get them)
-		$dirname = dirname(__FILE__);
-		include($dirname.'/lang/en_US/admin.inc.php');
-		$section = $lang['admin'][$gCms->modules[$module]['object']->GetAdminSection()];
+// 		$dirname = dirname(__FILE__);
+// 		include($dirname.'/lang/en_US/admin.inc.php');
+		$section = lang($gCms->modules[$module]['object']->GetAdminSection());
 		$wikiUrl .= '/'.$section.'/'.$moduleName;
-		if (FALSE == get_preference($userid, 'hide_help_links'))
+		//		if (FALSE == get_preference($userid, 'hide_help_links'))
+		  if (FALSE)
 		{
 			// Clean up URL
 			$wikiUrl = str_replace(' ', '_', $wikiUrl);
