@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: login.php 5568 2009-04-12 17:48:59Z calguy1000 $
+#$Id: login.php 6467 2010-07-03 19:56:32Z calguy1000 $
 
 $CMS_ADMIN_PAGE=1;
 
@@ -35,7 +35,7 @@ if ((isset($_REQUEST['forgotpwform']) || isset($_REQUEST['forgotpwchangeform']))
 {
 	redirect('login.php');
 }
-else if (isset($_REQUEST['forgotpwform']) && isset($_REQUEST['loginsubmit']))
+else if (isset($_REQUEST['forgotpwform']) && isset($_REQUEST['forgottenusername']))
 {
 	global $gCms;
 	$userops =& $gCms->GetUserOperations();
@@ -107,7 +107,7 @@ else if (isset($_REQUEST['forgotpwchangeform']) && $_REQUEST['forgotpwchangeform
 
 if (isset($_SESSION['logout_user_now']))
 {
-	debug_buffer("Logging out.  Clearning cookies and session variables.");
+	debug_buffer("Logging out.  Cleaning cookies and session variables.");
 	unset($_SESSION['logout_user_now']);
 	unset($_SESSION['cms_admin_user_id']);
 	unset($_SESSION[CMS_USER_KEY]);
@@ -177,16 +177,6 @@ if (isset($_POST["username"]) && isset($_POST["password"])) {
 		}
 		audit($oneuser->id, $oneuser->username, 'User Login');
 
-		#Perform the login_post callback  TODO: Remove me
-		foreach($gCms->modules as $key=>$value)
-		{
-			if ($gCms->modules[$key]['installed'] == true &&
-				$gCms->modules[$key]['active'] == true)
-			{
-				$gCms->modules[$key]['object']->LoginPost($oneuser);
-			}
-		}
-		
 		#Now call the event
 		Events::SendEvent('Core', 'LoginPost', array('user' => &$oneuser));
 
@@ -287,16 +277,6 @@ if (isset($_POST["username"]) && isset($_POST["password"])) {
 
 		audit($username, $username, 'User Login Failed');
 
-		#Perform the login_post callback  TODO: Remove me
-		foreach($gCms->modules as $key=>$value)
-		{
-			if ($gCms->modules[$key]['installed'] == true &&
-				$gCms->modules[$key]['active'] == true)
-			{
-				$gCms->modules[$key]['object']->LoginPost($username);
-			}
-		}
-		
 		#Now call the event
 		Events::SendEvent('Core', 'LoginPost', $username);
 
