@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: siteprefs.php 5859 2009-08-09 12:21:00Z calguy1000 $
+#$Id: siteprefs.php 6478 2010-07-04 23:07:12Z calguy1000 $
 
 $CMS_ADMIN_PAGE=1;
 $CMS_TOP_MENU='admin';
@@ -59,29 +59,29 @@ $db =& $gCms->GetDb();
 $error = "";
 $message = "";
 
+$thumbnail_width = 96;
+$thumbnail_height = 96;
 $clear_vc_cache = 0;
 $disablesafemodewarning = 0;
 $allowparamcheckwarnings = 0;
 $enablenotifications = 1;
 $sitedownexcludes = '';
 $basic_attributes = '';
-$enablecustom404 = "0";
 $xmlmodulerepository = "";
 $urlcheckversion = "";
 $defaultdateformat = "";
-$custom404 = "<p>Page not found<//p>";
-$custom404template = "-1";
 $enablesitedownmessage = "0";
 $sitedownmessage = "<p>Site is currently down.  Check back later.</p>";
 $sitedownmessagetemplate = "-1";
 $metadata = '';
 $sitename = 'CMSMS Website';
-$css_max_age = 0;
 $frontendlang = '';
 $frontendwysiwyg = '';
 $nogcbwysiwyg = '0';
 $global_umask = '022';
 $logintheme = "default";
+$auto_clear_cache_age = 0;
+$pseudocron_granularity = 60;
 
 
 
@@ -91,13 +91,14 @@ if (isset($_POST["cancel"])) {
 }
 
 
+$pseudocron_granularity = get_site_preference('pseudocron_granularity',$pseudocron_granularity);
+$auto_clear_cache_age = get_site_preference('auto_clear_cache_age',$auto_clear_cache_age);
+$thumbnail_width = get_site_preference('thumbnail_width',$thumbnail_width);
+$thumbnail_height = get_site_preference('thumbnail_height',$thumbnail_height);
 $global_umask = get_site_preference('global_umask',$global_umask);
 $frontendlang = get_site_preference('frontendlang',$frontendlang);
 $frontendwysiwyg = get_site_preference('frontendwysiwyg',$frontendwysiwyg);
 $nogcbwysiwyg = get_site_preference('nogcbwysiwyg',$nogcbwysiwyg);
-$enablecustom404 = get_site_preference('enablecustom404',$enablecustom404);
-$custom404 = get_site_preference('custom404',$custom404);
-$custom404template = get_site_preference('custom404template',$custom404template);
 $enablesitedownmessage = get_site_preference('enablesitedownmessage',$enablesitedownmessage);
 $sitedownmessage = get_site_preference('sitedownmessage',$sitedownmessage);
 $xmlmodulerepository = get_site_preference('xmlmodulerepository',$xmlmodulerepository);
@@ -105,7 +106,6 @@ $urlcheckversion = get_site_preference('urlcheckversion',$urlcheckversion);
 $defaultdateformat = get_site_preference('defaultdateformat',$defaultdateformat);
 $logintheme = get_site_preference('logintheme',$logintheme);
 $metadata = get_site_preference('metadata',$metadata);
-$css_max_age = (int)get_site_preference('css_max_age',$css_max_age);
 $sitename = get_site_preference('sitename',$sitename);
 $clear_vc_cache = get_site_preference('clear_vc_cache',$clear_vc_cache);
 $disablesafemodewarning = get_site_preference('disablesafemodewarning',$disablesafemodewarning);
@@ -171,8 +171,9 @@ if (isset($_POST["testumask"]))
 else if (isset($_POST['clearcache']))
 {
 	global $gCms;
-	$contentops =& $gCms->GetContentOperations();
-	$contentops->ClearCache();
+	$gCms->clear_cached_files();
+// 	$contentops =& $gCms->GetContentOperations();
+// 	$contentops->ClearCache();
 	$message .= lang('cachecleared');
 }
 else if (isset($_POST["editsiteprefs"]))
@@ -197,6 +198,10 @@ else if (isset($_POST["editsiteprefs"]))
 	  set_site_preference('defaultdateformat', $defaultdateformat);
 	  if (isset($_POST['nogcbwysiwyg'])) $nogcbwysiwyg = $_POST['nogcbwysiwyg'];
 	  set_site_preference('nogcbwysiwyg', $nogcbwysiwyg);
+	  if( isset($_POST['thumbnail_width']) ) $thumbnail_width = (int)$_POST['thumbnail_width'];
+	  if( isset($_POST['thumbnail_height']) ) $thumbnail_height = (int)$_POST['thumbnail_height'];
+	  set_site_preference('thumbnail_width',$thumbnail_width);
+	  set_site_preference('thumbnail_height',$thumbnail_height);
 	  break;
 
 	case 'sitedown':
@@ -211,15 +216,6 @@ else if (isset($_POST["editsiteprefs"]))
 	  set_site_preference('sitedownexcludes',$sitedownexcludes);
 	  break;
 
-	case 'handle_404':
-	  if (isset($_POST["enablecustom404"])) $enablecustom404 = $_POST['enablecustom404'];
-	  if (isset($_POST["custom404"])) $custom404 = $_POST["custom404"];
-	  if (isset($_POST["custom404template"])) $custom404template = $_POST["custom404template"];
-	  set_site_preference('enablecustom404', $enablecustom404);
-	  set_site_preference('custom404', $custom404);
-	  set_site_preference('custom404template', $custom404template);
-	  break;
-
 	case 'setup':
 	  if (isset($_POST["clear_vc_cache"])) $clear_vc_cache = $_POST['clear_vc_cache'];
 	  if (isset($_POST["disablesafemodewarning"])) $disablesafemodewarning = $_POST['disablesafemodewarning'];
@@ -235,7 +231,6 @@ else if (isset($_POST["editsiteprefs"]))
 	    }
 	  if (isset($_POST["xmlmodulerepository"])) $xmlmodulerepository = $_POST["xmlmodulerepository"];
 	  if (isset($_POST["urlcheckversion"])) $urlcheckversion = $_POST["urlcheckversion"];
-	  if (isset($_POST['css_max_age'])) $css_max_age = (int)$_POST['css_max_age'];
 	  if (isset($_POST['global_umask'])) 
 	    {
 	      $global_umask = $_POST['global_umask'];
@@ -248,11 +243,20 @@ else if (isset($_POST["editsiteprefs"]))
 	      set_site_preference('lastcmsversioncheck',0);
 	    }
 	  set_site_preference('clear_vc_cache', $clear_vc_cache);
-	  set_site_preference('css_max_age',$css_max_age);
 	  set_site_preference('disablesafemodewarning',$disablesafemodewarning);
 	  set_site_preference('allowparamcheckwarnings',$allowparamcheckwarnings);
 	  set_site_preference('enablenotifications',$enablenotifications);
 	  set_site_preference('basic_attributes',$basic_attributes);
+	  if( isset($_POST['auto_clear_cache_age']) )
+	    {
+	      $auto_clear_cache_age = (int)$_POST['auto_clear_cache_age'];
+	      set_site_preference('auto_clear_cache_age',$auto_clear_cache_age);
+	    }
+	  if( isset($_POST['pseudocron_granularity']) )
+	    {
+	      $pseudocron_granularity = (int)$_POST['pseudocron_granularity'];
+	      set_site_preference('pseudocron_granularity',$pseudocron_granularity);
+	    }
 	  break;
 	}
 
@@ -271,7 +275,7 @@ else if (isset($_POST["editsiteprefs"]))
 $templates = array();
 $templates['-1'] = lang('none');
 
-$query = "SELECT * FROM ".cms_db_prefix()."templates ORDER BY template_name";
+$query = "SELECT * FROM ".cms_db_prefix()."templates where active = 1 ORDER BY template_name";
 $result = $db->Execute($query);
 
 while ($result && $row = $result->FetchRow())
@@ -299,8 +303,10 @@ if (FALSE == is_writable(TMP_CACHE_LOCATION) ||
 $tmp = array_keys($gCms->modules);
 $firstmod = $tmp[0];
 $smarty->assign_by_ref('mod',$gCms->modules[$firstmod]['object']);
-asort($nls["language"]);
+
 $tmp = array(''=>lang('nodefault'));
+global $nls;
+asort($nls["language"]);
 foreach( $nls['language'] as $key=>$value )
 {
   if( isset($nls['englishlang'][$key]) )
@@ -343,27 +349,21 @@ if ($dir=opendir(dirname(__FILE__)."/themes/"))
 
 $smarty->assign('active_general', 0);
 $smarty->assign('active_sitedown', 0);
-$smarty->assign('active_handle_404', 0);
 $smarty->assign('active_setup', 0);
 
 $smarty->assign('active_general',($active_tab == 'general')?1:0);
 $smarty->assign('active_sitedown',($active_tab == 'sitedown')?1:0);
-$smarty->assign('active_handle_404',($active_tab == 'handle_404')?1:0);
 $smarty->assign('active_setup',($active_tab == 'setup')?1:0);
 
 $smarty->assign('SECURE_PARAM_NAME',CMS_SECURE_PARAM_NAME);
 $smarty->assign('CMS_USER_KEY',$_SESSION[CMS_USER_KEY]);
 $smarty->assign('sitename',$sitename);
 $smarty->assign('global_umask',$global_umask);
-$smarty->assign('css_max_age',$css_max_age);
 $smarty->assign('testresults',$testresults);
 $smarty->assign('frontendlang',$frontendlang);
 $smarty->assign('frontendwysiwyg',$frontendwysiwyg);
 $smarty->assign('nogcbwysiwyg',$nogcbwysiwyg);
 $smarty->assign('metadata',$metadata);
-$smarty->assign('enablecustom404',$enablecustom404);
-$smarty->assign('textarea_custom404',create_textarea(true,$custom404,'custom404','pagesmalltextarea'));
-$smarty->assign('custom404template',$custom404template);
 $smarty->assign('enablesitedownmessage',$enablesitedownmessage);
 $smarty->assign('textarea_sitedownmessage',create_textarea(true,$sitedownmessage,'sitedownmessage','pagesmalltextarea'));
 $smarty->assign('urlcheckversion',$urlcheckversion);
@@ -374,10 +374,26 @@ $smarty->assign('defaultdateformat',$defaultdateformat);
 $smarty->assign('enablenotifications',$enablenotifications);
 $smarty->assign('sitedownexcludes',$sitedownexcludes);
 $smarty->assign('basic_attributes',explode(',',$basic_attributes));
+$smarty->assign('thumbnail_width',$thumbnail_width);
+$smarty->assign('thumbnail_height',$thumbnail_height);
+$smarty->assign('auto_clear_cache_age',$auto_clear_cache_age);
+$smarty->assign('pseudocron_granularity',$pseudocron_granularity);
 
+$tmp = array(15=>lang('cron_15m'),30=>lang('cron_30m'),
+	     60=>lang('cron_60m'),120=>lang('cron_120m'),
+	     180=>lang('cron_3h'),360=>lang('cron_6h'),
+	     12*60=>lang('cron_12h'),
+	     24*60=>lang('cron_24h'),
+	     -1=>lang('cron_request'));
+$smarty->assign('pseudocron_options',$tmp);	     
+$smarty->assign('lang_pseudocron_granularity',lang('pseudocron_granularity'));
+$smarty->assign('lang_info_pseudocron_granularity',lang('info_pseudocron_granularity'));
+$smarty->assign('lang_info_autoclearcache',lang('info_autoclearcache'));
+$smarty->assign('lang_autoclearcache',lang('autoclearcache'));
+$smarty->assign('lang_thumbnail_width',lang('thumbnail_width'));
+$smarty->assign('lang_thumbnail_height',lang('thumbnail_height'));
 $smarty->assign('lang_general',lang('general_settings'));
 $smarty->assign('lang_sitedown',lang('sitedown_settings'));
-$smarty->assign('lang_handle404',lang('handle_404'));
 $smarty->assign('lang_cancel',lang('cancel'));
 $smarty->assign('lang_submit',lang('submit'));
 $smarty->assign('lang_clearcache',lang('clearcache'));
@@ -386,15 +402,11 @@ $smarty->assign('lang_setup',lang('setup'));
 $smarty->assign('lang_sitename',lang('sitename'));
 $smarty->assign('lang_global_umask',lang('global_umask'));
 $smarty->assign('lang_test',lang('test'));
-$smarty->assign('lang_css_max_age',lang('css_max_age'));
-$smarty->assign('lang_help_css_max_age',lang('help_css_max_age'));
 $smarty->assign('lang_results',lang('results'));
 $smarty->assign('lang_frontendlang',lang('frontendlang'));
 $smarty->assign('lang_frontendwysiwygtouse',lang('frontendwysiwygtouse'));
 $smarty->assign('lang_nogcbwysiwyg',lang('nogcbwysiwyg'));
 $smarty->assign('lang_globalmetadata',lang('globalmetadata'));
-$smarty->assign('lang_enablecustom404',lang('enablecustom404'));
-$smarty->assign('lang_custom404',lang('custom404'));
 $smarty->assign('lang_template',lang('template'));
 $smarty->assign('lang_enablesitedown',lang('enablesitedown'));
 $smarty->assign('lang_sitedownmessage',lang('sitedownmessage'));
@@ -415,6 +427,7 @@ $smarty->assign('lang_info_basic_attributes',lang('info_basic_attributes'));
 $all_attributes = array();
 $all_attributes['template'] = lang('template');
 $all_attributes['active'] = lang('active');
+$all_attributes['secure'] = lang('secure_page');
 $all_attributes['showinmenu'] = lang('showinmenu');
 $all_attributes['cachable'] = lang('cachable');
 $all_attributes['target'] = lang('target');
