@@ -90,7 +90,7 @@ class NCleanGreyTheme extends AdminTheme
 		global $gCms;
 		$config =& $gCms->GetConfig();
 ?><head>
-<meta name="Generator" content="CMS Made Simple - Copyright (C) 2004-9 Ted Kulp. All rights reserved." />
+<meta name="Generator" content="CMS Made Simple - Copyright (C) 2004-10 Ted Kulp. All rights reserved." />
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
 <meta name="robots" content="noindex, nofollow" />
 <link rel="shortcut icon" href="themes/NCleanGrey/images/layout/ncleangrey-favicon.ico" />
@@ -148,7 +148,7 @@ filter: alpha(opacity=90);
 		echo "\n\t</ul>\n";
 		//ICON VIEW SITE
 		echo "\n\t<div id=\"nav-icons_all\"><ul id=\"nav-icons\">\n";
-		echo "\n\t<li class=\"viewsite-icon\"><a  rel=\"external\" title=\"".lang('viewsite')."\"  href=\"../index.php\">".lang('viewsite')."</a></li>\n";
+		echo "\n\t<li class=\"viewsite-icon\"><a  rel=\"external\" title=\"".lang('viewsite')."\"  href=\"".$this->_viewsite_url."\">".lang('viewsite')."</a></li>\n";
 		//ICON LAGOUT
 		echo "\n\t<li class=\"logout-icon\"><a  title=\"".lang('logout')."\"  href=\"logout.php\">".lang('logout')."</a></li>\n";
 		echo "\n\t</ul></div>\n";
@@ -381,7 +381,7 @@ filter: alpha(opacity=90);
 	  echo '<div class="itemoverflow">';
 	  echo '<p class="itemicon">';
 	  $iconSpec = $thisSection;
-	  if ($menuItem['url'] == '../index.php')
+	  if ($menuItem['url'] == $this->_viewsite_url)
 	    {
 	      $iconSpec = 'viewsite';
 	    }
@@ -475,7 +475,7 @@ filter: alpha(opacity=90);
 	    }
 	  if (! $moduleIcon)
 	    {
-	      if ($thisItem['url'] == '../index.php')
+	      if ($thisItem['url'] == $this->_viewsite_url)
 		{
 		  $iconSpec = 'viewsite';
 		}
