@@ -90,7 +90,7 @@ class defaultTheme extends AdminTheme
 		global $gCms;
 		$config =& $gCms->GetConfig();
 ?><head>
-<meta name="Generator" content="CMS Made Simple - Copyright (C) 2004-9 Ted Kulp. All rights reserved." />
+<meta name="Generator" content="CMS Made Simple - Copyright (C) 2004-10 Ted Kulp. All rights reserved." />
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
 <meta name="robots" content="noindex, nofollow" />
 <title><?php echo $this->cms->siteprefs['sitename'] ." - ". $this->title ?></title>
@@ -221,7 +221,7 @@ class defaultTheme extends AdminTheme
 
 	function DisplayHTMLStartTag() {
 		$tag = '<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en"';
-		if ($this->cms->nls['direction'] == 'rtl')
+		if (isset($this->cms->nls['direction']) &&  $this->cms->nls['direction'] == 'rtl')
 		{
 			$tag .= ' dir="rtl"';
 		}
@@ -299,7 +299,7 @@ class defaultTheme extends AdminTheme
 	  echo '<div class="itemoverflow">';
 	  echo '<p class="itemicon">';
 	  $iconSpec = $thisSection;
-	  if ($menuItem['url'] == '../index.php')
+	  if ($menuItem['url'] == $this->_viewsite_url)
 	    {
 	      $iconSpec = 'viewsite';
 	    }
@@ -393,7 +393,7 @@ class defaultTheme extends AdminTheme
 	    }
 	  if (! $moduleIcon)
 	    {
-	      if ($thisItem['url'] == '../index.php')
+	      if ($thisItem['url'] == $this->_viewsite_url)
 		{
 		  $iconSpec = 'viewsite';
 		}
