@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: topadmin.php 3021 2006-07-03 14:40:50Z elijahlofgren $
+#$Id: topadmin.php 6402 2010-06-25 00:44:47Z calguy1000 $
 
 $CMS_ADMIN_PAGE=1;
 
@@ -24,10 +24,15 @@ require_once("../include.php");
 
 check_login();
 
+$section = 'siteadmin';
+if( isset($_GET['section']) )
+  {
+    $section = trim($_GET['section']);
+  }
 include_once("header.php");
 $themeObject->ShowShortcuts();
 $themeObject->DisplaySectionMenuDivStart();
-$themeObject->DisplaySectionPages('siteadmin');
+$themeObject->DisplaySectionPages($section);
 $themeObject->DisplaySectionMenuDivEnd();
 include_once("footer.php");
 
