@@ -59,7 +59,9 @@ if( isset($CMS_ADMIN_PAGE) )
  * @package CMS
  */
 #magic_quotes_runtime is a nuisance...  turn it off before it messes something up
-set_magic_quotes_runtime(false);
+if (version_compare(phpversion(),"5.3.0","<")) {
+  set_magic_quotes_runtime(false);
+}
 
 require_once($dirname.DIRECTORY_SEPARATOR.'lib'.DIRECTORY_SEPARATOR.'misc.functions.php');
 require_once($dirname.DIRECTORY_SEPARATOR.'lib'.DIRECTORY_SEPARATOR.'module.functions.php');
@@ -70,7 +72,7 @@ array_walk_recursive($_GET, 'sanitize_get_var');
 
 #Make a new CMS object
 require(cms_join_path($dirname,'lib','classes','class.global.inc.php'));
-$gCms =& new CmsObject();
+$gCms = new CmsObject();
 if (isset($starttime))
 {
     $gCms->variables['starttime'] = $starttime;
@@ -83,6 +85,39 @@ require(cms_join_path($dirname,'lib','config.functions.php'));
 #Grab the current configuration
 $config =& $gCms->GetConfig();
 
+#Adjust the url stuff if we're using HTTPS
+if( isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] != 'off' )
+{
+  // adjust the root url
+  if( !isset($config['ssl_url']) )
+  { 
+    $config['ssl_url'] = str_replace('http://','https://',$config['root_url']);
+  }
+  $config['root_url'] = $config['ssl_url'];
+
+  // adjust the uploads url
+  if( !isset($config['ssl_uploads_url']) )
+  {
+    $config['ssl_uploads_url'] = str_replace('http://','https://',$config['ssl_uploads_url']);
+  }
+  $config['uploads_url'] = $config['ssl_uploads_url'];
+}
+else if( startswith($config['root_url'],'https://') )
+{
+  // okay, not using SSL, but the root url is https...
+  if( !isset($config['non_ssl_url']) )
+    {
+      $config['non_ssl_url'] = str_replace('https://','http://',$config['root_url']);
+    }
+  $config['root_url'] = $config['non_ssl_url'];
+
+  if( !isset($config['non_ssl_uploads_url']) )
+    {
+      $config['non_ssl_uploads_url'] = str_replace('https://','http://',$config['uploads_url']);
+    }
+  $config['uploads_url'] = $config['non_ssl_uploads_url'];
+}
+
 #Attempt to override the php memory limit
 if( isset($config['php_memory_limit']) && !empty($config['php_memory_limit'])  )
   {
@@ -132,6 +167,7 @@ debug_buffer('loading events functions');
 require_once(cms_join_path($dirname,'lib','classes','class.events.inc.php'));
 debug_buffer('loading php4 entity decode functions');
 require_once($dirname.DIRECTORY_SEPARATOR.'lib'.DIRECTORY_SEPARATOR.'html_entity_decode_php4.php');
+require_once($dirname.DIRECTORY_SEPARATOR.'lib'.DIRECTORY_SEPARATOR.'autoloader.php');
 
 debug_buffer('done loading files');
 
@@ -154,12 +190,12 @@ while ($file = readdir ($handle))
     $path_parts = pathinfo($file);
     if (isset($path_parts['extension']) && $path_parts['extension'] == 'php')
     {
-		$obj =& new CmsContentTypePlaceholder();
+		$obj = new CmsContentTypePlaceholder();
 		$obj->type = strtolower(basename($file, '.inc.php'));
 		$obj->filename = cms_join_path($dir,$file);
 		$obj->loaded = false;
 		$obj->friendlyname = basename($file, '.inc.php');
-		$contenttypes[strtolower(basename($file, '.inc.php'))] =& $obj;
+		$contenttypes[strtolower(basename($file, '.inc.php'))] = $obj;
     }
 }
 closedir($handle);
@@ -232,19 +268,30 @@ if (isset($CMS_ADMIN_PAGE) || isset($CMS_STYLESHEET))
 	if (is_file(cms_join_path($dirname,'lib','convert','ConvertCharset.class.php')))
 	{
 		include(cms_join_path($dirname,'lib','convert','ConvertCharset.class.php'));
-		$gCms->variables['convertclass'] =& new ConvertCharset();
+		$gCms->variables['convertclass'] = new ConvertCharset();
 	}
 }
 
+
 #Load all installed module code
 $modload =& $gCms->GetModuleLoader();
 $modload->LoadModules(isset($LOAD_ALL_MODULES), !isset($CMS_ADMIN_PAGE));
-
 debug_buffer('', 'End of include');
 
+#Do auto task stuff.
+if (! isset($CMS_INSTALL_PAGE))
+  {
+    CmsRegularTaskHandler::handle_tasks();
+  }
+
+
 function sanitize_get_var(&$value, $key)
 {
+  if (version_compare(phpversion(),"5.3.0","<")) {
     $value = eregi_replace('\<\/?script[^\>]*\>', '', $value);
+  } else {
+    $value = preg_replace('/\<\/?script[^\>]*\>/i', '', $value); //the i makes it caseinsensitive
+  }
 }
 
 # vim:ts=4 sw=4 noet
