@@ -83,7 +83,7 @@ if(isset($_GET['advanceduser']))
 
 
 
-$installer =& new CMSInstaller($max_pages, $debug);
+$installer = new CMSInstaller($max_pages, $debug);
 
 
 
@@ -117,7 +117,7 @@ if(! isset($_GET['sessiontest']) && (! isset($_POST['page'])) )
 	}
 
 	require_once $pathSmartClass;
-	$smarty =& new Smarty();
+	$smarty = new Smarty();
 	$smarty->compile_dir = TMP_TEMPLATES_C_LOCATION;
 	$smarty->cache_dir = TMP_CACHE_LOCATION;
 	$smarty->template_dir = cms_join_path(CMS_INSTALL_BASE, 'templates');
@@ -140,6 +140,8 @@ else if(! isset($_SESSION['test']))
 
 // First checks ok
 require_once cms_join_path(CMS_BASE, 'include.php');
+$smarty->caching = false;
+$smarty->force_compile = true;
 
 if(isset($_POST['default_cms_lang']))
 {
