@@ -1,4 +1,10 @@
 <?php
+$lang['test_error_estrict'] = 'Testing error_reporting to ensure E_STRICT is disabled';
+$lang['test_estrict_failed'] = 'E_STRICT is enabled';
+$lang['info_estrict_failed'] = 'Some libraries that CMSMS uses do not work well with E_STRICT.  Please disable this before continuing';
+$lang['test_error_edeprecated'] = 'Testing error_reporting to ensure E_DEPRECATED is disabled';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED is enabled';
+$lang['info_edeprecated_failed'] = 'If E_DEPRECATED is enabled in your error reporting users will see alot of warning messages that could effect the display and functionalty';
 $lang['invalidemail'] = 'The email address entered is invalid';
 $lang['empty_query'] = 'Empty query?? %s';
 $lang['no_db_driver'] = 'No compatible database drivers found';
@@ -249,7 +255,7 @@ $lang['test_could_not_create_table'] = 'Could not create a table. Verify that th
 $lang['test_check_php'] = 'Checking for PHP version %s+';
 $lang['test_min_recommend'] = '(minimum %s, recommend %s or greater)';
 $lang['test_min_recommend_plus'] = '(min %s, recommend %s+)';
-$lang['test_requires_php_version'] = 'CMS Made Simple requires a php version of 4.3 or greater (you have %s), but PHP %s or greater is recommended to ensure maximum compatibility with third party addons';
+$lang['test_requires_php_version'] = 'CMS Made Simple requires a php version of 5.2.4 or greater (you have %s), but PHP %s or greater is recommended to ensure maximum compatibility with third party addons';
 $lang['test_check_md5_func'] = 'Checking for md5 Function';
 $lang['test_check_safe_mode'] = 'Checking for safe mode';
 $lang['test_check_safe_mode_failed'] = 'PHP safe mode could create some problems with uploading files and other functions. It all depends on how strict your server safe mode settings are.';
