@@ -28,7 +28,7 @@ $lang['installing_module'] = 'Instaluje se  %s modul ...';
 $lang['updating_schema_version'] = 'Aktualizuje se schema verze %s ...';
 $lang['upgrade_config'] = 'Aktualizuje se config.php';
 $lang['upgrade_config_info'] = 'aktualizace konfigurace';
-$lang['upgrade_failed_again'] = 'Jeden nebo v&iacute;ce aktualizac&iacute; selhalo. Opravte, pros&iacute;m, probl&eacute;m akliknětě na tlač&iacute;tko n&iacute;že pro překontrolov&aacute;n&iacute;.';
+$lang['upgrade_failed_again'] = 'Jedna nebo v&iacute;ce aktualizac&iacute; selhalo. Opravte, pros&iacute;m, probl&eacute;m a klikněte na tlač&iacute;tko n&iacute;že pro překontrolov&aacute;n&iacute;.';
 $lang['upgrade_cache_dirs'] = 'Čist&iacute; se adres&aacute;ře ke&scaron;e';
 $lang['cannot_clean_cache_dirs'] = 'Nelze vyčistit adres&aacute;ře ke&scaron;e!';
 $lang['upgrade_schema'] = 'Aktualizuje se schema';
@@ -333,8 +333,9 @@ uživatelsk&eacute; jm&eacute;no: %s
 heslo: %s
 
 Přihl&aacute;sit do administrace se můžete zde: %s';
-$lang['utma'] = '156861353.503654010.1232181160.1241440658.1245245150.32';
-$lang['utmz'] = '156861353.1245245150.32.7.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/projects/czech|utmcmd=referral';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.3769824904990279700.1249913289.1261996808.1263200482.16';
+$lang['utmz'] = '156861353.1249913289.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['qca'] = '1229762881-19854751-99654968';
+$lang['utmb'] = '156861353.1.10.1263200482';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
