@@ -1,81 +1,89 @@
 <?php
+$lang['test_error_estrict'] = 'Testing error_reporting to ensure E_STRICT is disabled';
+$lang['test_estrict_failed'] = 'E_STRICT is enabled';
+$lang['info_estrict_failed'] = 'Some libraries that CMSMS uses do not work well with E_STRICT.  Please disable this before continuing';
+$lang['test_error_edeprecated'] = 'Testing error_reporting to ensure E_DEPRECATED is disabled';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED is enabled';
+$lang['info_edeprecated_failed'] = 'If E_DEPRECATED is enabled in your error reporting users will see alot of warning messages that could effect the display and functionalty';
+$lang['invalidemail'] = 'Den angivne email adresse er ikke gyldig';
+$lang['empty_query'] = 'Tom foresp&oslash;rgsel? %s';
 $lang['no_db_driver'] = 'Ingen kompatibel database driver fundet';
 $lang['test_check_output_buffering'] = 'Kontrollerer output bufferin';
-$lang['test_check_output_buffering_failed'] = 'Output buffering is disabled. You will probably not be able to use any of functionality that requires this';
+$lang['test_check_output_buffering_failed'] = 'Output buffering er sl&aring;et fra. Du vil muligvis ikke kunne benytte funktioner der kr&aelig;ver dette.';
 $lang['phpinfo'] = 'Vis PHP information';
-$lang['mod_security'] = 'Apache Mod Security';
+$lang['mod_security'] = 'Apache Mod sikkerhed';
 $lang['test_check_tempnam'] = 'Kontrollerer for tempnam function';
-$lang['test_check_db_drivers'] = 'DB drivers';
-$lang['test_check_db_drivers_failed'] = 'No DB drivers found';
+$lang['test_check_db_drivers'] = 'DB drivere';
+$lang['test_check_db_drivers_failed'] = 'Ingen DB drivere found';
 $lang['test_check_register_globals'] = 'Kontrollerer for PHP register globals';
-$lang['test_check_register_globals_failed'] = 'PHP register globals is active. For security reasons, this should be disabled.';
-$lang['test_check_disable_functions'] = 'Checking PHP disable functions';
+$lang['test_check_register_globals_failed'] = 'PHP register globals er aktiv. Af sikkerhedshensyn b&oslash;r dette v&aelig;re sl&aring;et fra';
+$lang['test_check_disable_functions'] = 'Kontrollerer PHP funktioner der er sl&aring;et fra';
 $lang['test_check_disable_functions_failed'] = 'Advarsel: dette er en list over funktioner der er sl&aring;et fra p&aring; din server';
 $lang['install_admin_db_port'] = 'Database port';
-$lang['install_admin_db_port_info'] = 'Hvis du ikke ved det, lad dette felt forblive blanks for at benytte standard-installingerne';
+$lang['install_admin_db_port_info'] = 'Hvis du ikke ved det, lad dette felt forblive blankt for at benytte standard-installingerne';
 $lang['install_admin_db_socket'] = 'Database socket';
 $lang['install_admin_db_socket_info'] = 'Ikke underst&oslash;ttet';
 $lang['install_admin_frontendlang'] = 'Standard sprog for frontend. Dette angiver lokale installer for diverse dato funktioner etc.';
 $lang['install_default_encoding'] = 'I stort set alle situationer skal default_encoding v&aelig;re utf-8.';
 $lang['installer_done'] = '[f&aelig;rdig]';
 $lang['installer_failed'] = '[fejlede]';
-$lang['create_permission'] = 'Create permission ...';
-$lang['add_column_sql'] = 'Adding column to %s table ...';
-$lang['update_table_sql'] = 'Updating table %s ...';
-$lang['installing_module'] = 'Installing module %s ...';
-$lang['updating_schema_version'] = 'Updating schema version %s ...';
-$lang['upgrade_config'] = 'Upgrading config.php';
-$lang['upgrade_config_info'] = 'config upgrade';
-$lang['upgrade_failed_again'] = 'One or more upgrades have failed. Please correct the problem and click the button below to recheck.';
-$lang['upgrade_cache_dirs'] = 'Cleaning cache dirs';
-$lang['cannot_clean_cache_dirs'] = 'Cannot cleaning cache dirs!';
-$lang['upgrade_schema'] = 'Upgrade schema';
-$lang['need_upgrade_schema'] = 'CMS is in need of an upgrade.<br />You are now running schema version %s and you need to be upgraded to version %s';
-$lang['schema_ok'] = 'The CMS database is up to date.  Using schema version %s';
-$lang['noneed_upgrade_schema'] = 'The CMS database is up to date. Using schema version %s';
-$lang['upgrade_modules'] = 'Upgrade modules';
-$lang['noneed_upgrade_modules'] = 'The core modules are up to date';
+$lang['create_permission'] = 'Opretter tilladelse';
+$lang['add_column_sql'] = 'Tilf&oslash;jer kolonne til %s tabellen ...';
+$lang['update_table_sql'] = 'Opdaterer tabellen %s ...';
+$lang['installing_module'] = 'Installerer modul %s ...';
+$lang['updating_schema_version'] = 'Opdater til skema version %s ...';
+$lang['upgrade_config'] = 'Opgraderer config.php';
+$lang['upgrade_config_info'] = 'config opgradering';
+$lang['upgrade_failed_again'] = 'En eller flere opgraderinger fejlede. L&oslash;s venligst problemet og klik p&aring; knappen herunder for at pr&oslash;ve igen.';
+$lang['upgrade_cache_dirs'] = 'T&oslash;mmer cache mapper';
+$lang['cannot_clean_cache_dirs'] = 'Kan ikke t&oslash;mme cache mapper!';
+$lang['upgrade_schema'] = 'Opgrad&eacute;r skema';
+$lang['need_upgrade_schema'] = 'CMS skal opgraderes.<br/>Du k&oslash;rer lige nu skema version %s og du skal opgraderes til version %s';
+$lang['schema_ok'] = 'CMS-databasen er opdateret. Benytter skema version %s';
+$lang['noneed_upgrade_schema'] = 'CMS-databasen er opdateret. Benytter skema version %s';
+$lang['upgrade_modules'] = 'Opgrad&eacute;r moduler';
+$lang['noneed_upgrade_modules'] = 'Kerne-moduler er opdateret';
 $lang['upgrade_sql_module_from_to'] = 'Upgrading SQL of &quot;%s&quot; module from %s to %s ...';
 $lang['upgrade_event_module_from_to'] = 'Upgrading Events of &quot;%s&quot; module from %s to %s ...';
 $lang['sitedown_not_removed'] = 'Could not remove the tmp/cache/SITEDOWN file. Please remove manually or you will continue to show a &quot;Site Down for Maintainence&quot; message on your site';
 $lang['upgrade_ok'] = 'Please review config.php, modify any new settings as necessary and then reset it&#039;s permissions back to a locked state. You should also check that all of your modules are up to date, by going to the Extensions -> Modules page and looking for any listed as &quot;Needs Upgrade&quot;';
-$lang['upgrade_complete'] = 'Upgrade process complete';
-$lang['upgrade_end'] = 'CMS is up to date. Please click %s to go to your CMS site or you can %s.';
+$lang['upgrade_complete'] = 'Opgraderingen er udf&oslash;rt';
+$lang['upgrade_end'] = 'CMS er opgraderet. Klik %s for at se dit cms-site eller du kan %s.';
 $lang['here'] = 'her';
-$lang['go_to_admin'] = 'for at g&aring; til administrationen';
+$lang['go_to_admin'] = 'G&aring; til administrationen';
 $lang['errorfilenot'] = 'Fil ikke fundet!';
 $lang['errorfilenotwritable'] = 'Fil ikke skrivbar!';
-$lang['nofiles'] = 'This resource does not exist!';
-$lang['is_directory'] = 'This resource is a directory!';
-$lang['is_readable_false'] = 'This resource is not readable!';
-$lang['checksum_match'] = 'Checksum matches!';
-$lang['checksum_not_match'] = 'Checksum does not match!';
-$lang['not_checksum'] = 'Could not retrieve checksum!';
+$lang['nofiles'] = 'Denne ressource eksisterer ikke!';
+$lang['is_directory'] = 'Denne ressource er en mappe!';
+$lang['is_readable_false'] = 'Denne ressource er ikke l&aelig;sbar!';
+$lang['checksum_match'] = 'Checksum passer!';
+$lang['checksum_not_match'] = 'Checksum passer ikke!';
+$lang['not_checksum'] = 'Kunne ikke hente checksum.';
 $lang['format_datetime'] = '%c';
-$lang['upload_err_ini_size'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini!';
+$lang['upload_err_ini_size'] = 'Den upload&#039;ede fil er st&oslash;rre end den upload_max_filesize der er angivet i php.ini!';
 $lang['upload_err_form_size'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';
-$lang['upload_err_partial'] = 'The uploaded file was only partially uploaded.';
-$lang['upload_err_no_file'] = 'No file was uploaded.';
-$lang['upload_err_no_tmp_dir'] = 'Missing a temporary folder.';
-$lang['upload_err_cant_write'] = 'Failed to write file to disk.';
+$lang['upload_err_partial'] = 'Den upload&#039;ede fil blev kun delvist upload&#039;et';
+$lang['upload_err_no_file'] = 'Ingen fil blev upload&#039;et.';
+$lang['upload_err_no_tmp_dir'] = 'Mangler en midlertidig mappe.';
+$lang['upload_err_cant_write'] = 'Fejl ved skrivning til disk.';
 $lang['upload_err_extension'] = 'File upload stopped by extension.';
-$lang['upload_err_empty'] = 'File has size zero';
-$lang['upload_err_unknown'] = 'Unknown file upload problem.';
-$lang['function_file_uploads_off'] = 'file_uploads is off in your php configuration!';
-$lang['upload_file_no_readable'] = 'Uploaded file is not readable!';
+$lang['upload_err_empty'] = 'Filen er tom';
+$lang['upload_err_unknown'] = 'Ukendt upload problem';
+$lang['function_file_uploads_off'] = 'file_uploads er sl&aring;et fra i din php konfiguration!';
+$lang['upload_file_no_readable'] = 'Den upload&#039;ede fil kan ikke l&aelig;ses';
 $lang['upload_file_multiple'] = 'Multiple file uploads are not allowed!';
 $lang['test_check_magic_quotes_gpc'] = 'Magic quotes for Get/Post/Cookie operations';
 $lang['test_check_magic_quotes_gpc_failed'] = 'When magic_quotes are on, all single-quote, double quote and backslash are escaped with a backslash automatically. This can cause many problems in CMS.';
 $lang['test_check_magic_quotes_runtime'] = 'Magic quotes in runtime';
 $lang['test_check_magic_quotes_runtime_failed'] = 'When magic_quotes are on, most functions that return data from any sort of external source including databases and text files will have quotes escaped with a backslash. This will cause problems with CMS made simple.';
-$lang['install_admin_checksum'] = 'Check your installation';
-$lang['upgrade_admin_checksum'] = 'Check your system upgrade';
+$lang['install_admin_checksum'] = 'Tjek din installation';
+$lang['upgrade_admin_checksum'] = 'Tjek din system opgradering';
 $lang['checksum'] = 'Checksum test';
-$lang['checksum_file'] = 'Checksum file';
+$lang['checksum_file'] = 'Checksum fil';
 $lang['install_test_checksum'] = 'You can validate the integrity of your CMS files by comparing against original CMS checksum. It can assist in finding problems with uploads.';
-$lang['checksum_passed'] = 'All checksums match!';
+$lang['checksum_passed'] = 'Alle tjeksummer passer!';
 $lang['checksum_failed'] = 'Checksum match with errors. Look at the help for more information';
-$lang['test_check_open_basedir'] = 'Check for PHP Open Basedir';
+$lang['test_check_open_basedir'] = 'Tjek for PHP Open Basedir';
 $lang['test_check_open_basedir_failed'] = 'Open basedir restrictions are in effect. You may have difficulty with some addon functionality with this restriction.';
 $lang['unlimited'] = 'Ubegr&aelig;nset';
 $lang['test_open_basedir_session_save_path'] = 'Open basedir is setting. If you have SESSION problems and ini_set works you can try to enable session cookies adding: ini_set(&#039;session.use_only_cookies&#039;, 1);  to top of include.php';
@@ -184,9 +192,9 @@ $lang['version'] = 'Version';
 $lang['install_title'] = 'CMS Made Simple Installation (trin %s)';
 $lang['install_system'] = 'Installations system';
 $lang['install_thanks'] = 'Tak fordi du installerede CMS Made Simple';
-$lang['upgrade_title'] = 'CMS Made Simple Upgrade (step %s)';
-$lang['upgrade_system'] = 'Upgrade System';
-$lang['upgrade_thanks'] = 'Thanks for upgrading CMS Made Simple to';
+$lang['upgrade_title'] = 'CMS Made Simple Opgradering (trin %s)';
+$lang['upgrade_system'] = 'Opgrad&eacute;r systemet';
+$lang['upgrade_thanks'] = 'Tak fordi du opgradere CMS Made Simple til';
 $lang['install_please_read'] = 'L&aelig;s venligst <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting">Installation Troubleshooting</a> siden i CMS Made Simple dokumentations-wiki&#039;en';
 $lang['install_checking'] = 'Kontrollere rettigheder og PHP indstillinger';
 $lang['install_test'] = 'Test';
@@ -199,7 +207,7 @@ $lang['install_symbol'] = 'Symbol';
 $lang['install_definition'] = 'Definition';
 $lang['install_value_passed'] = 'En p&aring;kr&aelig;vet test lykkedes';
 $lang['install_value_failed'] = 'En p&aring;kr&aelig;vet test mislykkedes';
-$lang['install_error_fragment'] = 'Info Installation Troubleshooting';
+$lang['install_error_fragment'] = 'Information til fejlfinding af installationen';
 $lang['install_value_required'] = 'En indstilling er under den p&aring;kr&aelig;vede v&aelig;rdi';
 $lang['install_value_recommended'] = 'En indstillinger er over den p&aring;kr&aelig;vede v&aelig;rdi, men under den anbefalede<br />eller... En egenskab, som <em>m&aring;ske</em> vil v&aelig;re p&aring;kr&aelig;vet af nogle valgfrie funktioner, er ikke til stede';
 $lang['install_value_exceed'] = 'En indstilling er over eller lig med den anbefalede v&aelig;rdi<br />eller... En egenskab, som <em>m&aring;ske</em> vil v&aelig;re p&aring;kr&aelig;vet til nogle valgfrie funktioner, er til stede';
@@ -330,8 +338,9 @@ brugernavn: %s
 kodeord: %s
 
 Log ind i site administrationen her: %s';
-$lang['utma'] = '156861353.2155648126422823700.1234651492.1234651492.1234726049.2';
-$lang['utmz'] = '156861353.1234651492.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['utma'] = '156861353.2039886585.1231713618.1270923295.1271012110.115';
+$lang['utmz'] = '156861353.1269788432.113.24.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
+$lang['qca'] = '1229601790-85243197-43260713';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
