@@ -1,4 +1,10 @@
 <?php
+$lang['test_error_estrict'] = 'Teste error_reporting, um sicherzustellen, dass E_STRICT deaktiviert ist';
+$lang['test_estrict_failed'] = 'E_STRICT ist aktiviert';
+$lang['info_estrict_failed'] = 'Einige Programmbibliotheken, die CMSms verwendet, funktionieren nicht gut mit E_STRICT.  Bitte deaktivieren Sie dies, bevor Sie weitermachen.';
+$lang['test_error_edeprecated'] = 'Teste error_reporting, um sicherzustellen, dass E_DEPRECATED deaktiviert ist';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED ist aktiviert';
+$lang['info_edeprecated_failed'] = 'Wenn E_DEPRECATED in Ihren error_reporting Einstellungen aktiviert ist, werden eine ganze Reihe von Warnhinweisen angezeigt, die Auswirkungen auf die Anzeige und die Funktionalit&auml;ten haben k&ouml;nnen.';
 $lang['invalidemail'] = 'Die eingegebene Email-Adresse ist ung&uuml;ltig';
 $lang['empty_query'] = 'Leere Abfrage?? %s';
 $lang['no_db_driver'] = 'Keine kompatiblen Datenbanktreiber gefunden';
@@ -81,7 +87,7 @@ $lang['test_check_open_basedir'] = 'Pr&uuml;fung auf PHP Open Basedir';
 $lang['test_check_open_basedir_failed'] = 'Die &quot;Open basedir&quot;-Beschr&auml;nkungen sind bei Ihnen aktiviert. Aufgrund dieser Beschr&auml;nkung k&ouml;nnen bei bestimmten Funktionalit&auml;ten Probleme auftreten.';
 $lang['unlimited'] = 'Keine Einschr&auml;nkung';
 $lang['test_open_basedir_session_save_path'] = 'Die &quot;Open basedir&quot;-Beschr&auml;nkungen scheint bei Ihnen aktiviert zu sein. Wenn Sie Probleme mit Sessions haben, aber der Befehl ini_set ausgef&uuml;hrt werden kann, k&ouml;nnen Sie versuchen, die Option &quot;session by cookies&quot; zu aktivieren, indem Sie der Datei config.php gleich als erste Zeile folgendes hinzuf&uuml;gen: ini_set(&#039;session.use_only_cookies&#039;, 1);';
-$lang['install_warn_db_createtables'] = 'Normalerweise sollte dieses Feld regelm&auml;&szlig;ig &uuml;berpr&uuml;ft werden. Sie sollten daher wissen, was Sie tun, wenn Sie diese Funktion deaktivieren.';
+$lang['install_warn_db_createtables'] = 'Im Normalfall sollte dieses Kontrollfeld aktiviert sein. Sie sollten wissen, was Sie tun, wenn Sie diese Funktion deaktivieren.';
 $lang['install_admin_tablesnotcreated'] = 'Die Installation ist jetzt vollst&auml;ndig. Aufgrund Ihrer Einstellungen wurden die Datenbanktabellen NICHT erzeugt. Die Einstellungen wurden in der Datei config.php wurden gespeichert und alle Tests erfolgreich absolviert.  Vielen Dank, hier ist Ihr';
 $lang['info_create_dir_and_file'] = 'Der httpd-Proze&szlig; konnte keine Datei in eigenen Verzeichnissen erzeugen. Das bedeutet, dass der Safe-Modus auf Ihrem Host aktiviert ist. Ohne diese F&auml;higkeit k&ouml;nnen einige Funktionen von CMS made simple jedoch nicht arbeiten. Die Fortsetzung ist daher nicht m&ouml;glich.';
 $lang['test_create_dir_and_file'] = 'Pr&uuml;fung, ob der httpd-Proze&szlig; eine Datei in einem selbst erstellten Verzeichnis erzeugen kann.';
@@ -332,9 +338,8 @@ Benutzername: %s
 Passwort: %s
 
 In die Administration Ihrer Seite gelangen Sie hier: %s';
-$lang['qca'] = 'P0-1909116003-1254132235568';
-$lang['utma'] = '156861353.858097627.1254132339.1254132339.1254136190.2';
-$lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1254136190.2.2.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['utma'] = '156861353.1368086895.1281338275.1281338275.1281338275.1';
 $lang['utmb'] = '156861353';
+$lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1281338275.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/topic,46352.msg221259.html|utmcmd=referral';
 ?>
\ No newline at end of file
