@@ -85,7 +85,7 @@ $lang['install_warn_db_createtables'] = 'Este campo deberia estar seleccionado s
 $lang['install_admin_tablesnotcreated'] = 'Proceso completo. El proceso de instalaci&oacute;n se ha completado, como usted lo ha solicitado asi, no se han creado las tablas de la base de datos. Sin embargo, el archivo de configuraci&oacute;n ha sido reestablecido y todas las pruebas de pre-instalaci&oacute;n han sido pasadas. Gracias, y aqui est&aacute; su';
 $lang['info_create_dir_and_file'] = 'El due&ntilde;o del proceso HTTP no puede crear un archivo adentro de un directorio que le pertenece. Esto posiblemente quiere decir que &quot;safe mode&quot; est&aacute; activo de alguna forma. Muchas funciones adentro de &quot;CMS made simple&quot; no se ejecutaran adecuadamente sin esta opci&oacute;n. No se puede continuar.';
 $lang['test_create_dir_and_file'] = 'Revisando si el proceso de httpd puede crear un archivo adentro del directorio que este cre&oacute;.';
-$lang['cms_site'] = 'Sition CMS';
+$lang['cms_site'] = 'Sitio CMS';
 $lang['or_greater'] = 'O mayor';
 $lang['sitename'] = 'Nombre del sitio';
 $lang['warning_safe_mode'] = '<strong><em>ADVERTENCIA:</em></strong> El modo &#039;PHP Safe&#039; esta habilitado. Esto puede causar dificultades con archivos subidos a traves de la interfaz web de explorador de archivos, incluyendo imagenes, temas y paquetes XML de m&oacute;dulos. Se recomienda que contacte al administrador del sitio acerca de deshabilitar el modo &#039;PHP Safe&#039;.';
@@ -332,9 +332,9 @@ usuario: %s
 clave: %s
 
 Acceda al panel administrativo aqui: %s';
-$lang['utma'] = '156861353.661434885.1227567621.1254348603.1254357593.130';
-$lang['utmz'] = '156861353.1254357593.130.50.utmcsr=cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
-$lang['qca'] = '1227207610-48391025-71477127';
+$lang['qca'] = 'P0-2096054370-1259803615939';
+$lang['utma'] = '156861353.238606854.1259804368.1267925726.1267940197.71';
+$lang['utmz'] = '156861353.1267925726.70.33.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.3.10.1254357593';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
