@@ -1,4 +1,92 @@
 <?php
+$lang['test_error_estrict'] = 'Testataan error_reporting varmistaaksemme, ett&auml; E_STRICT on pois p&auml;&auml;lt&auml;';
+$lang['test_estrict_failed'] = 'E_STRICT on p&auml;&auml;ll&auml;';
+$lang['info_estrict_failed'] = 'Osa kirjastoista, joita CMSMS k&auml;ytt&auml;&auml; eiv&auml;t toimi hyvin E_STRICT:n kanssa.  Ole hyv&auml; ja ota se pois k&auml;yt&ouml;st&auml; ennen jatkamista';
+$lang['test_error_edeprecated'] = 'Testataan error_reporting varmistaaksemme, ett&auml; E_DEPRECATED on pois p&auml;&auml;lt&auml;';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED on p&auml;&auml;ll&auml;';
+$lang['info_edeprecated_failed'] = 'Jos E_DEPRECATED on p&auml;&auml;ll&auml; virheilmoituksissa, k&auml;ytt&auml;j&auml;si n&auml;kev&auml;t paljon virheilmoituksia, jotka voivat vaikuttaa sivuston ulkoasuun ja toiminnallsuuteen.';
+$lang['invalidemail'] = 'Annettu s&auml;hk&ouml;postiosoite on virheellinen';
+$lang['empty_query'] = 'Tyhj&auml; pyynt&ouml;?? %s';
+$lang['no_db_driver'] = 'Yhteensopivia tietokanta-ajureita ei l&ouml;ytynyt';
+$lang['test_check_output_buffering'] = 'Tarkistetaan ulosannin puskurointia';
+$lang['test_check_output_buffering_failed'] = 'Ulosannin puskurointi on pois p&auml;&auml;lt&auml;. Et todenn&auml;k&ouml;isesti voi k&auml;ytt&auml;&auml; toiminnallisuuksia, jotka vaativat t&auml;t&auml;';
+$lang['phpinfo'] = 'N&auml;yt&auml; PHP-tiedot';
+$lang['mod_security'] = 'Apache Mod Security';
+$lang['test_check_tempnam'] = 'Tarkistetaan tempnam-funktiota';
+$lang['test_check_db_drivers'] = 'Tietokanta-ajurit';
+$lang['test_check_db_drivers_failed'] = 'Tietokanta-ajureita ei l&ouml;ytynyt';
+$lang['test_check_register_globals'] = 'Tarkistetaan PHP register globals';
+$lang['test_check_register_globals_failed'] = 'PHP register globals on p&auml;&auml;ll&auml;. Turvallisuussyist&auml; se tulisi ottaa pois p&auml;&auml;lt&auml;.';
+$lang['test_check_disable_functions'] = 'Tarkistetaan PHP disable -funktiot';
+$lang['test_check_disable_functions_failed'] = 'Varoitus: t&auml;m&auml; on lista funktioita, jotka ovat pois p&auml;&auml;lt&auml; palvelimellasi.';
+$lang['install_admin_db_port'] = 'Tietokantaportti';
+$lang['install_admin_db_port_info'] = 'Jos et tied&auml; t&auml;t&auml;, j&auml;t&auml; se tyhj&auml;ksi. Siin&auml; tapauksessa k&auml;ytet&auml;&auml;n oletusarvoa.';
+$lang['install_admin_db_socket'] = 'Database socket';
+$lang['install_admin_db_socket_info'] = 'EI TUETTU.';
+$lang['install_admin_frontendlang'] = 'Oletuskieli julkiselle sivustolle. T&auml;m&auml; s&auml;&auml;t&auml;&auml; oletus kieliasetusta, jota k&auml;ytet&auml;&auml;n esimerkiksi p&auml;iv&auml;m&auml;&auml;r&auml;- ja aikamuodoissa yms.';
+$lang['install_default_encoding'] = 'L&auml;hes kaikissa tapauksissa, oletuksena tulisi olla utf-8.';
+$lang['installer_done'] = '[valmis]';
+$lang['installer_failed'] = '[ep&auml;onnistui]';
+$lang['create_permission'] = 'Luo oikeudet ...';
+$lang['add_column_sql'] = 'Lis&auml;t&auml;&auml;n sarake %s tauluun ...';
+$lang['update_table_sql'] = 'P&auml;ivitet&auml;&auml;n taulu %s ...';
+$lang['installing_module'] = 'Asennetaan moduuli %s ...';
+$lang['updating_schema_version'] = 'P&auml;ivitet&auml;&auml;n skeeman versio %s ...';
+$lang['upgrade_config'] = 'P&auml;ivitet&auml;&auml;n config.php';
+$lang['upgrade_config_info'] = 'konfiguraation p&auml;ivitys';
+$lang['upgrade_failed_again'] = 'Yksi tai useampi p&auml;ivitys ep&auml;onnistui. Ole hyv&auml;, korjaa virheet ja klikkaa painiketta alapuolella tehd&auml;ksesi tarkistus uudelleen.';
+$lang['upgrade_cache_dirs'] = 'Tyhjennet&auml;&auml;n v&auml;limuistihakemistot';
+$lang['cannot_clean_cache_dirs'] = 'Ei voida tyhjent&auml;&auml; v&auml;limuistihakemistoja!';
+$lang['upgrade_schema'] = 'P&auml;ivitysskeema';
+$lang['need_upgrade_schema'] = 'CMS vaatii p&auml;ivityksen.br />Ajat t&auml;ll&auml; hetkell&auml; versiota %s ja sinun t&auml;ytyy p&auml;ivitt&auml;&auml; versioon %s';
+$lang['schema_ok'] = 'CMS:n tietokanta on ajantasalla.  K&auml;ytet&auml;&auml;n skeemaversiota %s';
+$lang['noneed_upgrade_schema'] = 'CMS:n tietokanta on ajantasalla. K&auml;ytet&auml;&auml;n skeemaversiota %s';
+$lang['upgrade_modules'] = 'P&auml;ivit&auml; moduulit';
+$lang['noneed_upgrade_modules'] = 'Ydinmoduulit ovat ajantasalla';
+$lang['upgrade_sql_module_from_to'] = 'P&auml;ivitet&auml;&auml;n SQL &quot;%s&quot; moduulin versiosta %s versioon %s ...';
+$lang['upgrade_event_module_from_to'] = 'P&auml;ivitet&auml;&auml;n tapahtumat &quot;%s&quot; moduulin versiosta %s versioon %s ...';
+$lang['sitedown_not_removed'] = 'Ei voitu poistaa tmp/cache/SITEDOWN tiedostoa. Poista tiedosto k&auml;sin tai sivustollasi n&auml;kyy edelleen viesti huoltokatkoksesta.';
+$lang['upgrade_ok'] = 'Ole hyv&auml; ja tarkista config.php -tiedosto, muokkaa uudet asetukset tarvittaessa ja lukitse tiedosto j&auml;lleen sen j&auml;lkeen. Tarkista my&ouml;s, ett&auml; kaikki moduulisi ovat ajantasalla menem&auml;ll&auml; Lis&auml;osat >> Moduulit sivulle ja tarkista ettei saatavilla ole p&auml;ivityksi&auml;.';
+$lang['upgrade_complete'] = 'P&auml;ivitys on valmis';
+$lang['upgrade_end'] = 'CMS on ajantasalla. Klikkaa %s siirty&auml;ksesi sivustolle tai voit %s.';
+$lang['here'] = 't&auml;st&auml;';
+$lang['go_to_admin'] = 'menn&auml; hallintapaneeliin';
+$lang['errorfilenot'] = 'Tiedostoa ei l&ouml;ydy!';
+$lang['errorfilenotwritable'] = 'Tiedostoon ei voida kirjoittaa!';
+$lang['nofiles'] = 'T&auml;t&auml; resurssia ei ole olemassa!';
+$lang['is_directory'] = 'T&auml;m&auml; resurssi on hakemisto!';
+$lang['is_readable_false'] = 'T&auml;t&auml; resurssia ei voida lukea!';
+$lang['checksum_match'] = 'Tarkistesumma t&auml;sm&auml;&auml;!';
+$lang['checksum_not_match'] = 'Tarkistasumma ei t&auml;sm&auml;&auml;!';
+$lang['not_checksum'] = 'Ei voitu hakea tarkistesummaa!';
+$lang['format_datetime'] = '%c';
+$lang['upload_err_ini_size'] = 'L&auml;hetetty tiedosto ylitt&auml;&auml; e upload_max_filesize asetuksen php.ini-tiedostossa!';
+$lang['upload_err_form_size'] = 'L&auml;hetetty tiedosto ylitt&auml;&auml; MAX_FILE_SIZE asetuksen, joka on m&auml;&auml;ritelty HTML-lomakkeessa.';
+$lang['upload_err_partial'] = 'Tiedosto l&auml;hetettiin ainoastaan osittain.';
+$lang['upload_err_no_file'] = 'Ei l&auml;hetetty&auml; tiedostoa.';
+$lang['upload_err_no_tmp_dir'] = 'V&auml;liaikainen hakemisto puuttuu.';
+$lang['upload_err_cant_write'] = 'Levylle kirjoittaminen ep&auml;onnistui.';
+$lang['upload_err_extension'] = 'Laajennos keskeytti tiedoston l&auml;hetyksen.';
+$lang['upload_err_empty'] = 'Tiedoston koko on nolla';
+$lang['upload_err_unknown'] = 'Tuntematon virhe tiedoston l&auml;hetyksess&auml;.';
+$lang['function_file_uploads_off'] = 'file_uploads on pois p&auml;&auml;lt&auml; php-asetuksissa!';
+$lang['upload_file_no_readable'] = 'L&auml;hetetty&auml; tiedostoa ei voida lukea!';
+$lang['upload_file_multiple'] = 'Useamman tiedoston l&auml;hett&auml;minen ei ole sallittua!';
+$lang['test_check_magic_quotes_gpc'] = 'Magic quotes for Get/Post/Cookie operations';
+$lang['test_check_magic_quotes_gpc_failed'] = 'Kun magic_quotes on p&auml;&auml;ll&auml;, kaikki lainausmerkit merkit&auml;&auml;n automaattisesti kauttaviivalla. T&auml;m&auml; voi aiheuttaa ongelmia CMS:ss&auml;.';
+$lang['test_check_magic_quotes_runtime'] = 'Magic quotes in runtime';
+$lang['test_check_magic_quotes_runtime_failed'] = 'KunWhen magic_quotes on p&auml;&auml;ll&auml;, mitk&auml; tahansa funktiot, jotka palauttavat tietoa mist&auml; tahansa ulkoisesta l&auml;hteest&auml; mukaan lukien tietokannat ja tekstitiedostot sis&auml;lt&auml;v&auml;t lainausmerkit merkittyn&auml; kauttaviivoilla. T&auml;m&auml; aiheuttaa ongelmia CMS Made Simplen kanssa.';
+$lang['install_admin_checksum'] = 'Tarkista asennuksesi';
+$lang['upgrade_admin_checksum'] = 'Tarkista j&auml;rjestelm&auml;si p&auml;ivitys';
+$lang['checksum'] = 'Tarkistesumman testaus';
+$lang['checksum_file'] = 'Tarkistesummatiedosto';
+$lang['install_test_checksum'] = 'Voit tarkistaa CMS:n tiedostojen eheyden vertaamalla niit&auml; alkuper&auml;isiin tiedostoihin. Se voi helpottaa ongelmien l&ouml;yt&auml;misess&auml; tiedostojen l&auml;hetyksess&auml;.';
+$lang['checksum_passed'] = 'Kaikki tarkistesummat vastaavat!';
+$lang['checksum_failed'] = 'Tarkistesummien tarkistuksesta l&ouml;ytyi virhe. Katso ohjeista lis&auml;tietoa';
+$lang['test_check_open_basedir'] = 'Tarkista PHP Open Basedir';
+$lang['test_check_open_basedir_failed'] = 'Open basedir rajoitukset ovat p&auml;&auml;ll&auml;. Sinulla voi olla ongelmia joidenkin lis&auml;osien kanssa, kun t&auml;m&auml; rajoitus on olemassa.';
+$lang['unlimited'] = 'Rajoittamaton';
+$lang['test_open_basedir_session_save_path'] = 'Open basedir restrictions appear to be in effect. If you have SESSION problems and ini_set works, you can try to enable sessions with cookies adding: ini_set(&#039;session.use_only_cookies&#039;, 1);  to top of config.php';
 $lang['install_warn_db_createtables'] = 'Normaalisti t&auml;m&auml;n tulisi olla aina p&auml;&auml;ll&auml;. Ole varovainen, jos otat pois p&auml;&auml;lt&auml;.';
 $lang['install_admin_tablesnotcreated'] = 'Asennus on valmis. Asennusprosessi on nyt lopussa - pyynn&ouml;st&auml;si tietokantataulut j&auml;tettiin luomatta. Asetustiedosto on kuitenkin alustettu ja kaikki asennuksen vaatimat testit on suoritettu onnistuneesti. Kiitokset, ja t&auml;ss&auml; on sinun ';
 $lang['info_create_dir_and_file'] = 'HTTP-prosessin omistaja ei voi luoda tiedostoja hakemistoon, jonka omistaa. T&auml;m&auml; tarkoittaa todenn&auml;k&ouml;isesti sit&auml; ett&auml; php:n &quot;safe mode&quot; on p&auml;&auml;ll&auml;. Monet CMS Made Simplen toiminnot eiv&auml;t toimi safe moden ollessa p&auml;&auml;ll&auml;. Jatkaminen ei ole mahdollista';
@@ -21,7 +109,7 @@ $lang['server_software'] = 'Palvelimen ohjelmisto';
 $lang['server_information'] = 'Palvelimen tiedot';
 $lang['session_save_path'] = 'Sessioiden tallennuspolku (session_save_path)';
 $lang['max_execution_time'] = 'Maksimisuoritusaika (maximum_execution_time)';
-$lang['gd_version'] = 'GD versio';
+$lang['gd_version'] = 'GD-versio';
 $lang['upload_max_filesize'] = 'Maksimikoko ladatuille tiedostoille';
 $lang['post_max_size'] = 'Maksimikoko POST-kutsuille';
 $lang['memory_limit'] = 'PHP:n muistiraja';
@@ -56,7 +144,7 @@ $lang['cantremove'] = 'Ei voi poistaa';
 $lang['changepermissions'] = 'Vaihda k&auml;ytt&ouml;oikeudet';
 $lang['changepermissionsconfirm'] = 'Varoitus \n\n T&auml;m&auml; toiminto yritt&auml;&auml; vaihtaa kaikkien modulien tiedostooikeuksia niin ett&auml; palvelimella on niihin kirjoitusoikeus. \n Haluatko varmasti jatkaa?';
 $lang['success'] = 'Onnistui';
-$lang['advanced'] = 'Advanced';
+$lang['advanced'] = 'Monipuolinen';
 $lang['back'] = 'Takaisin valikkoon';
 $lang['cancel'] = 'Peruuta';
 $lang['cantchmodfiles'] = 'Ei voitu vaihtaa joidenkin tiedostojen oikeuksia';
@@ -104,6 +192,9 @@ $lang['version'] = 'Versio';
 $lang['install_title'] = 'CMS Made Simple -asennus (kohta %s)';
 $lang['install_system'] = 'Asennusj&auml;rjestelm&auml;';
 $lang['install_thanks'] = 'Kiitoksia CMS Made Simplen asennuksesta';
+$lang['upgrade_title'] = 'CMS Made Simple p&auml;ivitys (askel %s)';
+$lang['upgrade_system'] = 'P&auml;ivitysj&auml;rjestelm&auml;';
+$lang['upgrade_thanks'] = 'Kiitos CMS Made Simplen p&auml;ivitt&auml;misest&auml; versioon';
 $lang['install_please_read'] = 'Ole hyv&auml; ja lue <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting">asennus (en)</a> -sivu CMS Made Simple Wikist&auml;.';
 $lang['install_checking'] = 'Tarkistetaan oikeuksia ja PHP-asetuksia';
 $lang['install_test'] = 'Testaa';
@@ -116,6 +207,7 @@ $lang['install_symbol'] = 'Symboli';
 $lang['install_definition'] = 'M&auml;&auml;ritelm&auml;';
 $lang['install_value_passed'] = 'Vaadittu testi hyv&auml;ksytty';
 $lang['install_value_failed'] = 'Vaadittu testi hyl&auml;tty';
+$lang['install_error_fragment'] = 'Tietoa asennuksen mahdollisista ongelmista';
 $lang['install_value_required'] = 'Asetus on alle minimiarvon';
 $lang['install_value_recommended'] = 'Asetus on yli vaaditun, mutta alle suositellun arvon.<br />tai jokin lis&auml;tieto <em>saattaa</em> olla vaadittu jotain toiminnallisuutta varten';
 $lang['install_value_exceed'] = 'Asetus on yli tai juuri suositellun arvon<br />tai jokin lis&auml;tieto <em>saattaa</em> olla vaadittu jotain toiminnallisuutta varten';
@@ -162,8 +254,13 @@ $lang['test_check_xml_failed'] = 'XML-tukea ei ole k&auml;&auml;nnetty PHP-asenn
 $lang['test_allow_url_fopen_failed'] = 'Kun url fopen ei ole sallittu, URL objecteja ei voida k&auml;sitell&auml; kuten tiedostoja.';
 $lang['test_remote_url'] = 'Tarkistetaan remote URL';
 $lang['test_remote_url_failed'] = 'Todenn&auml;k&ouml;isesti et voi avata tiedostoja et&auml;palvelimelta';
-$lang['use_fsockopen'] = '&quot;allow_url_fopen&quot; ei ole k&auml;ytett&auml;viss&auml;, ulosp&auml;in suuntautuvat yhteydet n&auml;ytt&auml;v&auml;n olevan sallittuja. Voit olla yhteydess&auml; palveluntarjoajaan toiminnon sallimisesta.';
-$lang['use_fsockopen_error'] = 'Ulosp&auml;in suuntautuvat HTTP-yhteydet eiv&auml;t n&auml;yt&auml; toimivan. T&auml;m&auml; est&auml;&auml; module managerin k&auml;yt&ouml;n ja mahdollisesti my&ouml;s joidenkin muiden toiminnallisuuksien.';
+$lang['connection_error'] = 'Ulosmenev&auml;t HTTP-yhteydet eiv&auml;t n&auml;yt&auml; toimivan! Onko ulosmenevien yhteyksien tiell&auml; esimerkiksi palomuuri? T&auml;m&auml; voi aiheuttaa sen, ett&auml; moduulien hallintaj&auml;rjestelm&auml; tai muut toiminnallisuudet eiv&auml;t toimi.';
+$lang['remote_connection_timeout'] = 'Yhteys vanhentui!';
+$lang['search_string_find'] = 'Yhteys ok!';
+$lang['connection_failed'] = 'Yhteys ep&auml;onnistui!';
+$lang['remote_response_ok'] = 'Et&auml;vastaus: ok!';
+$lang['remote_response_404'] = 'Et&auml;vastaus: ei l&ouml;ytynyt!';
+$lang['remote_response_error'] = 'Et&auml;vastaus: virhe!';
 $lang['test_check_file_upload'] = 'Tarkistetaan tiedostolatauksia';
 $lang['test_check_file_failed'] = 'Jos tiedostolataukset on estetty, et voi k&auml;ytt&auml;&auml; CMS Made Simple:n tiedostojen lataustoimintoja. Voit keskustella palveluntarjoajan kanssa toiminnon sallimisesta.';
 $lang['test_check_memory'] = 'Tarkistetaan PHP:n muistirajoitusta';
@@ -175,9 +272,9 @@ $lang['test_check_post_max_failed'] = 'Et voi todenn&auml;k&ouml;isesti ladata p
 $lang['test_check_upload_max'] = 'Tarkistetaan tiedostolatauksen maksimikoko';
 $lang['test_check_upload_max_failed'] = 'Et voi todenn&auml;k&ouml;isesti ladata suurempia tiedostoja CMS Made Simplen tiedostonhallintatoiminnallisuuksilla.';
 $lang['test_check_writable'] = 'Tarkistetaan onko %s kirjoitettavissa';
-$lang['test_check_upload_failed'] = 'Uploads-kansio ei ole kirjoitettavissa. Voit jatkaa asennusta, mutta et voi ladata tiedostoja palvelimelle hallintapaneelin kautta.';
-$lang['test_check_images_failed'] = 'Kuvat-kansio ei ole kirjoitettavissa. Voit jatkaa asennusta, mutta et voi ladata kuvia hallintapaneelin kautta.';
-$lang['test_check_modules_failed'] = 'Modules-kansio ei ole kirjoitettavissa. Voit jatkaa asennusta, mutta et voi asentaa moduuleita hallintapaneelin kautta.';
+$lang['test_check_upload_failed'] = 'Uploads-hakemisto ei ole kirjoitettavissa. Voit jatkaa asennusta, mutta et voi ladata tiedostoja palvelimelle hallintapaneelin kautta.';
+$lang['test_check_images_failed'] = 'Kuvat-hakemisto ei ole kirjoitettavissa. Voit jatkaa asennusta, mutta et voi ladata kuvia hallintapaneelin kautta.';
+$lang['test_check_modules_failed'] = 'Modules-hakemisto ei ole kirjoitettavissa. Voit jatkaa asennusta, mutta et voi asentaa moduuleita hallintapaneelin kautta.';
 $lang['test_check_file_get_contents'] = 'Tarkistetaan file_get_contents';
 $lang['test_check_file_get_contents_failed'] = 'Et voi k&auml;ytt&auml;&auml; toimintoja, jotka k&auml;ytt&auml;v&auml;t t&auml;t&auml; toimintoa';
 $lang['test_check_session_save_path'] = 'Tarkistetaan onko session.save_path kirjoitettavissa';
@@ -187,9 +284,9 @@ $lang['test_check_ini_set'] = 'Tarkistetaan ini_set';
 $lang['test_check_ini_set_failed'] = 'Vaikka mahdollisuus ylikirjoittaa php:n ini-tiedoston asetuksia ei ole pakollinen, jotkut lis&auml;osat k&auml;ytt&auml;v&auml;t ini_set funktiota aikakatkaisun pident&auml;miseen ja suurempien tiedostojen lataamiseen ym. Joidenkin lis&auml;osien kanssa voi olla ongelmia jos ini_set ei toimi. safe_mode-rajoitukset voivat my&ouml;s aiheuttaa ongelmia.';
 $lang['install_admin_header'] = 'K&auml;ytt&auml;j&auml;tiedot';
 $lang['install_admin_info'] = 'Valitse k&auml;ytt&auml;j&auml;tunnus, salasana ja email-osoite hallintaliittym&auml;&auml;n. Muista salasanasi, sill&auml; se on ainoa tapa, jolla p&auml;&auml;set kirjautumaan j&auml;rjestelm&auml;&auml;n asennuksen j&auml;lkeen.';
-$lang['install_admin_email'] = 'Email-osoite';
-$lang['install_admin_email_info'] = 'L&auml;het&auml; kirjautumistiedot emailina asennuksen j&auml;lkeen';
-$lang['install_admin_email_note'] = '<strong>Huomaa:</strong> T&auml;m&auml; toiminto k&auml;ytt&auml;&auml; php:n email-funktiota. Jos et saa viesti&auml; asennuksen j&auml;lkeen, on mahdollista ett&auml; palvelinta ei ole m&auml;&auml;ritelty oikein l&auml;hett&auml;m&auml;&auml;n s&auml;hk&ouml;posteja. Ota yhteytt&auml; palvelimen yll&auml;pit&auml;j&auml;&auml;n.';
+$lang['install_admin_email'] = 'S&auml;hk&ouml;postiosoite';
+$lang['install_admin_email_info'] = 'L&auml;het&auml; kirjautumistiedot s&auml;hk&ouml;postissa asennuksen j&auml;lkeen';
+$lang['install_admin_email_note'] = '<strong>Huomaa:</strong> T&auml;m&auml; toiminto k&auml;ytt&auml;&auml; PHP:n email-funktiota. Jos et saa viesti&auml; asennuksen j&auml;lkeen, on mahdollista ett&auml; palvelinta ei ole m&auml;&auml;ritelty oikein l&auml;hett&auml;m&auml;&auml;n s&auml;hk&ouml;posteja. Ota yhteytt&auml; palvelimen yll&auml;pit&auml;j&auml;&auml;n.';
 $lang['install_admin_sitename'] = 'Sivuston nimi. T&auml;t&auml; nime&auml; k&auml;ytet&auml;&auml;n eri paikoissa oletussivupohjissa ja sit&auml; voidaan k&auml;ytt&auml;&auml; kaikissa pohjissa {sitename} -tagilla';
 $lang['install_admin_db'] = 'Tietokantatiedot';
 $lang['install_admin_db_info'] = '<p>Varmista ett&auml; sinulla on valmis tietokanta ja tietokantak&auml;ytt&auml;j&auml; kaikilla oikeuksilla.</p>
@@ -233,7 +330,6 @@ $lang['install_admin_emailing'] = 'L&auml;hetet&auml;&auml;n hallintatunnukset e
 $lang['install_admin_congratulations'] = 'Onnittelut, CMS Made Simple on nyt asennettu - t&auml;ss&auml; on sinun';
 $lang['could_not_connect_db'] = 'Ei voitu luoda yhteytt&auml; tietokantaan. Tarkista ett&auml; k&auml;ytt&auml;j&auml;tunnus ja salasana ovat oikein ja k&auml;ytt&auml;j&auml;ll&auml; on oikeudet tietokantaan.';
 $lang['cannot_write_config'] = 'Virhe: Ei voitu kirjoittaa %s.';
-$lang['install_additional_modules'] = 'Asenna lis&auml;moduuleita';
 $lang['email_accountinfo_subject'] = 'CMS Made Simple hallintatunnukset';
 $lang['email_accountinfo_message'] = 'Kiitos CMS Made Simple -asennuksesta
 
@@ -242,6 +338,9 @@ K&auml;ytt&auml;j&auml;tunnus: %s
 Salasana: %s
 
 Kirjaudu hallintaan: %s';
-$lang['utma'] = '156861353.1959547193.1213865783.1215201910.1215340163.28';
-$lang['utmz'] = '156861353.1214056345.10.4.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/forum/forum.php|utmcmd=referral';
+$lang['utma'] = '156861353.572491444.1274267548.1274270099.1274275175.3';
+$lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1274270099.2.2.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/files/6';
+$lang['qca'] = 'P0-1477326709-1274267548700';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
