@@ -1,4 +1,10 @@
 <?php
+$lang['test_error_estrict'] = 'Tester error_reporting for &aring; sikre at E_STRICT ikke er aktivert';
+$lang['test_estrict_failed'] = 'E_STRICT er aktivert';
+$lang['info_estrict_failed'] = 'Noen biblioteker som CMS Made Simple benytter fungerer ikke godt med E_STRICT. Vennligst sl&aring; av denne f&oslash;r du fortsetter';
+$lang['test_error_edeprecated'] = 'Tester error_reporting for &aring; sikre at E_DEPRECATED ikke er aktivert';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED er aktivert';
+$lang['info_edeprecated_failed'] = 'Om E_DEPRECATED er aktivert i din feilrapportering s&aring; vil brukere se mange advarselsmeldinger som kan ha innvirkning p&aring; visningen og funksjonaliteten';
 $lang['invalidemail'] = 'E-postadressen som er oppgitt er ugyldig';
 $lang['empty_query'] = 'Tom sp&oslash;rring?? %s';
 $lang['no_db_driver'] = 'Ingen kompatible databasedrivere ble funnet';
@@ -231,7 +237,7 @@ $lang['test_could_not_create_table'] = 'Kunne ikke opprette en tabell. Bekreft a
 $lang['test_check_php'] = 'Tester om PHP versjon %s+';
 $lang['test_min_recommend'] = '(min %s, anbefalt %s eller st&oslash;rre)';
 $lang['test_min_recommend_plus'] = '(min. %s, anbefalt %s+)';
-$lang['test_requires_php_version'] = 'CMS Made Simple krever php versjon 4.3 eller st&oslash;rre (du har %s), men PHP %s eller st&oslash;rre er anbefalt for &aring; sikre maksimum kompatibilitet med tredjeparts tillegg';
+$lang['test_requires_php_version'] = 'CMS Made Simple krever php versjon 5.2.4 eller st&oslash;rre (du har %s), men PHP %s eller st&oslash;rre er anbefalt for &aring; sikre maksimum kompatibilitet med tredjeparts tillegg';
 $lang['test_check_md5_func'] = 'Ser etter md5 funksjon';
 $lang['test_check_safe_mode'] = 'Tester om safe_mode';
 $lang['test_check_safe_mode_failed'] = 'PHP safe mode kan for&aring;rsake noen problemer under opplasting av filer og med andre funksjoner. Alt avhenger av hvor streng din server safe mode innstilling er.';
@@ -332,8 +338,9 @@ brukernavn: %s
 passord: %s
 
 Logg inn i nettstedets administrasjon her: %s';
-$lang['utmz'] = '156861353.1245190196.1444.36.utmcsr=themes.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/download_themes.html';
-$lang['utma'] = '156861353.179052623084110100.1210423577.1245587444.1245590676.1462';
+$lang['utma'] = '156861353.4516254727077762000.1214829895.1269862427.1271013637.210';
+$lang['utmz'] = '156861353.1258366036.187.21.utmcsr=themes.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
+$lang['qca'] = '1214401694-66536492-18746566';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1245590676';
 ?>
\ No newline at end of file
