@@ -1,5 +1,11 @@
 <?php
-$lang['invalidemail'] = 'Het ingevoerde email adres is niet correct';
+$lang['test_error_estrict'] = 'Error_reporting testen om er zeker van te zijn dat E_STRICT is uitgeschakeld';
+$lang['test_estrict_failed'] = 'E_STRICT is ingeschakeld';
+$lang['info_estrict_failed'] = 'Bepaalde functionaliteiten die CMSMS gebruikt, werken niet goed met E_STRICT.  Schakel deze alstublieft uit voordat u verder gaat';
+$lang['test_error_edeprecated'] = 'Error_reporting testen om er zeker van te zijn dat E_DEPRECATED is uitgeschakeld';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED is ingeschakeld';
+$lang['info_edeprecated_failed'] = 'Als E_DEPRECATED is ingeschakeld by error_reporting zullen gebruikers veel waarschuwingsmeldingen krijgen te zien, wat effect heeft op de lay-out en werking van de website';
+$lang['invalidemail'] = 'Het ingevoerde e-mail adres is niet correct';
 $lang['empty_query'] = 'Lege query?? %s';
 $lang['no_db_driver'] = 'Geen bruikbare database drivers gevonden';
 $lang['test_check_output_buffering'] = 'Controleer output buffering';
@@ -29,11 +35,11 @@ $lang['updating_schema_version'] = 'Bezig met het upgraden van schema versie %s
 $lang['upgrade_config'] = 'Bezig met het bijwerken van config.php';
 $lang['upgrade_config_info'] = 'configuratie upgrade';
 $lang['upgrade_failed_again'] = 'Een of meer upgrades zijn mislukt. Verhelp het probleem en klik op de knop om opnieuw te controleren.';
-$lang['upgrade_cache_dirs'] = 'Opschonen van cache mappen';
-$lang['cannot_clean_cache_dirs'] = 'Kan cache mappen niet opschonen!';
+$lang['upgrade_cache_dirs'] = 'Legen van cache mappen';
+$lang['cannot_clean_cache_dirs'] = 'Kan cache mappen niet legen!';
 $lang['upgrade_schema'] = 'Bijwerken van schema';
 $lang['need_upgrade_schema'] = 'CMS heeft een update nodig.<br />U gebruikt nu schema versie %s en u moet deze bijwerken naar schema versie %s';
-$lang['schema_ok'] = 'De CMS database is nu bijgewerkt en gebruikt schema versie %s';
+$lang['schema_ok'] = 'De CMS database is bijgewerkt en gebruikt schema versie %s';
 $lang['noneed_upgrade_schema'] = 'De CMS database is bijgewerkt en gebruikt schema versie %s';
 $lang['upgrade_modules'] = 'Bezig met bijwerken van modules';
 $lang['noneed_upgrade_modules'] = 'De core modules zijn bijgewerkt';
@@ -233,7 +239,7 @@ $lang['test_could_not_create_table'] = 'Niet mogelijk tabel aan te maken. Contro
 $lang['test_check_php'] = 'Controleer voor PHP versie %s+';
 $lang['test_min_recommend'] = '(minimaal %s, aanbevolen %s of hoger)';
 $lang['test_min_recommend_plus'] = '(minimaal %s, aanbevolen %s+)';
-$lang['test_requires_php_version'] = 'CMS Made Simple heeft een php versie nodig van 4.3 of hoger (u heeft %s), maar PHP %s of hoger is aanbevolen voor de beste prestaties bij het gebruik van modules van derden';
+$lang['test_requires_php_version'] = 'CMS Made Simple heeft een php versie nodig van 5.2.4 of hoger (u heeft %s), maar PHP %s of hoger is aanbevolen voor de beste prestaties bij het gebruik van modules van derden';
 $lang['test_check_md5_func'] = 'Controleren op md5-funktie';
 $lang['test_check_safe_mode'] = 'Controle op safe mode';
 $lang['test_check_safe_mode_failed'] = 'PHP veilige modus kan voor problemen met het uploaden van bestanden en andere functies. Het hangt allemaal af van hoe streng je server veilige modus instellingen zijn.';
@@ -338,8 +344,9 @@ gebruikersnaam: %s
 wachtwoord: %s
 
 Log hier in op het beheerpaneel van de website: %s';
-$lang['utma'] = '156861353.799969050.1225024056.1247232408.1247232841.405';
-$lang['utmz'] = '156861353.1246952402.399.67.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,35251.msg166670.html';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.1269027775.1259416186.1271008961.1271013397.628';
+$lang['utmz'] = '156861353.1271013397.628.109.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,42884.0/topicseen.html';
+$lang['qca'] = 'P0-431297011-1259416186230';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353.1.10.1271013397';
 ?>
\ No newline at end of file
