@@ -1,4 +1,10 @@
 <?php
+$lang['test_error_estrict'] = 'Testar error_reporting f&ouml;r att kontrollera att E_STRICT &auml;r deaktiverat';
+$lang['test_estrict_failed'] = 'E_STRICT &auml;r aktiverat';
+$lang['info_estrict_failed'] = 'Vissa paket som CMSMS anv&auml;nder fungerar inte bra med E_STRICT. Var v&auml;nlig deaktivera detta innan du forts&auml;tter.';
+$lang['test_error_edeprecated'] = 'Testar error_reporting f&ouml;r att kontrollera att E_DEPRECATED &auml;r deaktiverat';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED &auml;r aktiverat';
+$lang['info_edeprecated_failed'] = 'Om E_DEPRECATED &auml;r aktiverat i din error reporting kommer anv&auml;ndare att se m&aring;nga varningsmeddelanden som kan p&aring;verka utseendet och funktionaliteten';
 $lang['invalidemail'] = 'Den angivna e-postadressen &auml;r ogiltig';
 $lang['empty_query'] = 'Empty query?? %s ';
 $lang['no_db_driver'] = 'Inga kompatibla databasdrivrutiner hittades';
@@ -332,8 +338,9 @@ anv&auml;ndarnamn: %s
 l&ouml;senord: %s
 
 Logga in p&aring; adminsidorna: %s';
+$lang['qca'] = 'P0-245748072-1251504180990';
+$lang['utmz'] = '156861353.1269352899.20.14.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
+$lang['utma'] = '156861353.2917280715391859000.1251504181.1269540149.1269891113.22';
 $lang['utmc'] = '156861353';
-$lang['utma'] = '156861353.415365204.1233508366.1239119741.1242658766.11';
-$lang['utmz'] = '156861353.1242658766.11.8.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
-$lang['utmb'] = '156861353.1.10.1242658766';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
