@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: CMSInstallPage2.class.php 239 2009-10-03 17:32:59Z calguy1000 $
+#$Id: CMSInstallPage2.class.php 255 2010-03-16 21:12:04Z calguy1000 $
 
 class CMSInstallerPage2 extends CMSInstallerPage
 {
@@ -85,6 +85,14 @@ class CMSInstallerPage2 extends CMSInstallerPage
 		}
 
 
+		$settings['required'][] =
+		  testIntegerMask(1,lang('test_error_estrict'), 'error_reporting',E_STRICT,lang('test_estrict_failed'),true,true,false);
+
+		if( defined('E_DEPRECATED') )
+		  {
+		$settings['required'][] =
+		  testIntegerMask(1,lang('test_error_edeprecated'), 'error_reporting',E_DEPRECATED,lang('test_edeprecated_failed'),true,true,false);
+		  }
 
 		/*
 		 * Recommended Settings
@@ -153,7 +161,7 @@ class CMSInstallerPage2 extends CMSInstallerPage
 				testDirWrite(0, lang('test_check_session_save_path'), $session_save_path,
 					lang('test_check_session_save_path_failed', $session_save_path), 1, $this->debug);
 		}
-		$settings['recommended'][] = testBoolean(0, 'session.use_cookies', 'session.use_cookies', lang('session.use_cookies'));
+		$settings['recommended'][] = testBoolean(0, 'session.use_cookies', 'session.use_cookies', lang('session_use_cookies'));
 
 		$settings['recommended'][] =
 			testBoolean(0, lang('test_check_xml_func'),
