@@ -27,6 +27,8 @@ if (isset($CMS_INSTALL_DROP_TABLES)) {
 
 	$sqlarray = $dbdict->DropIndexSQL("idx_template_id_modified_date");
 	$dbdict->ExecuteSQLArray($sqlarray);
+	$sqlarray = $dbdict->DropIndexSQL($db_prefix."idx_template_id_modified_date");
+	$dbdict->ExecuteSQLArray($sqlarray);
 
 	$sqlarray = $dbdict->DropTableSQL($db_prefix."additional_users");
 	$dbdict->ExecuteSQLArray($sqlarray);
@@ -119,7 +121,7 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_table', 'admin_bookmarks', $ado_ret);
 
-	$sqlarray = $dbdict->CreateIndexSQL('index_admin_bookmarks_by_user_id', $db_prefix."admin_bookmarks", 'user_id');
+	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_admin_bookmarks_by_user_id', $db_prefix."admin_bookmarks", 'user_id');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_index', 'admin_bookmarks', $ado_ret);
@@ -181,24 +183,25 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 		accesskey C(5),
 		last_modified_by I,
 		create_date DT,
-		modified_date DT
+		modified_date DT,
+                secure I1
 	";
 	$sqlarray = $dbdict->CreateTableSQL($db_prefix."content", $flds, $taboptarray);
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_table', 'content', $ado_ret);
 
-	$sqlarray = $dbdict->CreateIndexSQL('index_content_by_content_alias_active', $db_prefix."content", 'content_alias, active');
+	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_content_by_content_alias_active', $db_prefix."content", 'content_alias, active');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_index', 'content', $ado_ret);
 
-	$sqlarray = $dbdict->CreateIndexSQL('index_content_by_default_content', $db_prefix."content", 'default_content');
+	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_content_by_default_content', $db_prefix."content", 'default_content');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_index', 'content', $ado_ret);
 
-	$sqlarray = $dbdict->CreateIndexSQL('index_content_by_parent_id', $db_prefix."content", 'parent_id');
+	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_content_by_parent_id', $db_prefix."content", 'parent_id');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_index', 'content', $ado_ret);
@@ -221,7 +224,7 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_table', 'content_props', $ado_ret);
 
-	$sqlarray = $dbdict->CreateIndexSQL('index_content_props_by_content_id', $db_prefix."content_props", 'content_id');
+	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_content_props_by_content_id', $db_prefix."content_props", 'content_id');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_index', 'content', $ado_ret);
@@ -242,12 +245,12 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_table', 'crossref', $ado_ret);
 
-	$sqlarray = $dbdict->CreateIndexSQL('index_crossref_by_child_type_child_id', $db_prefix."crossref", 'child_type, child_id');
+	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_crossref_by_child_type_child_id', $db_prefix."crossref", 'child_type, child_id');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_index', 'content', $ado_ret);
 
-	$sqlarray = $dbdict->CreateIndexSQL('index_crossref_by_parent_type_parent_id', $db_prefix."crossref", 'parent_type, parent_id');
+	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_crossref_by_parent_type_parent_id', $db_prefix."crossref", 'parent_type, parent_id');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_index', 'content', $ado_ret);
@@ -267,7 +270,7 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_table', 'css', $ado_ret);
 
-	$sqlarray = $dbdict->CreateIndexSQL('index_css_by_css_name', $db_prefix."css", 'css_name');
+	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_css_by_css_name', $db_prefix."css", 'css_name');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_index', 'content', $ado_ret);
@@ -287,12 +290,12 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_table', 'css_assoc', $ado_ret);
 
-	$sqlarray = $dbdict->CreateIndexSQL('index_css_assoc_by_assoc_to_id', $db_prefix."css_assoc", 'assoc_to_id');
+	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_css_assoc_by_assoc_to_id', $db_prefix."css_assoc", 'assoc_to_id');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_index', 'content', $ado_ret);
 
-	$sqlarray = $dbdict->CreateIndexSQL('index_css_assoc_by_assoc_css_id', $db_prefix."css_assoc", 'assoc_css_id');
+	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_css_assoc_by_assoc_css_id', $db_prefix."css_assoc", 'assoc_css_id');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_index', 'content', $ado_ret);
@@ -324,12 +327,12 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_table', 'events', $ado_ret);
 	
-	$sqlarray = $dbdict->CreateIndexSQL('originator', $db_prefix."events", 'originator');
+	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'originator', $db_prefix."events", 'originator');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_index', 'content', $ado_ret);
     
-	$sqlarray = $dbdict->CreateIndexSQL('event_name', $db_prefix."events", 'event_name');
+	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'event_name', $db_prefix."events", 'event_name');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_index', 'content', $ado_ret);
@@ -348,7 +351,7 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_table', 'group_perms', $ado_ret);
 
-	$sqlarray = $dbdict->CreateIndexSQL('index_group_perms_by_group_id_permission_id', $db_prefix."group_perms", 'group_id, permission_id');
+	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_group_perms_by_group_id_permission_id', $db_prefix."group_perms", 'group_id, permission_id');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_index', 'content', $ado_ret);
@@ -382,7 +385,7 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_table', 'htmlblobs', $ado_ret);
 
-	$sqlarray = $dbdict->CreateIndexSQL('index_htmlblobs_by_htmlblob_name', $db_prefix."htmlblobs", 'htmlblob_name');
+	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_htmlblobs_by_htmlblob_name', $db_prefix."htmlblobs", 'htmlblob_name');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_index', 'content', $ado_ret);
@@ -413,7 +416,7 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_table', 'modules', $ado_ret);
 
-	$sqlarray = $dbdict->CreateIndexSQL('index_modules_by_module_name', $db_prefix."modules", 'module_name');
+	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_modules_by_module_name', $db_prefix."modules", 'module_name');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_index', 'content', $ado_ret);
@@ -446,7 +449,7 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_table', 'module_templates', $ado_ret);
 
-	$sqlarray = $dbdict->CreateIndexSQL('index_module_templates_by_module_name_template_name', $db_prefix."module_templates", 'module_name, template_name');
+	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_module_templates_by_module_name_template_name', $db_prefix."module_templates", 'module_name, template_name');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_index', 'content', $ado_ret);
@@ -496,7 +499,7 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_table', 'templates', $ado_ret);
 
-	$sqlarray = $dbdict->CreateIndexSQL('index_templates_by_template_name', $db_prefix."templates", 'template_name');
+	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_templates_by_template_name', $db_prefix."templates", 'template_name');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_index', 'content', $ado_ret);
@@ -527,7 +530,7 @@ if (isset($CMS_INSTALL_CREATE_TABLES)) {
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_table', 'userprefs', $ado_ret);
 
-	$sqlarray = $dbdict->CreateIndexSQL('index_userprefs_by_user_id', $db_prefix."userprefs", 'user_id');
+	$sqlarray = $dbdict->CreateIndexSQL($db_prefix.'index_userprefs_by_user_id', $db_prefix."userprefs", 'user_id');
 	$return = $dbdict->ExecuteSQLArray($sqlarray);
 	$ado_ret = ($return == 2) ? lang('done') : lang('failed');
 	echo lang('install_creating_index', 'content', $ado_ret);
