@@ -84,7 +84,7 @@ if(isset($_GET['advanceduser']))
 
 
 
-$installer =& new CMSInstaller($max_pages, $debug);
+$installer = new CMSInstaller($max_pages, $debug);
 
 
 
@@ -118,7 +118,7 @@ if(! isset($_GET['sessiontest']) && (! isset($_POST['page'])) )
 	}
 
 	require_once $pathSmartClass;
-	$smarty =& new Smarty();
+	$smarty = new Smarty();
 	$smarty->compile_dir = TMP_TEMPLATES_C_LOCATION;
 	$smarty->cache_dir = TMP_CACHE_LOCATION;
 	$smarty->template_dir = cms_join_path(CMS_INSTALL_BASE, 'templates');
