@@ -17,7 +17,16 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: class.content.inc.php 5858 2009-08-08 22:11:52Z calguy1000 $
+#$Id: class.content.inc.php 6524 2010-07-29 11:04:34Z wishy $
+
+/**
+ * @package CMS
+ */
+
+/**
+ * @ignore
+ */
+define('CMS_CONTENT_HIDDEN_NAME','--------');
 
 /**
  * Generic content class.
@@ -29,7 +38,6 @@
  * @since		0.8
  * @package		CMS
  */
-define('CMS_CONTENT_HIDDEN_NAME','--------');
 class ContentBase
 {
     /**
@@ -141,6 +149,11 @@ class ContentBase
      */
     var $mCachable;
 
+    /**
+     * Secure?
+     */
+    var $mSecure;
+
     /**
      * Does this content have a preview function?
      */
@@ -180,11 +193,14 @@ class ContentBase
     
     var $mAdditionalEditors;
 	
+    /*
+     * state or meta information
+     */
     var $mReadyForEdit;
-
     var $_attributes;
     var $_prop_defaults;
     var $_add_mode;
+    var $_error;
 
     /************************************************************************/
     /* Constructor related													*/
@@ -230,6 +246,7 @@ class ContentBase
 	$this->mDefaultContent = false ;
 	$this->mShowInMenu     = false ;
 	$this->mCachable       = true;
+	$this->mSecure         = 0;
 	$this->mMenuText       = "" ;
 	$this->mCreationDate   = "" ;
 	$this->mModifiedDate   = "" ;
@@ -251,7 +268,8 @@ class ContentBase
       $this->AddBaseProperty('parent',3,1);
       $this->AddBaseProperty('active',5);
       $this->AddBaseProperty('showinmenu',5);
-      $this->AddBaseProperty('cachable',6);
+      $this->AddBaseProperty('secure',6);
+      $this->AddBaseProperty('cachable',7);
       $this->AddBaseProperty('alias',10);
       $this->AddBaseProperty('titleattribute',55);
       $this->AddBaseProperty('accesskey',56);
@@ -262,8 +280,8 @@ class ContentBase
       $this->AddContentProperty('image',50);
       $this->AddContentProperty('thumbnail',50);
       $this->AddContentProperty('extra1',80);
-      $this->AddContentProperty('extra2',80);
-      $this->AddContentProperty('extra3',80);
+      $this->AddContentProperty('extra2',81);
+      $this->AddContentProperty('extra3',82);
     }
 
     
@@ -493,12 +511,14 @@ class ContentBase
 	return $this->mIdHierarchy;
     }
 
+
     function SetIdHierarchy($idhierarchy)
     {
 	$this->DoReadyForEdit();
 	$this->mIdHierarchy = $idhierarchy;
     }
 
+
     /**
      * Returns the Hierarchy
      */
@@ -507,12 +527,14 @@ class ContentBase
 	return $this->mHierarchyPath;
     }
 
+
     function SetHierarchyPath($hierarchypath)
     {
 	$this->DoReadyForEdit();
 	$this->mHierarchyPath = $hierarchypath;
     }
 
+
     /**
      * Returns the Active state
      */
@@ -521,12 +543,14 @@ class ContentBase
 	return $this->mActive;
     }
 
+
     function SetActive($active)
     {
 	$this->DoReadyForEdit();
 	$this->mActive = $active;
     }
 
+
     /**
      * Returns whether it should show in the menu
      */
@@ -535,12 +559,14 @@ class ContentBase
 	return $this->mShowInMenu;
     }
 
+
     function SetShowInMenu($showinmenu)
     {
         $this->DoReadyForEdit();
 	$this->mShowInMenu = $showinmenu;
     }
 
+
     /**
      * Returns if the page is the default
      */
@@ -549,22 +575,38 @@ class ContentBase
 	return $this->mDefaultContent;
     }
 
+
     function SetDefaultContent($defaultcontent)
     {
 	$this->DoReadyForEdit();
 	$this->mDefaultContent = $defaultcontent;
     }
 
+
     function Cachable()
     {
 	return $this->mCachable;
     }
 
+
     function SetCachable($cachable)
     {
 	$this->DoReadyForEdit();
 	$this->mCachable = $cachable;
     }
+
+
+    function Secure()
+    {
+      return $this->mSecure;
+    }
+
+
+    function SetSecure($secure)
+    {
+	$this->DoReadyForEdit();
+	$this->mSecure = $secure;
+    }
 	
 	function Markup()
 	{
@@ -616,11 +658,11 @@ class ContentBase
 			
 			$tolower = true;
 			$alias = munge_string_to_url($alias, $tolower);
-			if( empty($alias) )
-			  {
-			    // calguy: quick hack so that the alias is never empty...
-			    $alias = 'alias';
-			  }
+// 			if( empty($alias) )
+// 			  {
+// 			    // calguy: quick hack so that the alias is never empty...
+// 			    $alias = 'alias';
+// 			  }
 			// Make sure auto-generated new alias is not already in use on a different page, if it does, add "-2" to the alias
 			$contentops =& $gCms->GetContentOperations();
 			$error = $contentops->CheckAliasError($alias);
@@ -820,6 +862,7 @@ class ContentBase
 				$this->mDefaultContent             = ($row->fields["default_content"] == 1 ? true : false);
 				$this->mShowInMenu                 = ($row->fields["show_in_menu"] == 1    ? true : false);
 				$this->mCachable                   = ($row->fields["cachable"] == 1        ? true : false);
+				$this->mSecure                     = $row->fields['secure'];
 				$this->mLastModifiedBy             = $row->fields["last_modified_by"];
 				$this->mCreationDate               = $row->fields["create_date"];
 				$this->mModifiedDate               = $row->fields["modified_date"];
@@ -921,6 +964,8 @@ class ContentBase
 		$this->mActive                     = ($data["active"] == 1          ? true : false);
 		$this->mShowInMenu                 = ($data["show_in_menu"] == 1    ? true : false);
 		$this->mCachable                   = ($data["cachable"] == 1        ? true : false);
+		if( isset($data['secure']) )
+		  $this->mSecure                   = $data["secure"];
 		$this->mLastModifiedBy             = $data["last_modified_by"];
 		$this->mCreationDate               = $data["create_date"];
 		$this->mModifiedDate               = $data["modified_date"];
@@ -1050,7 +1095,7 @@ class ContentBase
 
 		$this->mModifiedDate = trim($db->DBTimeStamp(time()), "'");
 
-		$query = "UPDATE ".cms_db_prefix()."content SET content_name = ?, owner_id = ?, type = ?, template_id = ?, parent_id = ?, active = ?, default_content = ?, show_in_menu = ?, cachable = ?, menu_text = ?, content_alias = ?, metadata = ?, titleattribute = ?, accesskey = ?, tabindex = ?, modified_date = ?, item_order = ?, markup = ?, last_modified_by = ? WHERE content_id = ?";
+		$query = "UPDATE ".cms_db_prefix()."content SET content_name = ?, owner_id = ?, type = ?, template_id = ?, parent_id = ?, active = ?, default_content = ?, show_in_menu = ?, cachable = ?, secure = ?, menu_text = ?, content_alias = ?, metadata = ?, titleattribute = ?, accesskey = ?, tabindex = ?, modified_date = ?, item_order = ?, markup = ?, last_modified_by = ? WHERE content_id = ?";
 		$dbresult = $db->Execute($query, array(
 			$this->mName,
 			$this->mOwner,
@@ -1061,6 +1106,7 @@ class ContentBase
 			($this->mDefaultContent == true ? 1 : 0),
 			($this->mShowInMenu == true     ? 1 : 0),
 			($this->mCachable == true       ? 1 : 0),
+			$this->mSecure,
 			$this->mMenuText,
 			$this->mAlias,
 			$this->mMetadata,
@@ -1160,7 +1206,7 @@ class ContentBase
 
 		$this->mModifiedDate = $this->mCreationDate = trim($db->DBTimeStamp(time()), "'");
 
-		$query = "INSERT INTO ".$config["db_prefix"]."content (content_id, content_name, content_alias, type, owner_id, parent_id, template_id, item_order, hierarchy, id_hierarchy, active, default_content, show_in_menu, cachable, menu_text, markup, metadata, titleattribute, accesskey, tabindex, last_modified_by, create_date, modified_date) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
+		$query = "INSERT INTO ".$config["db_prefix"]."content (content_id, content_name, content_alias, type, owner_id, parent_id, template_id, item_order, hierarchy, id_hierarchy, active, default_content, show_in_menu, cachable, secure, menu_text, markup, metadata, titleattribute, accesskey, tabindex, last_modified_by, create_date, modified_date) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)";
 
 		$dbresult = $db->Execute($query, array(
 			$newid,
@@ -1177,6 +1223,7 @@ class ContentBase
 			($this->mDefaultContent == true ? 1 : 0),
 			($this->mShowInMenu == true     ? 1 : 0),
 			($this->mCachable == true       ? 1 : 0),
+			$this->mSecure,
 			$this->mMenuText,
 			$this->mMarkup,
 			$this->mMetadata,
@@ -1414,6 +1461,10 @@ class ContentBase
       if (isset($params['active']))
 	{
 	  $this->mActive = $params['active'];
+	  if( $this->DefaultContent() )
+	    {
+	      $this->mActive = 1;
+	    }
 	}
       
       // show in menu
@@ -1423,21 +1474,11 @@ class ContentBase
 	}
 
       // alias
+      $tmp = '';
       if (isset($params['alias']))
 	{
 	  $tmp = trim($params['alias']);
-	  if( empty($tmp) )
-	    {
-	      $this->SetAlias($tmp);
-	    }
-	  else
-	    {
-	      $this->SetAlias($tmp, $this->DoAutoAlias());
-	    }
-	}
-      else if($this->RequiresAlias() && $this->DoAutoAlias())
-	{
-	  $this->SetAlias('');
+	  $this->SetAlias($tmp);
 	}
 
       // target
@@ -1479,6 +1520,16 @@ class ContentBase
 	  $this->_handleRemovedBaseProperty('cachable','mCachable');
 	}
 
+      // secure
+      if (isset($params['secure']))
+	{
+	  $this->mSecure = $params['secure'];
+	}
+      else
+	{
+	  $this->_handleRemovedBaseProperty('secure','mSecure');
+	}
+
       // owner
       if (isset($params["ownerid"]))
 	{
@@ -1510,9 +1561,22 @@ class ContentBase
 		$url = "";
 		$alias = ($this->mAlias != ''?$this->mAlias:$this->mId);
 
+		$base_url = $config['root_url'];
+		if( $this->Secure() )
+		  {
+		    if( isset($config['ssl_url']) )
+		      {
+			$base_url = $config['ssl_url'];
+		      }
+		    else
+		      {
+			$base_url = str_replace('http://','https://',$base_url);
+		      }
+		  }
+
 		/* use root_url for default content */
 		if($this->mDefaultContent) {
-			$url =  $config['root_url']. '/';
+			$url =  $base_url . '/';
 			return $url;
 		}
 
@@ -1520,11 +1584,11 @@ class ContentBase
 		{
 			if ($config['use_hierarchy'] == true)
 			{
-				$url = $config['root_url']. '/' . $this->HierarchyPath() . (isset($config['page_extension'])?$config['page_extension']:'.html');
+				$url = $base_url. '/' . $this->HierarchyPath() . (isset($config['page_extension'])?$config['page_extension']:'.html');
 			}
 			else
 			{
-				$url = $config['root_url']. '/' . $alias . (isset($config['page_extension'])?$config['page_extension']:'.html');
+				$url = $base_url . '/' . $alias . (isset($config['page_extension'])?$config['page_extension']:'.html');
 			}
 		}
 		else
@@ -1533,16 +1597,16 @@ class ContentBase
 			{
 				if ($config['use_hierarchy'] == true)
 				{
-					$url = $config['root_url'] . '/index.php/' . $this->HierarchyPath() . (isset($config['page_extension'])?$config['page_extension']:'.html');
+					$url = $base_url . '/index.php/' . $this->HierarchyPath() . (isset($config['page_extension'])?$config['page_extension']:'.html');
 				}
 				else
 				{
-					$url = $config['root_url'] . '/index.php/' . $alias . (isset($config['page_extension'])?$config['page_extension']:'.html');
+					$url = $base_url . '/index.php/' . $alias . (isset($config['page_extension'])?$config['page_extension']:'.html');
 				}
 			}
 			else
 			{
-				$url = $config['root_url'] . '/index.php?' . $config['query_var'] . '=' . $alias;
+				$url = $base_url . '/index.php?' . $config['query_var'] . '=' . $alias;
 			}
 		}
 		return $url;
@@ -1734,15 +1798,16 @@ class ContentBase
 	/* private */
 	function _handleRemovedBaseProperty($name,$member)
 	{
-	  if( !in_array($name,$this->_attributes) )
-	    {
-	      if( isset($this->_prop_defaults[$name]) )
+		if( !is_array($this->_attributes) ) return FALSE;
+		if( !in_array($name,$this->_attributes) )
 		{
-		  $this->$member = $this->_prop_defaults[$name];
-		  return TRUE;
+			if( isset($this->_prop_defaults[$name]) )
+			{
+				$this->$member = $this->_prop_defaults[$name];
+				return TRUE;
+			}
 		}
-	    }
-	  return FALSE;
+		return FALSE;
 	}
 
 	/* private */
@@ -1800,6 +1865,25 @@ class ContentBase
 	  $this->_attributes[] = array($name,$priority,$is_required);
 	}
 
+
+	/* private */
+	/*
+	 * Given a string, see if it's a known property name.
+	 */
+	function is_known_property($str)
+	{
+	  $tmp = array();
+	  foreach( $this->_attributes as $one )
+	    {
+	      $tmp[] = $one[0];
+	    }
+	  
+// 	  $props = $this->Properties();
+// 	  $tmp = array_merge(array_keys($props->mPropertyTypes),$tmp);
+// 	  $tmp = array_unique($tmp);
+	  return in_array($str,$tmp);
+	}
+
 	/* private */
 	/*
 	 * Given the list of registered properties, cross reference with our
@@ -1927,7 +2011,7 @@ class ContentBase
 	    case 'parent':
 		{
 		  $contentops =& $gCms->GetContentOperations();
-		  $tmp = $contentops->CreateHierarchyDropdown($this->mId, $this->mParentId, 'parent_id', 0, 1);
+		  $tmp = $contentops->CreateHierarchyDropdown($this->mId, $this->mParentId, 'parent_id', 0, 1, 0, 1);
 		  if( empty($tmp) && !check_permission(get_userid(),'Manage All Content') )
 		    return array('','<input type="hidden" name="parent_id" value="'.$this->mParentId.'" />');
 		  if( !empty($tmp) ) return array(lang('parent').':',$tmp);
@@ -1935,7 +2019,10 @@ class ContentBase
 	      break;
 
 	    case 'active':
-	      return array(lang('active').':','<input type="hidden" name="active" value="0"/><input class="pagecheckbox" type="checkbox" name="active" value="1"'.($this->mActive?' checked="checked"':'').' />');
+	      if( !$this->DefaultContent() )
+		{
+		  return array(lang('active').':','<input type="hidden" name="active" value="0"/><input class="pagecheckbox" type="checkbox" name="active" value="1"'.($this->mActive?' checked="checked"':'').' />');
+		}
 	      break;
 	      
 	    case 'showinmenu':
@@ -1958,6 +2045,19 @@ class ContentBase
 	      return array(lang('pagealias').':','<input type="text" name="alias" value="'.$this->mAlias.'" />');
 	      break;
 	      
+	    case 'secure':
+	      {
+		$opt = '';
+		if( $this->mSecure )
+		  {
+		    $opt = ' checked="checked"';
+		  }
+		$str  = '<input type="hidden" name="secure" value="0"/>';
+                $str .= '<input type="checkbox" name="secure" value="1"'.$opt.'/>';
+		return array(lang('secure_page').':',$str);
+	      }
+	      break;
+
 	    case 'image':
 	      {
 		$dir = $config['image_uploads_path'];
@@ -2039,6 +2139,15 @@ class ContentBase
 	    }
 	}
 
+	protected function SetError($str)
+	{
+	  $this->_error = $str;
+	}
+
+	public function GetError()
+	{
+	  return $this->_error;
+	}
 }
 
 /**
@@ -2082,7 +2191,7 @@ class ContentProperties
 	{
 		#debug_buffer($this->mPropertyNames);
 		if (!isset($this->mPropertyNames))
-		$this->mPropertyNames = array();
+		  $this->mPropertyNames = array();
 		return in_array($name, $this->mPropertyNames);
 	}
 
@@ -2127,7 +2236,6 @@ class ContentProperties
 
 	function Load($content_id)
 	{
-		debug_buffer('load properties called');
 		if (count($this->mPropertyNames) > 0)
 		{
 			global $gCms, $sql_queries, $debug_errors;
