@@ -1,35 +1,51 @@
-<?php
-
-# CMS - CMS Made Simple
-# (c)2004 by Ted Kulp (tedkulp@users.sf.net)
-# This project's homepage is: http://cmsmadesimple.org
+<?php // -*- mode:php; tab-width:4; indent-tabs-mode:t; c-basic-offset:4; -*-
+#CMS - CMS Made Simple
+#(c)2004-2010 by Ted Kulp (ted@cmsmadesimple.org)
+#This project's homepage is: http://cmsmadesimple.org
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+#This program is free software; you can redistribute it and/or modify
+#it under the terms of the GNU General Public License as published by
+#the Free Software Foundation; either version 2 of the License, or
+#(at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
-# BUT withOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#This program is distributed in the hope that it will be useful,
+#but WITHOUT ANY WARRANTY; without even the implied warranty of
+#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#GNU General Public License for more details.
+#You should have received a copy of the GNU General Public License
+#along with this program; if not, write to the Free Software
+#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 #$Id$
 
 /**
- * Class for static methods related to content
+ * Content related functions.
  *
- * @since		0.8
- * @package		CMS
+ * @package CMS
+ * @license GPL
  */
 
+/**
+ * Include the content class definition
+ */
 require_once(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'class.content.inc.php');
 
+/**
+ * Class for static methods related to content
+ *
+ * @since 0.8
+ * @package CMS
+ * @version $Revision$
+ * @license GPL
+ */
 class ContentOperations
 {
+	/**
+	 * Loads a content type into the system by it's name.
+	 *
+	 * @param string $type The content type to load
+	 * @return boolean Returns true if the content type was found and loaded
+	 */
 	function LoadContentType($type)
 	{
 		$type = strtolower($type);
@@ -50,6 +66,30 @@ class ContentOperations
 		return false;
 	}
 
+	/**
+	 * Given an array of content_type and seralized_content, reconstructs a 
+	 * content object.  It will handled loading the content type if it hasn't
+	 * already been loaded.
+	 *
+	 * @return mixed The unserialized content object
+	 */
+	function &LoadContentFromSerializedData(&$data)
+	{
+	  if( !isset($data['content_type']) && !isset($data['serialized_content']) ) return FALSE;
+
+	  $contenttype = 'content';
+	  if( isset($data['content_type']) ) $contenttype = $data['content_type'];
+
+	  $contentobj =& ContentOperations::CreateNewContent($contenttype);
+	  $contentobj = unserialize($data['serialized_content']);
+	  return $contentobj;
+	}
+
+	/**
+	 * Creates a new, empty content object of the given type.
+	 *
+	 * @return mixed The new content object
+	 */
 	function &CreateNewContent($type)
 	{
 		$type = strtolower($type);
@@ -58,14 +98,18 @@ class ContentOperations
 		
 		if (ContentOperations::LoadContentType($type))
 		{
-			$result =& new $type;
+			$result = new $type;
 		}
 		
 		return $result;
 	}
 	
     /**
-     * Determine proper type of object, load it and return it
+     * Given a content id, load and return the loaded content object.
+     *
+     * @param integer $id The id of the content object to load
+     * @param boolean $loadprops Also load the properties of that content object. Defaults to false.
+     * @return mixed The loaded content object. If nothing is found, returns FALSE.
      */
 	function &LoadContentFromId($id,$loadprops=false)
 	{
@@ -100,6 +144,13 @@ class ContentOperations
 		}
 	}
 
+    /**
+     * Given a content alias, load and return the loaded content object.
+     *
+     * @param integer $id The id of the content object to load
+     * @param boolean $only_active If true, only return the object if it's active flag is true. Defaults to false.
+     * @return mixed The loaded content object. If nothing is found, returns NULL.
+     */
 	function &LoadContentFromAlias($alias, $only_active = false)
 	{
 		global $gCms;
@@ -138,24 +189,25 @@ class ContentOperations
 			}
 			else
 			{
-				return FALSE;
+			  $tmp = NULL; return $tmp;
 			}
 		}
 		else
 		{
-			return FALSE;
+		  $tmp = NULL; return $tmp;
 		}
 	}
 
      /**
-     * Load the content of the object from a list of ID
-     * Private method.
-     * @param $ids	array of element ids
-     * @param $loadProperties	whether to load or not the properties
-     *
-     * @returns array of content objects (empty if not found)
-     */
-	/*private*/ function &LoadMultipleFromId($ids, $loadProperties = false)
+      * Load the content of the object from a list of ids
+      * Private method.
+      *
+      * @access private
+      * @param array $ids List of of element ids to load
+      * @param boolean $loadProperties Whether or not to load the properties
+      * @return array Array of content objects (empty if not found)
+      */
+	function &LoadMultipleFromId($ids, $loadProperties = false)
 	{
 		global $gCms, $sql_queries, $debug_errors;
 		$cpt = count($ids);
@@ -178,7 +230,7 @@ class ContentOperations
 		$id_list .= ')';
 		if ($id_list=='()') 
 		{
-			return $contents;
+		  return $contents;
 		}
 		$result = false;
 		$query  = "SELECT * FROM ".cms_db_prefix()."content WHERE content_id IN $id_list";
@@ -242,17 +294,15 @@ class ContentOperations
 	}
 	
     /**
-     * Load the content of the object from a list of aliases
-     * Private method.
-     * @param $ids	array of element ids
-     * Private method
-     *
-     * @param $alis				the alias of the element
-     * @param $loadProperties	whether to load or not the properties
-     *
-     * @returns array of content objects (empty if not found)
+    * Load the content of the object from a list of content aliases.
+    * Private method.
+    *
+    * @access private
+    * @param array $ids List of of content aliases to load
+    * @param boolean $loadProperties Whether or not to load the properties
+    * @return array Array of content objects (empty if not found)
      */
-	/*private*/function &LoadMultipleFromAlias($ids, $loadProperties = false)
+	function &LoadMultipleFromAlias($ids, $loadProperties = false)
 	{
 		global $gCms, $sql_queries, $debug_errors;
 		$contents=array();
@@ -329,22 +379,30 @@ class ContentOperations
 	}
 
 
-    /**
-     * Display content
-     */
+	/**
+	 * Displays the content of the given content object
+	 *
+	 * @param mixed $content Content object
+	 * @return void
+	 */
 	function DisplayContent($content)
 	{
 		//This should be straight forward, since the content will pretty much determine how it is displayed
 		$content->Show();
 	}
 
-    /**
-     * Determine if content should be loaded from cache
-     */
+	/**
+	 * @ignore
+	 */
     function IsCached($id)
     {
     }
 
+	/**
+	 * Returns the id of the content marked as default.
+	 *
+	 * @return integer The id of the default content page
+	 */
 	function & GetDefaultContent()
 	{
 	  global $gCms;
@@ -377,11 +435,13 @@ class ContentOperations
 		return $result;
 	}
 
-    /**
+	/**
      * Returns a hash of valid content types (classes that extend ContentBase)
      * The key is the name of the class that would be saved into the dabase.  The
      * value would be the text returned by the type's FriendlyName() method.
-     */
+	 *
+	 * @return array Lost of content types registerd in the system.
+	 */
 	function &ListContentTypes()
 	{
 		global $gCms;
@@ -410,6 +470,9 @@ class ContentOperations
 
     /**
      * Updates the hierarchy position of one item
+	 *
+	 * @param integer $contentid The content id to update
+	 * @return void
      */
 	function SetHierarchyPosition($contentid)
 	{
@@ -462,9 +525,11 @@ class ContentOperations
 		$db->Execute($query, array($current_hierarchy_position, $current_id_hierarchy_position, $current_hierarchy_path, implode(',', $prop_name_array), $contentid));
 	}
 
-    /**
-     * Updates the hierarchy position of all items
-     */
+	/**
+	 * Updates the hierarchy position of all items
+	 *
+	 * @return void
+	 */
 	function SetAllHierarchyPositions()
 	{
 		global $gCms;
@@ -482,7 +547,16 @@ class ContentOperations
 		if ($dbresult) $dbresult->Close();
 	}
 	
-	function &GetAllContentAsHierarchy($loadprops, $onlyexpanded=null)
+	/**
+	 * Loads a set of content objects into the cached tree.
+	 *
+	 * @param boolean $loadprops If true, load the properties of those content objects
+	 * @param boolean $onlyexpanded Not implemented
+	 * @param boolean $loadcontent If false, only create the nodes in the tree, 
+	 *                             don't load the content objects
+	 * @return mixed The cached tree of content
+	 */
+	function &GetAllContentAsHierarchy($loadprops, $onlyexpanded=null, $loadcontent = false)
 	{
 		debug_buffer('', 'starting tree');
 
@@ -544,9 +618,9 @@ class ContentOperations
 				}
 			}
 
-			$tree = &new Tree();
+			$tree = new Tree();
 			debug_buffer('', 'Start Loading Children into Tree');
-			$tree = &Tree::createFromList($nodes, '.');
+			$tree = Tree::createFromList($nodes, '.');
 			debug_buffer('', 'End Loading Children into Tree');
 		}
 
@@ -558,46 +632,113 @@ class ContentOperations
 			fclose($handle);
 		}
 
-		ContentOperations::LoadChildrenIntoTree(-1, $tree);
+		if( $loadcontent )
+		  {
+		    ContentOperations::LoadChildrenIntoTree(-1, $tree, false, true);
+		  }
 
 		debug_buffer('', 'ending tree');
 
 		return $tree;
 	}
 	
-	function LoadChildrenIntoTree($id, &$tree, $loadprops = false)
+	/**
+	 * Loads additional, active children into a given tree object
+	 *
+	 * @param integer $id The parent of the content objects to load into the tree
+	 * @param mixed $tree The passed tree object (reference)
+	 * @param boolean $loadprops If true, load the properties of all loaded content objects
+	 * @param boolean $all If true, load all content objects, even inactive ones.
+	 * @return void
+	 * @author Ted Kulp
+	 */
+	function LoadChildrenIntoTree($id, &$tree, $loadprops = false, $all = false)
 	{	
 		global $gCms;
 		$db = &$gCms->GetDb();
 
-		$query = "SELECT * FROM ".cms_db_prefix()."content WHERE parent_id = ? ORDER BY hierarchy";
-		$dbresult =& $db->Execute($query, array($id));
+		// get the content rows
+		$query = "SELECT * FROM ".cms_db_prefix()."content WHERE parent_id = ? AND active = 1 ORDER BY hierarchy";
+		if( $all )
+		  $query = "SELECT * FROM ".cms_db_prefix()."content WHERE parent_id = ? ORDER BY hierarchy";
+		$contentrows =& $db->GetArray($query, array($id));
+		$contentprops = '';
 
-		if ($dbresult && $dbresult->RecordCount() > 0)
-		{
-			while ($row = $dbresult->FetchRow())
-			{
-				#Make sure the type exists.  If so, instantiate and load
-				if (in_array($row['type'], array_keys(ContentOperations::ListContentTypes())))
-				{
-					$contentobj =& ContentOperations::CreateNewContent($row['type']);
-					if ($contentobj)
-					{
-						$contentobj->LoadFromData($row, $loadprops);
-						$contentcache =& $tree->content;
-						$id = $row['content_id'];
-						$contentcache[$id] =& $contentobj;
-					}
-				}
-			}
-		}
+		// get the content ids from the returned data
+		if( $loadprops )
+		  {
+		    $child_ids = array();
+		    for( $i = 0; $i < count($contentrows); $i++ )
+		      {
+			$child_ids[] = $contentrows[$i]['content_id'];
+		      }
+		    
+		    // get all the properties for the child_ids
+		    $query = 'SELECT * FROM '.cms_db_prefix().'content_props WHERE content_id IN ('.implode(',',$child_ids).') ORDER BY content_id';
+		    $tmp =& $db->GetArray($query);
+
+		    // re-organize the tmp data into a hash of arrays of properties for each content id.
+		    if( $tmp )
+		      {
+			$contentprops = array();
+			for( $i = 0; $i < count($contentrows); $i++ )
+			  {
+			    $content_id = $contentrows[$i]['content_id'];
+			    $t2 = array();
+			    for( $j = 0; $j < count($tmp); $j++ )
+			      {
+				if( $tmp[$j]['content_id'] == $content_id )
+				  {
+				    $t2[] = $tmp[$j];
+				  }
+			      }
+			    $contentprops[$content_id] = $t2;
+			  }
+		      }
+		  }
 		
-		if ($dbresult) $dbresult->Close();
+		// build the content objects
+		for( $i = 0; $i < count($contentrows); $i++ )
+		  {
+		    $row =& $contentrows[$i];
+		    $id = $row['content_id'];
+
+		    if (!in_array($row['type'], array_keys(ContentOperations::ListContentTypes()))) continue;
+		    $contentobj =& ContentOperations::CreateNewContent($row['type']);
+		    if ($contentobj)
+		      {
+			$contentobj->LoadFromData($row, false);
+			if( $loadprops && $contentprops && isset($contentprops[$id]) )
+			  {
+			    // load the properties from local cache.
+			    $props =& $contentprops[$id];
+			    $obj =& $contentobj->mProperties;
+			    $obj->mPropertyNames = array();
+			    $obj->mPropertyTypes = array();
+			    $obj->mPropertyValues = array();
+			    foreach( $props as $oneprop )
+			      {
+				$obj->mPropertyNames[] = $oneprop['prop_name'];
+				$obj->mPropertyTypes[$oneprop['prop_name']] = $oneprop['type'];
+				$obj->mPropertyValues[$oneprop['prop_name']] = $oneprop['content'];
+			      }
+			    $contentobj->mPropertiesLoaded = true;
+			  }
+
+			// cache the content objects
+			$contentcache =& $tree->content;
+			$contentcache[$id] =& $contentobj;
+		      }
+		  }
 	}
 
 	/**
-	*  Sets the default content as id
-	*/   
+	 * Sets the default content to the given id
+	 *
+	 * @param integer $id The id to set as default
+	 * @return void
+	 * @author Ted Kulp
+	 */
 	function SetDefaultContent($id) {
 		global $gCms;
 		$db = &$gCms->GetDb();
@@ -618,6 +759,12 @@ class ContentOperations
 		$one->Save();
 	}
 
+	/**
+	 * Returns an array of all content objects in the system, active or not.
+	 *
+	 * @param boolean $loadprops Not implemented
+	 * @return array The array of content objects
+	 */
 	function &GetAllContent($loadprops=true)
 	{
 		debug_buffer('get all content...');
@@ -641,7 +788,8 @@ class ContentOperations
 				$contentobj =& ContentOperations::CreateNewContent($dbresult->fields['type']);
 				if (isset($contentobj))
 				{
-					$contentobj->LoadFromData($dbresult->FetchRow(), false);
+					$tmp = $dbresult->FetchRow();
+					$contentobj->LoadFromData($tmp, false);
 					$map[$contentobj->Id()] = $count;
 					$contentcache[] = $contentobj;
 					$count++;
@@ -670,73 +818,125 @@ class ContentOperations
 		return $contentcache;
 	}
 
-	function CreateHierarchyDropdown($current = '', $parent = '', $name = 'parent_id', $allowcurrent = 0)
+	/**
+	 * Create a hierarchical ordered dropdown of all the content objects in the system for use
+	 * in the admin and various modules.  If $current or $parent variables are passed, care is taken
+	 * to make sure that children which could cause a loop are hidden, in cases of when you're creating
+	 * a dropdown for changing a content object's parent.
+	 *
+	 * @param string $current The currently selected content object.  If none is given, we show all items.
+	 * @param string $parent The parent of the currently selected content object. If none is given, we show all items.
+	 * @param string $name The html name of the dropdown
+	 * @param boolean $allowcurrent Overrides the logic if $current and/or $parent are passed. Defaults to false.
+	 * @param boolean $use_perms If true, checks authorship permissions on pages and only shows those the current
+	 *                user has access to.
+	 * @param boolean $ignore_current Ignores the value of $current totally by not marking any items as invalid.
+	 * @param boolean $allow_all If true, show all items, even if the content object 
+	 *                           doesn't have a valid link. Defaults to false.
+	 * @return string The html dropdown of the hierarchy
+	 */
+	function CreateHierarchyDropdown($current = '', $parent = '', $name = 'parent_id', $allowcurrent = 0, $use_perms = 0, $ignore_current = 0, $allow_all = false)
 	{
 		$result = '';
+		$userid = -1;
 
 		$allcontent =& ContentOperations::GetAllContent();
 
 		if ($allcontent !== FALSE && count($allcontent) > 0)
 		{
-			$result .= '<select name="'.$name.'">';
-			$result .= '<option value="-1">'.lang('none').'</option>';
-
+			if( $use_perms )
+			  {
+			    $userid = get_userid();
+			  }
+			if( ($userid > 0 && check_permission($userid,'Manage All Content')) || 
+			    $userid == -1 ||
+			    $parent == -1 )
+			  {
+			    $result .= '<option value="-1">'.lang('none').'</option>';
+			  }
 			$curhierarchy = '';
 
 			foreach ($allcontent as $one)
  			{
 			  $value = $one->Id();
-				if ($one->Id() == $current)
+			  if ($value == $current)
+			    {
+			      // Grab hierarchy just in case we need to check children
+			      // (which will always be after)
+			      $curhierarchy = $one->Hierarchy();
+			      
+			      if( !$allowcurrent )
 				{
-					#Grab hierarchy just in case we need to check children
-					#(which will always be after)
-					$curhierarchy = $one->Hierarchy();
-
-					if( !$allowcurrent )
-					  {
-					    // Then jump out.  We don't want ourselves in the list.
-					    continue;
-					  }
-					$value = -1;
+				  // Then jump out.  We don't want ourselves in the list.
+				  continue;
 				}
+			      $value = -1;
+			    }
 
-				#If it's a child of the current, we don't want to show it as it
-				#could cause a deadlock.
-				if (!$allowcurrent && $curhierarchy != '' && strstr($one->Hierarchy() . '.', $curhierarchy . '.') == $one->Hierarchy() . '.')
+			  // If it doesn't have a valid link...
+			  // don't include it.
+			  if( !$allow_all && !$one->HasUsableLink() )
+			    {
+			      continue;
+			    }
+
+			  // If it's a child of the current, we don't want to show it as it
+			  // could cause a deadlock.
+			  if (!$allowcurrent && 
+			      $curhierarchy != '' && 
+			      strstr($one->Hierarchy() . '.', $curhierarchy . '.') == $one->Hierarchy() . '.')
+			    {
+			      continue;
+			    }
+
+                          // If we have a valid userid... only include pages where this user
+                          // has write access... or is an admin user... or has appropriate permission.
+			  if( $userid > 0 && $one->Id() != $parent)
+			    {
+			      if( !check_permission($userid,'Manage All Content') && 
+				  !check_authorship($userid,$one->Id()) )
 				{
-					continue;
+				  continue;
 				}
+			    }				
 
-				#Don't include content types that do not want children either...
-				if ($one->WantsChildren() == true)
-				  {
-					$result .= '<option value="'.$value.'"';
-
-					#Select current parent if it exists
-					if ($one->Id() == $parent)
-					{
-						$result .= ' selected="selected"';
-					}
-
-					if( $value == -1 )
-					  {
-					    $result .= '>'.$one->Hierarchy().'. - '.$one->Name().' ('.lang('invalid').')</option>';
-					  }
-					else
-					  {
-					    $result .= '>'.$one->Hierarchy().'. - '.$one->Name().'</option>';
-					  }
-				}
+			  // Don't include content types that do not want children either...
+			  if (!$one->WantsChildren()) continue;
+			  {
+			    $result .= '<option value="'.$value.'"';
+			    
+			    // Select current parent if it exists
+			    if ($one->Id() == $parent)
+			      {
+				$result .= ' selected="selected"';
+			      }
+			    
+			    if( ($value == -1) && ($ignore_current == 0) )
+			      {
+				$result .= '>'.$one->Hierarchy().'. - '.$one->Name().' ('.lang('invalid').')</option>';
+			      }
+			    else
+			      {
+				$result .= '>'.$one->Hierarchy().'. - '.$one->Name().'</option>';
+			      }
+			  }
 			}
 
-			$result .= '</select>';
 		}
 
+		if( !empty($result) )
+			{
+				$result = '<select name="'.$name.'">'.$result.'</select>';
+			}
+
 		return $result;
 	}
 
-
-    // function to get the id of the default page
+	/**
+	 * Gets the content id of the page marked as default
+	 *
+	 * @return integer The id of the default page. false if not found.
+	 */
 	function GetDefaultPageID()
 	{
 	  
@@ -748,7 +948,7 @@ class ContentOperations
 
 		$db = &$gCms->GetDb();
 
-		$query = "SELECT * FROM ".cms_db_prefix()."content WHERE default_content = 1";
+		$query = "SELECT content_id FROM ".cms_db_prefix()."content WHERE default_content = 1";
 		$row = &$db->GetRow($query);
 		if (!$row)
 		{
@@ -758,9 +958,12 @@ class ContentOperations
 		return $row['content_id'];
 	}
 
-
-    // function to map an alias to a page id
-    // returns false if nothing cound be found.
+	/**
+	 * Returns the content id given a valid content alias.
+	 *
+	 * @param string $alias The alias to query
+	 * @return integer The resulting id.  false if not found.
+	 */
 	function GetPageIDFromAlias( $alias )
 	{
 		global $gCms;
@@ -772,7 +975,7 @@ class ContentOperations
 		}
 
 		$params = array($alias);
-		$query = "SELECT * FROM ".cms_db_prefix()."content WHERE content_alias = ?";
+		$query = "SELECT content_id FROM ".cms_db_prefix()."content WHERE content_alias = ?";
 		$row = $db->GetRow($query, $params);
 
 		if (!$row)
@@ -783,12 +986,18 @@ class ContentOperations
 		return $row['content_id'];
 	}
 	
+	/**
+	 * Returns the content id given a valid hierarchical position.
+	 *
+	 * @param string $position The position to query
+	 * @return integer The resulting id.  false if not found.
+	 */
 	function GetPageIDFromHierarchy($position)
 	{
 		global $gCms;
 		$db = &$gCms->GetDb();
 
-		$query = "SELECT * FROM ".cms_db_prefix()."content WHERE hierarchy = ?";
+		$query = "SELECT content_id FROM ".cms_db_prefix()."content WHERE hierarchy = ?";
 		$row = $db->GetRow($query, array(ContentOperations::CreateUnfriendlyHierarchyPosition($position)));
 
 		if (!$row)
@@ -798,9 +1007,12 @@ class ContentOperations
 		return $row['content_id'];
 	}
 
-
-    // function to map an alias to a page id
-    // returns false if nothing cound be found.
+	/**
+	 * Returns the content alias given a valid content id.
+	 *
+	 * @param integer $id The content id to query
+	 * @return string The resulting content alias.  false if not found.
+	 */
 	function GetPageAliasFromID( $id )
 	{
 		global $gCms;
@@ -812,7 +1024,7 @@ class ContentOperations
 		}
 
 		$params = array($id);
-		$query = "SELECT * FROM ".cms_db_prefix()."content WHERE content_id = ?";
+		$query = "SELECT content_alias FROM ".cms_db_prefix()."content WHERE content_id = ?";
 		$row = $db->GetRow($query, $params);
 
 		if ( !$row )
@@ -822,6 +1034,13 @@ class ContentOperations
 		return $row['content_alias'];
 	}
 
+	/**
+	 * Checks to see if a content alias is valid and not in use.
+	 *
+	 * @param string $alias The content alias to check
+	 * @param string $content_id The id of the current page, for used alias checks on existing pages
+	 * @return string The error, if any.  If there is no error, returns FALSE.
+	 */
 	function CheckAliasError($alias, $content_id = -1)
 	{
 		global $gCms;
@@ -840,7 +1059,7 @@ class ContentOperations
 		else
 		{
 			$params = array($alias);
-			$query = "SELECT * FROM ".cms_db_prefix()."content WHERE content_alias = ?";
+			$query = "SELECT content_id FROM ".cms_db_prefix()."content WHERE content_alias = ?";
 			if ($content_id > -1)
 			{
 				$query .= " AND content_id != ?";
@@ -857,6 +1076,11 @@ class ContentOperations
 		return $error;
 	}
 	
+	/**
+	 * Clears the content cache
+	 *
+	 * @return void
+	 */
 	function ClearCache()
 	{
 		global $gCms;
@@ -874,11 +1098,19 @@ class ContentOperations
 		@touch(cms_join_path(TMP_TEMPLATES_C_LOCATION,'index.html'));
 	}
 
+	/**
+	 * Converts a friendly hierarchy (1.1.1) to an unfriendly hierarchy (00001.00001.00001) for
+	 * use in the database.
+	 *
+	 * @param string $position The hierarchy position to convert
+	 * @return string The unfriendly version of the hierarchy string
+	 */
 	function CreateFriendlyHierarchyPosition($position)
 	{
 		#Change padded numbers back into user-friendly values
 		$tmp = '';
-		$levels = split('\.', $position);
+    $levels = preg_split('/\./', $position);
+    
 		foreach ($levels as $onelevel)
 		{
 			$tmp .= ltrim($onelevel, '0') . '.';
@@ -887,11 +1119,20 @@ class ContentOperations
 		return $tmp;
 	}
 
+	/**
+	 * Converts an unfriendly hierarchy (00001.00001.00001) to a friendly hierarchy (1.1.1) for
+	 * use in the database.
+	 *
+	 * @param string $position The hierarchy position to convert
+	 * @return string The friendly version of the hierarchy string
+	 */
 	function CreateUnfriendlyHierarchyPosition($position)
 	{
 		#Change user-friendly values into padded numbers
 		$tmp = '';
-		$levels = split('\.', $position);
+        
+    $levels = preg_split('/\./', $position);
+    
 		foreach ($levels as $onelevel)
 		{
 			$tmp .= str_pad($onelevel, 5, '0', STR_PAD_LEFT) . '.';
@@ -902,6 +1143,10 @@ class ContentOperations
 	
 }
 
+/**
+ * @package CMS
+ * @ignore
+ */
 class ContentManager extends ContentOperations
 {
 }
