@@ -1,23 +1,34 @@
-<?php
-# CMS - CMS Made Simple
-# (c)2004-6 by Ted Kulp (ted@cmsmadesimple.org)
-# This project's homepage is: http://cmsmadesimple.org
+<?php // -*- mode:php; tab-width:4; indent-tabs-mode:t; c-basic-offset:4; -*-
+#CMS - CMS Made Simple
+#(c)2004-2010 by Ted Kulp (ted@cmsmadesimple.org)
+#This project's homepage is: http://cmsmadesimple.org
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+#This program is free software; you can redistribute it and/or modify
+#it under the terms of the GNU General Public License as published by
+#the Free Software Foundation; either version 2 of the License, or
+#(at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
-# BUT withOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
-# GNU General Public License for more details.
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA	02111-1307	USA
+#This program is distributed in the hope that it will be useful,
+#but WITHOUT ANY WARRANTY; without even the implied warranty of
+#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#GNU General Public License for more details.
+#You should have received a copy of the GNU General Public License
+#along with this program; if not, write to the Free Software
+#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 #$Id$
 
+/**
+ * @package CMS 
+ */
+
+/**
+ * @ignore
+ */
+define( "MODULE_DTD_VERSION", "1.3" );
+
+require_once(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'class.module.inc.php');
+
 /**
  * "Static" module functions for internal use and module development.  CMSModule
  * extends this so that it has internal access to the functions.
@@ -25,10 +36,6 @@
  * @since		0.9
  * @package		CMS
  */
-define( "MODULE_DTD_VERSION", "1.3" );
-
-require_once(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'class.module.inc.php');
-
 class ModuleOperations
 {
   /**
@@ -69,6 +76,9 @@ class ModuleOperations
 
   /**
    * Set an error condition
+   *
+   * @param string $str The string to set for the error
+   * @return void
    */
   function SetError($str = '')
   {
@@ -78,6 +88,8 @@ class ModuleOperations
 
   /**
    * Return the last error
+   *
+   * @return string The last error, if any
    */
   function GetLastError()
   {
@@ -89,6 +101,13 @@ class ModuleOperations
 
 	/**
 	 * Creates an xml data package from the module directory.
+	 *
+	 * @param mixed $modinstance The instance of the module object
+	 * @param string $message Reference to a string which will be filled with the message 
+	 *                        created by the run of the method
+	 * @param integer $filecount Reference to an interger which will be filled with the 
+	 *                           total # of files in the package
+	 * @return string an XML string comprising the module and its files
 	 */
 	function CreateXMLPackage( &$modinstance, &$message, &$filecount )
 	{
@@ -104,12 +123,12 @@ class ModuleOperations
 	  $xmltxt .= "	<name>".$modinstance->GetName()."</name>\n";
 	  $xmltxt .= "	<version>".$modinstance->GetVersion()."</version>\n";
 	  $xmltxt .= "  <mincmsversion>".$modinstance->MinimumCMSVersion()."</mincmsversion>\n";
-	  $xmltxt .= "	<help>".base64_encode($modinstance->GetHelpPage())."</help>\n";
-	  $xmltxt .= "	<about>".base64_encode($modinstance->GetAbout())."</about>\n";
+	  $xmltxt .= "	<help><![CDATA[".base64_encode($modinstance->GetHelpPage())."]]></help>\n";
+	  $xmltxt .= "	<about><![CDATA[".base64_encode($modinstance->GetAbout())."]]></about>\n";
 	  $desc = $modinstance->GetAdminDescription();
 	  if( $desc != '' )
 		{
-		  $xmltxt .= "	<description>".$desc."</description>\n";
+		  $xmltxt .= "	<description><![CDATA[".$desc."]]></description>\n";
 		}
 	  $depends = $modinstance->GetDependencies();
 	  foreach( $depends as $key=>$val )
@@ -154,6 +173,11 @@ class ModuleOperations
   /**
    * Unpackage a module from an xml string
    * does not touch the database
+   *
+   * @param string $xml The xml data for the package
+   * @param boolean $overwrite Should we overwrite files if they exist?
+   * @param boolean $brief If set to true, less checking is done and no errors are returned
+   * @return array A hash of details about the installed module
    */
   function ExpandXMLPackage( $xml, $overwrite = 0, $brief = 0 )
   {
@@ -422,6 +446,10 @@ class ModuleOperations
 
   /**
    * Install a module into the database
+   *
+   * @param string $module The name of the module to install
+   * @param boolean $loadifnecessary If true, loads the module before trying to install it
+   * @return array Returns a tuple of whether the install was successful and a message if applicable
    */
   function InstallModule($module, $loadifnecessary = false)
   {
@@ -489,6 +517,9 @@ class ModuleOperations
 
   /**
    * Load a single module from the filesystem
+   *
+   * @param string $modulename The name of the module to load
+   * @return boolean Whether or not the module load was successful
    */
   function LoadNewModule( $modulename )
   {
@@ -507,7 +538,7 @@ class ModuleOperations
 	    return false;
 	  }
 
-	$newmodule =& new $modulename;
+	$newmodule = new $modulename;
 	$name = $newmodule->GetName();
 	$cmsmodules[$name]['object'] =& $newmodule;
 	$cmsmodules[$name]['installed'] = false;
@@ -523,6 +554,11 @@ class ModuleOperations
 
   /**
    * Upgrade a module
+   *
+   * @param string $module The name of the module to upgrade
+   * @param string $oldversion The version number of the existing module
+   * @param string $newversion The version number of the new module
+   * @return boolean Whether or not the upgrade was successful
    */
   function UpgradeModule( $module, $oldversion, $newversion )
   {
@@ -551,16 +587,51 @@ class ModuleOperations
     return true;
   }
 
-	/**
-	 * Returns a hash of all loaded modules.  This will include all
-	 * modules loaded by LoadModules, which could either be all or them,
-	 * or just ones that are active and installed.
-	 */
-	function & GetAllModules()
-	{
-		global $gCms;
-		$cmsmodules = &$gCms->modules;
-		return $cmsmodules;
-	}
+  /**
+   * Returns a hash of all loaded modules.  This will include all
+   * modules loaded by LoadModules, which could either be all or them,
+   * or just ones that are active and installed.
+   *
+   * @return array The hash of all loaded modules
+   */
+  function & GetAllModules()
+    {
+      global $gCms;
+      $cmsmodules = &$gCms->modules;
+      return $cmsmodules;
+    }
 
+
+  /**
+   * Returns an array of modules that have a certain capabilies
+   * 
+   * @param string $capability The capability name
+   * @param mixed $args Capability arguments
+   * @return array List of all the module with that capability
+   */
+  public static function get_modules_with_capability($capability, $args= '')
+  {
+    global $gCms;
+
+    $output = array();
+    foreach($gCms->modules as $key => $data)
+      {
+	if( isset($data['installed']) &&
+	    isset($data['object']) && 
+	    is_object($data['object']) )
+	  {
+	    $obj =& $data['object'];
+	    if( $obj->HasCapability($capability,$args) )
+	      {
+		$output->append($obj);
+	      }
+	  }
+      }
+
+    if( count($output) ) return FALSE;
+    return $output;
+  }
 }
+
+# vim:ts=4 sw=4 noet
+?>
\ No newline at end of file
