@@ -1,6 +1,6 @@
-<?php
+<?php // -*- mode:php; tab-width:4; indent-tabs-mode:t; c-basic-offset:4; -*-
 #CMS - CMS Made Simple
-#(c)2004 by Ted Kulp (tedkulp@users.sf.net)
+#(c)2004-2010 by Ted Kulp (ted@cmsmadesimple.org)
 #This project's homepage is: http://cmsmadesimple.org
 #
 #This program is free software; you can redistribute it and/or modify
@@ -9,28 +9,37 @@
 #(at your option) any later version.
 #
 #This program is distributed in the hope that it will be useful,
-#BUT withOUT ANY WARRANTY; without even the implied warranty of
+#but WITHOUT ANY WARRANTY; without even the implied warranty of
 #MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #GNU General Public License for more details.
 #You should have received a copy of the GNU General Public License
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
+#
 #$Id: class.bookmark.inc.php 2746 2006-05-09 01:18:15Z wishy $
 
+/**
+ * Usertag related functions.
+ *
+ * @package CMS
+ * @license GPL
+ */
+
 /**
  * UserTags class for admin
  *
  * @package CMS
+ * @license GPL
  */
 class UserTagOperations
 {
 	/**
 	 * Retrieve the body of a user defined tag
 	 *
-	 * @params string $name User defined tag name
+	 * @param string $name User defined tag name
 	 *
-	 * @returns mixed If successfull, the body of the user tag (string).  If it fails, false
+	 * @return mixed If successfull, the body of the user tag (string).  If it fails, false
 	 */
 	function GetUserTag( $name )
 	{
@@ -55,10 +64,10 @@ class UserTagOperations
 	/**
 	 * Add or update a named user defined tag into the database
 	 *
-	 * @params string $name User defined tag name
-	 * @params string $text Body of user defined tag
+	 * @param string $name User defined tag name
+	 * @param string $text Body of user defined tag
 	 *
-	 * @returns mixed If successful, true.  If it fails, false.
+	 * @return mixed If successful, true.  If it fails, false.
 	 */
 	function SetUserTag( $name, $text )
 	{
@@ -90,9 +99,9 @@ class UserTagOperations
 	/**
 	 * Remove a named user defined tag from the database
 	 *
-	 * @params string $name User defined tag name
+	 * @param string $name User defined tag name
 	 *
-	 * @returns mixed If successful, true.  If it fails, false.
+	 * @return mixed If successful, true.  If it fails, false.
 	 */
 	function RemoveUserTag( $name )
 	{
@@ -114,7 +123,7 @@ class UserTagOperations
  	/**
 	 * Return a list (suitable for use in a pulldown) of user tags.
 	 *
-	 * @returns mixed If successful, an array.  If it fails, false.
+	 * @return mixed If successful, an array.  If it fails, false.
 	 */
 	function ListUserTags()
 	{
@@ -165,6 +174,12 @@ class UserTagOperations
 
 } // class
 
+/**
+ * @ignore
+ * @package CMS
+ * @version $Revision$
+ * @license GPL
+ */
 class UserTags extends UserTagOperations
 {}
 
