@@ -1,23 +1,37 @@
-<?php
-# CMS - CMS Made Simple
-# (c)2004 by Ted Kulp (tedkulp@users.sf.net)
-# This project's homepage is: http://cmsmadesimple.org
+<?php // -*- mode:php; tab-width:4; indent-tabs-mode:t; c-basic-offset:4; -*-
+#CMS - CMS Made Simple
+#(c)2004-2010 by Ted Kulp (ted@cmsmadesimple.org)
+#This project's homepage is: http://cmsmadesimple.org
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+#This program is free software; you can redistribute it and/or modify
+#it under the terms of the GNU General Public License as published by
+#the Free Software Foundation; either version 2 of the License, or
+#(at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
-# BUT withOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#This program is distributed in the hope that it will be useful,
+#but WITHOUT ANY WARRANTY; without even the implied warranty of
+#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#GNU General Public License for more details.
+#You should have received a copy of the GNU General Public License
+#along with this program; if not, write to the Free Software
+#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 #$Id: Link.inc.php 4225 2007-10-14 16:31:00Z calguy1000 $
 
+/**
+ * Class definition and methods for Page Link content type
+ *
+ * @package CMS
+ * @license GPL
+ */
+
+/**
+ * Class for CMS Made Simple Page Link content type
+ *
+ * @package CMS
+ * @version $Revision$
+ * @license GPL
+ */
 class PageLink extends ContentBase
 {
 
@@ -36,16 +50,19 @@ class PageLink extends ContentBase
       return lang('contenttype_pagelink');
     }
 
-    function HasUsableLink()
-    {
-      return false;
-    }
+// calguy1000: commented this out so that this page can be seen in cms_selflink
+// but not sure what it's gonna mess up.
+//     function HasUsableLink()
+//     {
+//       return false;
+//     }
 
     function SetProperties()
     {
       parent::SetProperties();
       $this->RemoveProperty('cachable',1);
       //$this->RemoveProperty('showinmenu',1);
+      $this->RemoveProperty('secure',0);
       $this->AddContentProperty('page',10,1,'int');
       $this->AddContentProperty('params',10,1);
 		
@@ -131,7 +148,7 @@ class PageLink extends ContentBase
 	  $contentops =& $gCms->GetContentOperations();
 	  
 	  $tmp = $contentops->CreateHierarchyDropdown($this->mId, 
-						      $this->GetPropertyValue('page'), 'page', 1);
+						      $this->GetPropertyValue('page'), 'page', 1, 0, 0, 0);
 	  if( !empty($tmp) ) return array(lang('destination_page').':',$tmp);
 	}
 	break;
