@@ -1,29 +1,44 @@
-<?php
-# CMS - CMS Made Simple
-# (c)2004 by Ted Kulp (tedkulp@users.sf.net)
-# This project's homepage is: http://cmsmadesimple.org
+<?php // -*- mode:php; tab-width:4; indent-tabs-mode:t; c-basic-offset:4; -*-
+#CMS - CMS Made Simple
+#(c)2004-2010 by Ted Kulp (ted@cmsmadesimple.org)
+#This project's homepage is: http://cmsmadesimple.org
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
+#This program is free software; you can redistribute it and/or modify
+#it under the terms of the GNU General Public License as published by
+#the Free Software Foundation; either version 2 of the License, or
+#(at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful,
-# BUT withOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#This program is distributed in the hope that it will be useful,
+#but WITHOUT ANY WARRANTY; without even the implied warranty of
+#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#GNU General Public License for more details.
+#You should have received a copy of the GNU General Public License
+#along with this program; if not, write to the Free Software
+#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: Separator.inc.php 5991 2009-09-14 18:37:18Z calguy1000 $
+#$Id: Separator.inc.php 6447 2010-07-02 06:40:08Z sjg $
 
+/**
+ * Class definition and methods for Separator content type
+ *
+ * @package CMS
+ * @license GPL
+ */
+
+/**
+ * Class for CMS Made Simple Separator content type
+ *
+ * @package CMS
+ * @version $Revision$
+ * @license GPL
+ */
 class Separator extends ContentBase
 {
 
     function SetProperties()
     {
       parent::SetProperties();
+      $this->RemoveProperty('secure',0);
       $this->RemoveProperty('template','-1');
       $this->RemoveProperty('alias','');
       $this->RemoveProperty('title','');
