@@ -16,17 +16,19 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: config.functions.php 5718 2009-05-15 00:52:29Z nuno $
+#$Id: config.functions.php 6524 2010-07-29 11:04:34Z wishy $
 
 /**
  * Functions relating to the config hash and config files
  *
  * @package CMS
  */
+
 /**
  * Loads the config file with defaults and then with specific values from config.php
  *
  * @since 0.5
+ * @ignore
  */
 function cms_config_load($loadLocal = true, $upgrade = false)
 {
@@ -155,11 +157,29 @@ function cms_config_load($loadLocal = true, $upgrade = false)
 			$config['assume_mod_rewrite'] = false;
 	}
 
+	// adjust ssl url if not specified
+	if( !isset($config['ssl_url']) )
+	  {
+	    $config['ssl_url'] = str_replace('http://','https://',$config['root_url']);
+	  }
+	// adjust ssl url if not specified
+	if( !isset($config['ssl_uploads_url']) )
+	  {
+	    $config['ssl_uploads_url'] = str_replace('http://','https://',$config['uploads_url']);
+	  }
 	return $config;
 }
 
+/**
+ * @ignore
+ */
 function cms_config_text($config)
 {
+  if( !isset($config['ssl_url']) )
+    $config['ssl_url'] = str_replace('http://','https://',$config['root_url']);
+  if( !isset($config['ssl_uploads_url']) )
+    $config['ssl_uploads_url'] = str_replace('http://','https://',$config['uploads_url']);
+
 	$true = 'true';
 	$false = 'false';
 	$result = <<<EOF
@@ -176,7 +196,8 @@ function cms_config_text($config)
 # use extreme caution when editing these.  Additionally, some settings may have 
 # no effect on servers with significantly restricted configurability.
 
-# If you are experiencing propblems with php memory limit errors, then you may
+# Warning: This option is deprecated and will be removed in later versions oF CMSMS.
+# If you are experiencing problems with php memory limit errors, then you may
 # want to try enabling and/or adjusting this setting.  
 # Note: Your server may not allow the application to override memory limits.
 \$config['php_memory_limit'] = '{$config['php_memory_limit']}';
@@ -238,10 +259,9 @@ function cms_config_text($config)
 #If page is requested with https use https as root url
 #e.g. http://blah.com
 \$config['root_url'] = '{$config['root_url']}';
-if(isset(\$_SERVER['HTTPS']) && \$_SERVER['HTTPS']=='on')
-{
-  \$config['root_url'] = str_replace('http','https',\$config['root_url']);
-}
+
+#SSL URL.  This is used for pages that are marked as secure.
+\$config['ssl_url'] = '{$config['ssl_url']}';
 
 #Path to document root. This should be the directory this file is in.
 #e.g. /var/www/localhost
@@ -316,6 +336,8 @@ if(isset(\$_SERVER['HTTPS']) && \$_SERVER['HTTPS']=='on')
 #Default path and URL for uploaded images in the image manager
 \$config['image_uploads_path'] = '{$config['image_uploads_path']}';
 \$config['image_uploads_url'] = \$config['root_url'] . '{$config['image_uploads_url']}'; 
+#SSL URL.  This is used for pages that are marked as secure.
+\$config['ssl_uploads_url'] = '{$config['ssl_uploads_url']}';
 
 #------------------------
 #Locale/Encoding Settings
@@ -342,6 +364,16 @@ if(isset(\$_SERVER['HTTPS']) && \$_SERVER['HTTPS']=='on')
 # Set none if you want hide the link from Error 
 \$config['wiki_url'] = '{$config['wiki_url']}';
 
+#------------------------
+#Miscelaneous Settings
+#------------------------
+
+#Add performance information (in the form of an HTML comment) to the
+#bottom of all generated pages.  Note, this may cause problems with validation
+#or with advanced AJAX requests where only portions of a page are requested.
+#This variable just needs to exist, value is irrelevant.
+#\$config['show_performance_info'] = 'anything';
+
 EOF;
 	return $result;
 }
@@ -354,6 +386,7 @@ EOF;
  * if there is no access to the file;
  *
  * @since 0.5
+ * @ignore
  */
 function cms_config_save($config)
 {
@@ -401,6 +434,8 @@ function cms_config_save($config)
  * Upgrades config.php from the old style
  *
  * @since 0.5
+ * @deprecated
+ * @ignore
  */
 function cms_config_upgrade()
 {
