@@ -16,26 +16,39 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: content.functions.php 5669 2009-05-07 17:27:44Z calguy1000 $
+#$Id: content.functions.php 6439 2010-07-02 03:32:12Z calguy1000 $
 
 /**
  * Handles content related functions
  *
  * @package CMS
  */
+
+/**
+ * @ignore
+ */
 $sorted_sections = array();
+
+/**
+ * @ignore
+ */
 $sorted_content = array();
 
 /**
  * Extends the Smarty class for content.
  *
- * Extends the Smarty class for checking timestamps and rendering
- * content to the browser.
+ * Extends the Smarty class for checking timestamps and rendering content to the browser.
  *
+ * @package CMS
  * @since 0.1
  */
 class Smarty_CMS extends Smarty {
 	
+        /**
+	 * Constructor
+	 *
+	 * @param array The hash of CMSMS config settings
+	 */
 	function Smarty_CMS(&$config)
 	{
 		$this->Smarty();
@@ -142,6 +155,11 @@ class Smarty_CMS extends Smarty {
 
     /**
      * wrapper for include() retaining $this
+     *
+     * @ignore
+     * @access private
+     * @param  string The input filename
+     * @param  boolean A flag wether include_once should be called or just include
      * @return mixed
      */
     function _include($filename, $once=false, $params=null)
@@ -156,14 +174,36 @@ class Smarty_CMS extends Smarty {
         }
     }
 
+
+    /**
+     * Wrapper for the trigger_error method
+     *
+     * @ignore
+     * @access private
+     * @param string The error message
+     * @param int    The error type E_USER_WARNING or E_USER_NOTICE
+     * @return void
+     */
     function trigger_error($error_msg, $error_type = E_USER_WARNING)
     {   
         var_dump("Smarty error: $error_msg");
     }
 
-	function module_file_template($tpl_name, &$tpl_source, &$smarty_obj)
+
+    /**
+     * Method to return module file template contents.
+     * 
+     * @access private
+     * @param string The module template name
+     * @param string (returned) template contents
+     * @param object The smarty object
+     * @return boolean
+     */
+    function module_file_template($tpl_name, &$tpl_source, &$smarty_obj)
     {
-        $params = split(';', $tpl_name);
+      
+      $params = preg_split('/;/', $tpl_name);
+      
 	
         if (count($params) == 2 && file_exists(dirname(dirname(__FILE__)) . '/module_custom/' . $params[0] . '/templates/' . $params[1]))
 	  {
@@ -178,9 +218,20 @@ class Smarty_CMS extends Smarty {
         return false;
     }
 
+    /** 
+     *  A method to return the timestamp of a module file template
+     *
+     *  @access private
+     *  @param  string The filename of the module template
+     *  @param  int    (returned) The file timestamp
+     *  @param  object The smarty object
+     *  @return boolean
+     */
 	function module_file_timestamp($tpl_name, &$tpl_timestamp, &$smarty_obj)
 	{
-		$params = split(';', $tpl_name);
+      
+    $params = preg_split('/;/', $tpl_name);
+      
 		if (count($params) == 2 && file_exists(dirname(dirname(__FILE__)) . '/modules/' . $params[0] . '/templates/' . $params[1]))
 		{
 			$tpl_timestamp = filemtime(dirname(dirname(__FILE__)) . '/modules/' . $params[0] . '/templates/' . $params[1]);
@@ -189,6 +240,15 @@ class Smarty_CMS extends Smarty {
 		return false;
 	}
 
+    /**
+     * A method to return a module database template.
+     *
+     * @access private
+     * @param string The database template name.
+     * @param  string (returned) The database template contents
+     * @param  object The smarty object.
+     * @return boolean
+     */
     function module_db_template($tpl_name, &$tpl_source, &$smarty_obj)
     {   
         global $gCms;
@@ -197,7 +257,7 @@ class Smarty_CMS extends Smarty {
         $config = $gCms->config;
 
         $query = "SELECT content from ".cms_db_prefix()."module_templates WHERE module_name = ? and template_name = ?";
-        $row = $db->GetRow($query, split(';', $tpl_name));
+        $row = $db->GetRow($query, preg_split('/;/', $tpl_name));
 
         if ($row)
         {
@@ -208,6 +268,15 @@ class Smarty_CMS extends Smarty {
         return false;
     }
 
+    /** 
+     *  A method to return the timestamp of a module database template
+     *
+     *  @access private
+     *  @param  string The name of the module template
+     *  @param  int    (returned) The file timestamp
+     *  @param  object The smarty object
+     *  @return boolean
+     */
 	function module_db_timestamp($tpl_name, &$tpl_timestamp, &$smarty_obj)
 	{
 		global $gCms;
@@ -242,6 +311,16 @@ class Smarty_CMS extends Smarty {
 		return true;
 	}
 
+
+    /**
+     * A method to return the contents of a global content block.
+     *
+     * @access private
+     * @param string The global content block name.
+     * @param  string (returned) The database template contents
+     * @param  object The smarty object.
+     * @return boolean
+     */
 	function global_content_get_template($tpl_name, &$tpl_source, &$smarty_obj)
 	{
 		debug_buffer('start global_content_get_template');
@@ -274,7 +353,7 @@ class Smarty_CMS extends Smarty {
 			#defined plugin instead.
 			if (!(isset($config["use_smarty_php_tags"]) && $config["use_smarty_php_tags"] == true))
 			{
-				$tpl_source = ereg_replace("\{\/?php\}", "", $tpl_source);
+				$tpl_source = preg_replace("/\{\/?php\}/", "", $tpl_source);
 			}
 		}
 		else
@@ -285,6 +364,16 @@ class Smarty_CMS extends Smarty {
 		return true;
 	}
 
+
+    /** 
+     *  A method to return the timestamp of a global content block.
+     *
+     *  @access private
+     *  @param  string The name of the global content block.
+     *  @param  int    (returned) The file timestamp
+     *  @param  object The smarty object
+     *  @return boolean
+     */
 	function global_content_get_timestamp($tpl_name, &$tpl_timestamp, &$smarty_obj)
 	{
 		debug_buffer('start global_content_get_timestamp');
@@ -303,6 +392,16 @@ class Smarty_CMS extends Smarty {
 		}
 	}
 
+
+    /**
+     * Given a page template, return the portion of a page template before the head tag.
+     *
+     * @access private
+     * @param string The page template name.
+     * @param  string (returned) The database template contents
+     * @param  object The smarty object.
+     * @return boolean
+     */
 	function template_top_get_template($tpl_name, &$tpl_source, &$smarty_obj)
 	{
 	  global $gCms;
@@ -349,6 +448,16 @@ class Smarty_CMS extends Smarty {
 	  return false;
 	}
 
+
+    /**
+     * Given a page template, return the head portion of a page template.
+     *
+     * @access private
+     * @param string The page template name.
+     * @param  string (returned) The database template contents
+     * @param  object The smarty object.
+     * @return boolean
+     */
 	function template_head_get_template($tpl_name, &$tpl_source, &$smarty_obj)
 	{
 	  global $gCms;
@@ -399,6 +508,15 @@ class Smarty_CMS extends Smarty {
 	}
 
 
+    /**
+     * Given a page template, return the body portion of a page template.
+     *
+     * @access private
+     * @param string The page template name.
+     * @param  string (returned) The database template contents
+     * @param  object The smarty object.
+     * @return boolean
+     */
 	function template_body_get_template($tpl_name, &$tpl_source, &$smarty_obj)
 	{
 	  global $gCms;
@@ -453,6 +571,15 @@ class Smarty_CMS extends Smarty {
 	  return false;
 	}
 
+    /**
+     * Given a page template name, return it's entire contents.
+     *
+     * @access private
+     * @param string The page template name.
+     * @param  string (returned) The database template contents
+     * @param  object The smarty object.
+     * @return boolean
+     */
 	function template_get_template($tpl_name, &$tpl_source, &$smarty_obj)
 	{
 		global $gCms;
@@ -549,7 +676,7 @@ class Smarty_CMS extends Smarty {
 					#defined plugin instead.
 					if (!(isset($config["use_smarty_php_tags"]) && $config["use_smarty_php_tags"] == true))
 					{
-						$tpl_source = ereg_replace("\{\/?php\}", "", $tpl_source);
+						$tpl_source = preg_replace("/\{\/?php\}/", "", $tpl_source);
 					}
 					
 					//do_cross_reference($pageinfo->template_id, 'template', $tpl_source);
@@ -561,6 +688,16 @@ class Smarty_CMS extends Smarty {
 		}
 	}
 
+
+    /**
+     * Given a page template name, return it's modification date.
+     *
+     * @access private
+     * @param string The page template name.
+     * @param  int (returned) The database template modification time.
+     * @param  object The smarty object.
+     * @return boolean
+     */
 	function template_get_timestamp($tpl_name, &$tpl_timestamp, &$smarty_obj)
 	{
 		global $gCms;
@@ -589,6 +726,20 @@ class Smarty_CMS extends Smarty {
 		}
 	}
 
+
+    /**
+     * Given the name of a content block, return it's content.
+     * This method assumes the use of the pageinfo information that is created in the CMSMS index.php
+     * to determine the page id that should be used to identify which content object to use.
+     * if the pageinfo is not set, it is possible for a 404 error message to be displayed.
+     * This method also handles returning preview content if the data exists in the session.
+     *
+     * @access private
+     * @param string The page template name.
+     * @param  string (returned) The database template contents
+     * @param  object The smarty object.
+     * @return boolean
+     */
 	function content_get_template($tpl_name, &$tpl_source, &$smarty_obj)
 	{
 		global $gCms;
@@ -621,7 +772,7 @@ class Smarty_CMS extends Smarty {
                   #defined plugin instead.
 		  if (!(isset($config["use_smarty_php_tags"]) && $config["use_smarty_php_tags"] == true))
 		    {
-		      $tpl_source = ereg_replace("\{\/?php\}", "", $tpl_source);
+		      $tpl_source = preg_replace("/\{\/?php\}/", "", $tpl_source);
 		    }
 
 		  return true;
@@ -641,7 +792,7 @@ class Smarty_CMS extends Smarty {
 				#defined plugin instead.
 				if (!(isset($config["use_smarty_php_tags"]) && $config["use_smarty_php_tags"] == true))
 				{
-					$tpl_source = ereg_replace("\{\/?php\}", "", $tpl_source);
+					$tpl_source = preg_replace("/\{\/?php\}/", "", $tpl_source);
 				}
 				
 				//do_cross_reference($pageinfo->content_id, 'content', $tpl_source);
@@ -652,6 +803,16 @@ class Smarty_CMS extends Smarty {
 		return false;
 	}
 
+    /**
+     * Return the modified date of the current page id (as specified in the pageinfo)
+     * This method is used by smarty to indicate wether a content page should be recompiled and cached
+     *
+     * @access private
+     * @param string The page template name (ignored)
+     * @param  int (returned) The timestamp of the modification date of the matching content object.
+     * @param  object The smarty object.
+     * @return boolean
+     */
 	function content_get_timestamp($tpl_name, &$tpl_timestamp, &$smarty_obj)
 	{
 		global $gCms;
@@ -677,6 +838,19 @@ class Smarty_CMS extends Smarty {
 		return true;
 	}
 	
+    /**
+     * Retrieve output from a module.
+     * This method grabs parameters from the request, and given the module name
+     * will call the module with the specified parameters to retrieve the module output.
+     * This is used to replace the contents of the {content} tag when a module action is
+     * called in a non inline manner.
+     *
+     * @access private
+     * @param string The module name.
+     * @param  string (returned) The moduleoutput.
+     * @param  object The smarty object.
+     * @return boolean
+     */
 	function module_get_template ($tpl_name, &$tpl_source, &$smarty_obj)
 	{
 		global $gCms;
@@ -714,24 +888,53 @@ class Smarty_CMS extends Smarty {
 		#defined plugin instead.
 		if (!(isset($config["use_smarty_php_tags"]) && $config["use_smarty_php_tags"] == true))
 		{
-			$tpl_source = ereg_replace("\{\/?php\}", "", $tpl_source);
+			$tpl_source = preg_replace("/\{\/?php\}/", "", $tpl_source);
 		}
 
 		return true;
 	}
 
+    /**
+     * A dummy function to return the modified date of the latest module output.  
+     * This function always returns the current time which essentially disables smarty compile caching
+     * for non-inline module output.
+     *
+     * @access private
+     * @param string The page template name (ignored)
+     * @param  int (returned) The timestamp of the modification date of the matching template (always current time)
+     * @param  object The smarty object.
+     * @return boolean
+     */
 	function module_get_timestamp($tpl_name, &$tpl_timestamp, &$smarty_obj)
 	{
 		$tpl_timestamp = time();
 		return true;
 	}
 
+	/** 
+	 * A dummy function that indicates that all db templates are secure.
+	 * (always returns true)
+	 *
+	 * @access private
+	 * @param  string The template name (ignored)
+	 * @param  object The smarty object
+	 * @return boolean
+	 */
 	function db_get_secure($tpl_name, &$smarty_obj)
 	{
 		// assume all templates are secure
 		return true;
 	}
 
+	/** 
+	 * A dummy function that indicates that all db templates are truested.
+	 * (always returns true)
+	 *
+	 * @access private
+	 * @param  string The template name (ignored)
+	 * @param  object The smarty object
+	 * @return boolean
+	 */
 	function db_get_trusted($tpl_name, &$smarty_obj)
 	{
 		// not used for templates
@@ -742,6 +945,8 @@ class Smarty_CMS extends Smarty {
  * Loads all plugins into the system
  *
  * @since 0.5
+ * @param object The smarty object
+ * @return void
  */
 function load_plugins(&$smarty)
 {
@@ -782,6 +987,17 @@ function load_plugins(&$smarty)
 	}
 }
 
+/**
+ * A function to load all valid plugins in the plugins directory.
+ *
+ * @internal
+ * @access private
+ * @param object The smarty object
+ * @param array  A reference to the $gCms->plugins array.
+ * @param string The directory name
+ * @param boolean Wether caching should be applied
+ * @return void
+ */
 function search_plugins(&$smarty, &$plugins, $dir, $caching)
 {
 	global $CMS_LOAD_ALL_PLUGINS;
@@ -852,6 +1068,17 @@ function search_plugins(&$smarty, &$plugins, $dir, $caching)
 	closedir($handle);
 }
 
+/**
+ * A function to generate cross references between content types
+ * This function can be used to generate which global content blocks are used by which content object
+ *
+ * @ignore
+ * @access private
+ * @param int the parent object id (usually a page template id or a page id.
+ * @param string The parent object type
+ * @param string The test content
+ * @return void
+ */
 function do_cross_reference($parent_id, $parent_type, $content)
 {
 	global $gCms;
@@ -882,6 +1109,15 @@ function do_cross_reference($parent_id, $parent_type, $content)
 	}
 }
 
+/**
+ * A function to remove all cross references for a parent object
+ *
+ * @ignore
+ * @access private
+ * @param int The parent object id
+ * @param string The parent object type
+ * @return void
+ */
 function remove_cross_references($parent_id, $parent_type)
 {
 	global $gCms;
@@ -892,6 +1128,15 @@ function remove_cross_references($parent_id, $parent_type)
 	$db->Execute($query, array($parent_id, $parent_type));
 }
 
+/**
+ * A function to remove all cross references for a child
+ *
+ * @ignore
+ * @access private
+ * @param int The child object id
+ * @param string The child object type
+ * @return void
+ */
 function remove_cross_references_by_child($child_id, $child_type)
 {
 	global $gCms;
@@ -902,6 +1147,14 @@ function remove_cross_references_by_child($child_id, $child_type)
 	$db->Execute($query, array($child_id, $child_type));
 }
 
+/**
+ * A utility function to load the specified global content blocks and call the GlobalContentPrecompile method.
+ *
+ * @ignore
+ * @access private
+ * @param array Array containing the name of 1 global content block
+ * @return void
+ */
 function global_content_regex_callback($matches)
 {
 	global $gCms;
@@ -914,16 +1167,16 @@ function global_content_regex_callback($matches)
 			$text = $oneblob->content;
 
 			#Perform the content htmlblob callback
-			reset($gCms->modules);
-			while (list($key) = each($gCms->modules))
-			{
-				$value =& $gCms->modules[$key];
-				if ($gCms->modules[$key]['installed'] == true &&
-					$gCms->modules[$key]['active'] == true)
-				{
-					$gCms->modules[$key]['object']->GlobalContentPreCompile($text);
-				}
-			}
+			#reset($gCms->modules);
+			#while (list($key) = each($gCms->modules))
+			#{
+			#	$value =& $gCms->modules[$key];
+			#	if ($gCms->modules[$key]['installed'] == true &&
+			#		$gCms->modules[$key]['active'] == true)
+			#	{
+			#		$gCms->modules[$key]['object']->GlobalContentPreCompile($text);
+			#	}
+			#}
 			
 			Events::SendEvent('Core', 'GlobalContentPreCompile', array('content' => &$text));
 
@@ -941,6 +1194,13 @@ function global_content_regex_callback($matches)
 }
 
 
+/**
+ * A convenience function to test if the site is marked as down according to the config panel.
+ * This method includes handling the preference that indicates that site-down behaviour should
+ * be disabled for certain IP address ranges.
+ *
+ * @return boolean
+ */
 function is_sitedown()
 {
   if( get_site_preference('enablesitedownmessage') !== '1' ) return FALSE;
