@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: page.functions.php 5753 2009-05-23 16:29:06Z calguy1000 $
+#$Id: page.functions.php 6428 2010-07-01 17:56:45Z calguy1000 $
 
 /**
  * Page related functions.  Generally these are functions not necessarily
@@ -24,13 +24,15 @@
  *
  * @package CMS
  */
+
+
 /**
  * Checks to see if the user is logged in.   If not, redirects the browser
  * to the admin login.
  *
  * @since 0.1
  * @param string no_redirect - If true, then don't redirect if not logged in
- * @returns If they're logged in, true.  If not logged in, false. 
+ * @return boolean
  */
 function check_login($no_redirect = false)
 {
@@ -130,11 +132,13 @@ function check_login($no_redirect = false)
 	return true;
 }
 
+
 /**
  * Gets the userid of the currently logged in user.
  *
- * @returns If they're logged in, the user id.  If not logged in, false.
  * @since 0.1
+ * @param  boolean Redirect to the admin login page if the user is not logged in.
+ * @return integer The UID of the logged in administrator, otherwise FALSE
  */
 function get_userid($check = true)
 {
@@ -153,6 +157,15 @@ function get_userid($check = true)
 	}
 }
 
+/**
+ * A function to check if the checksum provided can be used to validate the user to this site
+ *
+ * @internal
+ * @access private
+ * @param int The admin userid.
+ * @param string The checksum variable
+ * @return boolean
+ */
 function check_passhash($userid, $checksum)
 {
 	$check = false;
@@ -178,7 +191,11 @@ function check_passhash($userid, $checksum)
  * for 20+ minutes with no interaction), the user won't have to relogin to regenerate
  * the details.
  *
+ * @internal
+ * @access private
  * @since 0.5
+ * @param integer The admin user id
+ * @return void
  */
 function generate_user_object($userid)
 {
@@ -199,6 +216,15 @@ function generate_user_object($userid)
 	}
 }
 
+
+/**
+ * A function to send lost password recovery email to a specified admin user (by name)
+ *
+ * @internal
+ * @access private
+ * @param string the username
+ * @return results from the attempt to send a message.
+ */
 function send_recovery_email($username)
 {
 	global $gCms;
@@ -231,6 +257,14 @@ function send_recovery_email($username)
 	return $obj->Send();
 }
 
+/**
+ * A function find a matching user id given an identity hash
+ *
+ * @internal
+ * @access private
+ * @param string the hash
+ * @return object The matching user object if found, or null otherwise.
+ */
 function find_recovery_user($hash)
 {
 	global $gCms;
@@ -251,7 +285,11 @@ function find_recovery_user($hash)
 /**
  * Loads all permissions for a particular user into a global variable so we don't hit the db for every one.
  *
+ * @internal
+ * @access private
  * @since 0.8
+ * @param int The user id
+ * @return void
  */
 function load_all_permissions($userid)
 {
@@ -275,11 +313,13 @@ function load_all_permissions($userid)
 }
 
 /**
- * Checks to see that the given userid has access to
- * the given permission.
+ * Checks to see that the given userid has access to the given permission.
+ * Members of the admin group have all permissions.
  *
- * @returns mixed If they have perimission, true.  If they do not, false.
  * @since 0.1
+ * @param int The user id
+ * @param string The permission name
+ * @return boolean
  */
 function check_permission($userid, $permname)
 {
@@ -306,11 +346,17 @@ function check_permission($userid, $permname)
 	return $check;
 }
 
+
 /**
  * Checks that the given userid is the owner of the given contentid.
+ * (members of the admin group have all permission)
  *
- * @returns mixed If they have ownership, true.  If they do not, false.
+ * @internal
  * @since 0.1
+ * @param   integer  The User ID
+ * @param   integer  The content id
+ * @param   boolean  use strict checking (ignored)
+ * @return  boolean 
  */
 function check_ownership($userid, $contentid = '', $strict = false)
 {
@@ -356,8 +402,11 @@ function check_ownership($userid, $contentid = '', $strict = false)
  * pageid.  This would mean that they were set as additional
  * authors/editors by the owner.
  *
- * @returns mixed If they have authorship, true.  If they do not, false.
+ * @internal
  * @since 0.2
+ * @param  integer The admin user id
+ * @param  integer A valid content id.
+ * @return boolean
  */
 function check_authorship($userid, $contentid = '')
 {
@@ -383,8 +432,10 @@ function check_authorship($userid, $contentid = '')
 /**
  * Prepares an array with the list of the pages $userid is an author of
  *
- * @returns an array in whose elements are the IDs of the pages
+ * @internal
  * @since 0.11
+ * @param  integer The user id.
+ * @return array   An array of pages this user is an author of.
  */
 function author_pages($userid)
 {
@@ -443,8 +494,11 @@ function author_pages($userid)
  * pageid.  This would mean that they were set as additional
  * authors/editors by the owner.
  *
- * @returns mixed If they have authorship, true.  If they do not, false.
  * @since 0.11
+ * @internal
+ * @param   integer The content id to test with
+ * @param   array   A list of the authors pages.
+ * @return  boolean
  */
 function quick_check_authorship($contentid, $hispages)
 {
@@ -458,11 +512,16 @@ function quick_check_authorship($contentid, $hispages)
 	return $check;
 }
 
+
 /**
  * Put an event into the audit (admin) log.  This should be
  * done on most admin events for consistency.
  *
  * @since 0.3
+ * @param integer The item id (perhaps a content id, or a record id from a module)
+ * @param string  The item name (perhaps Content, or the module name)
+ * @param string  The action that needs to be audited
+ * @return void
  */
 function audit($itemid, $itemname, $action)
 {
@@ -498,15 +557,16 @@ function audit($itemid, $itemname, $action)
 	$db->Execute($query,array(time(),$userid,$username,$itemid,$itemname,$action));
 }
 
+
 /**
  * Loads a cache of site preferences so we only have to do it once.
  *
  * @since 0.6
+ * @internal
+ * @return void
  */
 function load_site_preferences()
 {
-	$value = "";
-
 	global $gCms;
 	$db = &$gCms->GetDb();
 	$siteprefs = &$gCms->siteprefs;
@@ -524,14 +584,16 @@ function load_site_preferences()
 		
 		if ($result) $result->Close();
 	}
-
-	return $value;
 }
 
+
 /**
  * Gets the given site prefernce
  *
  * @since 0.6
+ * @param string The preference name
+ * @param mixed  The default value if the preference does not exist
+ * @return mixed
  */
 function get_site_preference($prefname, $defaultvalue = '') {
 
@@ -553,10 +615,13 @@ function get_site_preference($prefname, $defaultvalue = '') {
 	return $value;
 }
 
+
 /**
  * Removes the given site preference
  *
  * @param string Preference name to remove
+ * @param boolean Wether or not to remove all preferences that are LIKE the supplied name
+ * @return void
  */
 function remove_site_preference($prefname,$uselike=false)
 {
@@ -581,10 +646,14 @@ $db->debug = true;
 	if ($result) $result->Close();
 }
 
+
 /**
  * Sets the given site perference with the given value.
  *
  * @since 0.6
+ * @param string The preference name
+ * @param mixed  The preference value (will be stored as a string)
+ * @return void
  */
 function set_site_preference($prefname, $value)
 {
@@ -618,6 +687,15 @@ function set_site_preference($prefname, $value)
 	$siteprefs[$prefname] = $value;
 }
 
+
+/**
+ * A function to load all user preferences for the specified user ID
+ *
+ * @internal
+ * @access private
+ * @param integer The User ID
+ * @return void
+ */
 function load_all_preferences($userid)
 {
 	global $gCms;
@@ -640,6 +718,10 @@ function load_all_preferences($userid)
  * Gets the given preference for the given userid.
  *
  * @since 0.3
+ * @param integer The user id
+ * @param string  The preference name
+ * @param mixed   The default value if the preference is not set for the given user id.
+ * @return mixed.
  */
 function get_preference($userid, $prefname, $default='')
 {
@@ -673,6 +755,10 @@ function get_preference($userid, $prefname, $default='')
  * Sets the given perference for the given userid with the given value.
  *
  * @since 0.3
+ * @param integer The user id
+ * @param string  The preference name
+ * @param mixed   The preference value (will be stored as a string)
+ * @return void
  */
 function set_preference($userid, $prefname, $value)
 {
@@ -712,10 +798,16 @@ function set_preference($userid, $prefname, $value)
 	}
 }
 
+
 /**
  * Returns the stylesheet for the given templateid.  Returns a hash with encoding and stylesheet entries.
  *
  * @since 0.1
+ * @internal
+ * @deprecated
+ * @param integer template id
+ * @param string  An optional media type
+ * @return string
  */
 function get_stylesheet($template_id, $media_type = '')
 {
@@ -784,6 +876,15 @@ function get_stylesheet($template_id, $media_type = '')
 	return $result;
 }
 
+
+/**
+ * Return a list of the media types supported for the specified template
+ *
+ * @internal
+ * @access private
+ * @param integer The template ID
+ * @return array
+ */
 function get_stylesheet_media_types($template_id)
 {
 	$result = array();
@@ -828,8 +929,13 @@ function get_stylesheet_media_types($template_id)
 	return $result;
 }
 
+
 /**
  * Strips slashes from an array of values.
+ *
+ * @internal
+ * @param array A reference to an array of strings
+ * @return reference to the cleaned values
  */
 function & stripslashes_deep(&$value) 
 { 
@@ -843,7 +949,26 @@ function & stripslashes_deep(&$value)
         } 
         return $value;
 }
-	
+
+/**
+ * A method to create a text area control
+ *
+ * @internal
+ * @access private
+ * @param boolean Wether the currently selected wysiwyg area should be enabled (depends on user, and site preferences
+ * @param string  The contents of the text area
+ * @param string  The name of the text area
+ * @param string  An optional class name
+ * @param string  An optional ID (HTML ID) value
+ * @param string  The optional encoding
+ * @param string  Optional style information
+ * @param integer Width (the number of columns) (CSS can and will override this)
+ * @param integer Hieght (the number of rows) (CSS can and will override this)
+ * @param string  A flag to indicate that the wysiwyg should be forced to a different type independant of user settings
+ * @param string  The name of the syntax hilighter to use (if empty it is assumed that a wysiwyg text area is requested instead of a syntax hiliter)
+ * @param string  Optional additional text to include in the textarea tag
+ * @return string
+ */
 function create_textarea($enablewysiwyg, $text, $name, $classname='', $id='', $encoding='', $stylesheet='', $width='80', $height='15',$forcewysiwyg='',$wantedsyntax='',$addtext='')
 {
 	global $gCms;
@@ -916,6 +1041,10 @@ function create_textarea($enablewysiwyg, $text, $name, $classname='', $id='', $e
 		{
 			$result .= ' class="'.$classname.'"';
 		}
+		else
+                {
+		  $result .= ' class="cms_textarea"';
+		}
 		if ($id != '')
 		{
 			$result .= ' id="'.$id.'"';
@@ -977,20 +1106,12 @@ function textarea_highlight($use_javasyntax, $text, $name, $class_name="syntaxHi
     return $output;
 }
 */
-/*
- * Displays the login form (frontend)
- */
-function display_login_form()
-{
-	return '<form method=post action="'.$_SERVER['PHP_SELF'].'">'.
-	'Name: <input type="text" name="login_name"><br>'.
-	'Password: <input type="password" name="login_password"><br>'.
-	'<input type="submit">'.
-	'</form>';
-}
+
 
 /**
  * Creates a string containing links to all the pages.
+ *
+ * @deprecated
  * @param page - the current page to display
  * @param totalrows - the amount of items being listed
  * @param limit - the amount of items to list per page
@@ -1059,42 +1180,12 @@ function display_login_form()
  }
 
 
-function wysiwyg_form_submit()
-{
-	global $gCms;
-	$result = '';
-
-	$userid = get_userid(false);
-    if( $userid != '' ) 
-    {
-	    $wysiwyg = get_preference($userid, 'wysiwyg');
-    }
-
-	if (isset($wysiwyg) && $wysiwyg != '')
-	{
-		#Perform the content title callback
-		reset($gCms->modules);
-		while (list($key) = each($gCms->modules))
-		{
-			$value =&  $gCms->modules[$key];
-			if ($gCms->modules[$key]['installed'] == true &&
-				$gCms->modules[$key]['active'] == true)
-			{
-				@ob_start();
-				$gCms->modules[$key]['object']->WYSIWYGPageFormSubmit();
-				$result = @ob_get_contents();
-				@ob_end_clean();
-			}
-		}
-	}
-
-	return $result;
-}
 
 /**
  * Returns the currently configured database prefix.
  *
  * @since 0.4
+ * @return string
  */
 function cms_db_prefix() {
   global $gCms;
@@ -1102,6 +1193,22 @@ function cms_db_prefix() {
   return $config["db_prefix"];
 }
 
+
+/**
+ * Create a dropdown form element containing a list of files that match certain conditions
+ *
+ * @internal
+ * @param string The name for the select element.
+ * @param string The directory name to search for files.
+ * @param string The name of the file that should be selected
+ * @param string A comma separated list of extensions that should be displayed in the list
+ * @param string An optional string with which to prefix each value in the output by
+ * @param boolean Wether 'none' should be an allowed option
+ * @param string Text containing additional parameters for the dropdown element
+ * @param string A prefix to use when filtering files
+ * @param boolean A flag indicating wether the files matching the extension and the prefix should be included or excluded from the result set
+ * @return string
+ */
 function create_file_dropdown($name,$dir,$value,$allowed_extensions,$optprefix='',$allownone=false,$extratext='',
 			      $fileprefix='',$excludefiles=1)
 {
@@ -1137,5 +1244,206 @@ function create_file_dropdown($name,$dir,$value,$allowed_extensions,$optprefix='
   return $out;
 }
 
+
+/**
+ * A function tat, given the current request information will return
+ * a pageid or an alias that should be used for the display
+ * This method also handles matching routes and specifying which module
+ * should be called with what parameters
+ *
+ * @internal
+ * @access private
+ * @return string
+ */
+function get_pageid_or_alias_from_url()
+{
+  global $gCms;
+  $config = $gCms->GetConfig();
+  $contentops =& $gCms->GetContentOperations();
+  $smarty = &$gCms->smarty;
+
+  $params =& $_REQUEST;
+  if (isset($params['mact']))
+    {
+      $ary = explode(',', cms_htmlentities($params['mact']), 4);
+      $smarty->id = (isset($ary[1])?$ary[1]:'');
+    }
+  else
+    { // old?
+      $smarty->id = (isset($params['id'])?intval($params['id']):'');
+    }
+
+  $page = '';
+  if (isset($smarty->id) && isset($params[$smarty->id . 'returnid']))
+    {
+      // old?
+      $page = $params[$smarty->id . 'returnid'];
+    }
+  else if (isset($config["query_var"]) && $config["query_var"] != '' && isset($_GET[$config["query_var"]]))
+    {
+      $page = $_GET[$config["query_var"]];    
+    }
+  else
+    {
+      // either we're using internal urls
+      // or this is the default page.
+      if (isset($_SERVER["REQUEST_URI"]) && !endswith($_SERVER['REQUEST_URI'], 'index.php'))
+	{
+	  $matches = array();
+	  if (preg_match('/.*index\.php\/(.*?)$/', $_SERVER['REQUEST_URI'], $matches))
+	    {
+	      // internal pretty urls.
+	      $page = $matches[1];
+	    }
+	}
+    }
+
+
+  // by here, if page is empty, use the default page id
+  if ($page == '')
+    {
+      // assume default content
+      $page = $contentops->GetDefaultContent();
+    }
+
+  // by here page should be a string.
+  if( is_numeric($page) ) return $page;
+
+  // strip off GET params.
+  if( ($tmp = strpos($page,'?')) !== FALSE )
+    {
+      $page = substr($page,0,$tmp);
+    }
+
+  // strip off page extension
+  if ($config['page_extension'] != '' && endswith($page, $config['page_extension']))
+    {   
+      $page = substr($page, 0, strlen($page) - strlen($config['page_extension']));
+    }
+
+  // trim trailing /
+  $page = rtrim($page, '/');
+
+  // match routes
+  $matched = false;
+  if (strpos($page, '/') !== FALSE)
+    {
+      $routes =& $gCms->variables['routes'];
+      foreach ($routes as $route)
+	{
+	  $matches = array();
+	  if (preg_match($route->regex, $page, $matches))
+	    {
+	      //Now setup some assumptions
+	      if (!isset($matches['id']))
+		$matches['id'] = 'cntnt01';
+	      if (!isset($matches['action']))
+		$matches['action'] = 'defaulturl';
+	      if (!isset($matches['inline']))
+		$matches['inline'] = 0;
+	      if (!isset($matches['returnid']))
+		$matches['returnid'] = ''; #Look for default page
+	      if (!isset($matches['module']))
+		$matches['module'] = $route->module;
+
+	      //Get rid of numeric matches
+	      foreach ($matches as $key=>$val)
+		{
+		  if (is_int($key))
+		    {
+		      unset($matches[$key]);
+		    }
+		  else
+		    {
+		      if ($key != 'id')
+			$_REQUEST[$matches['id'] . $key] = $val;
+		    }
+		}
+
+	      //Now set any defaults that might not have been in the url
+	      if (isset($route->defaults) && count($route->defaults) > 0)
+		{
+		  foreach ($route->defaults as $key=>$val)
+		    {
+		      $_REQUEST[$matches['id'] . $key] = $val;
+		      if (array_key_exists($key, $matches))
+			{ 
+			  $matches[$key] = $val;
+			}
+		    }
+		}
+
+	      //Get a decent returnid
+	      if ($matches['returnid'] == '') {
+		$matches['returnid'] = $contentops->GetDefaultPageID();
+	      }
+
+	      $_REQUEST['mact'] = $matches['module'] . ',' . $matches['id'] . ',' . $matches['action'] . ',' . $matches['inline'];
+
+	      $page = $matches['returnid'];
+	      $smarty->id = $matches['id'];
+
+	      $matched = true;
+	      break;
+	    }
+	}
+    }
+
+  if( !$matched )
+    {
+      // call modules to see if they can match the URL
+      foreach( $gCms->modules as $key => &$data )
+	{
+	  if( !isset($data['installed']) || $data['installed'] == FALSE ) continue;
+
+	  $module =& $data['object'];
+	  $res = $module->IsValidRoute($page);
+	  if( !is_array($res) ) continue;
+
+	  $tmp = array('id'=>'cntnt01','action'=>'defaulturl',
+		       'inline'=>0,'returnid'=>'','module'=>$key);
+	  $tmp = array_merge($tmp,$res);
+
+	  foreach( $tmp as $key => $value )
+	    {
+	      switch( $key )
+		{
+		case 'returnid':
+		case 'module':
+		case 'id':
+		case 'inline':
+		  // do nothing.
+		  break;
+
+		case 'action':
+		  $_REQUEST['mact'] = $tmp['module'] . ',' . $tmp['id'] . ',' . $tmp['action'] . ',' . $tmp['inline'];
+		  break;
+
+		default:
+		  $_REQUEST[$tmp['id'].$key] = $value;
+		}
+	    }
+	  
+	  $page = $tmp['returnid'];
+	  $smarty->id = $tmp['id'];
+	  $matched = true;
+	}
+    }
+
+  // if noroute matched... grab the alias from the last /
+  if( ($pos = strrpos($page,'/')) !== FALSE && $matched == false )
+    {
+      $page = substr($page, $pos + 1);
+    }
+
+  // at this point we MUST have a valid page
+  if( empty($page) )
+    {
+      // maybe it's the home page.
+      $page = $contentops->GetDefaultContent();
+    }
+  
+  return $page;
+}
 # vim:ts=4 sw=4 noet
 ?>
