@@ -1,4 +1,9 @@
 <?php
+$lang['none'] = 'Keiner';
+$lang['ssl'] = 'SSL ';
+$lang['tls'] = 'TLS ';
+$lang['secure'] = 'Verschl&uuml;sselung mit';
+$lang['info_secure'] = 'Funktioniert nur mit der Einstellung SMTP-Mailer. &Uuml;ber diese Option kann festgelegt werden, welche Verschl&uuml;sselung f&uuml;r die Verbindung verwendet werden soll.';
 $lang['info_cmsmailer'] = 'Dieses Modul wird von einigen anderen Modulen verwendet, um den Emailversand zu erleichtern. Es muss daher entsprechend den Vorgaben Ihres Hosters konfiguriert werden.  Wenn Sie trotzdem keine Testnachricht versenden k&ouml;nnen, sollten Sie Ihren Hoster um Hilfe bitten.';
 $lang['charset'] = 'Zeichensatz';
 $lang['sendtestmailconfirm'] = 'Hiermit wird eine Testnachricht an die festgelegte Adresse versandt. War der Versand erfolgreich, kehren Sie zu dieser Seite zur&uuml;ck. Wollen Sie dies wirklich?';
@@ -314,9 +319,9 @@ $lang['help'] = '<h3>Was macht dieses Modul?</h3>
 <p>Copyright &copy; 2005, Robert Campbell <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. Alle Rechte vorbehalten.</p>
 <p>Dieses Modul wurde unter der <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a> ver&ouml;ffentlicht. Sie m&uuml;ssen dieser Lizenz zustimmen, bevor Sie das Modul verwenden.</p>
 ';
-$lang['qca'] = 'P0-617342851-1252404665837';
-$lang['utma'] = '156861353.343462282.1252405474.1252405474.1252408135.2';
+$lang['qca'] = 'P0-75091478-1268421814072';
+$lang['utmz'] = '156861353.1272379137.12.8.utmcsr=cmsmadesimple.de|utmccn=(referral)|utmcmd=referral|utmcct=/';
+$lang['utma'] = '156861353.728989452.1268567475.1271758833.1272379137.12';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1252405474.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
-$lang['utmb'] = '156861353';
+$lang['utmb'] = '156861353.1.10.1272379137';
 ?>
\ No newline at end of file
