@@ -1,4 +1,9 @@
 <?php
+$lang['none'] = 'Aucun';
+$lang['ssl'] = 'SSL ';
+$lang['tls'] = 'TLS ';
+$lang['secure'] = 'Protocole de s&eacute;curisation&nbsp;';
+$lang['info_secure'] = 'Applicable uniquement &agrave; la m&eacute;thode de courrier SMTP, cette option permet de sp&eacute;cifier les diff&eacute;rents protocole de s&eacute;curisation pour la connexion';
 $lang['info_cmsmailer'] = 'Ce module est utilis&eacute; par de nombreux autres modules pour faciliter l&#039;envoi d&#039;emails. Il doit &ecirc;tre correctement configur&eacute; pour votre h&eacute;bergement. Utiliser les informations fournies par votre h&eacute;bergeur pour r&eacute;gler ces param&egrave;tres. Si vous ne parvenez toujours pas  &agrave; envoyer le message de test correctement, vous devez contacter votre h&eacute;bergeur pour obtenir de l&#039;aide.';
 $lang['charset'] = 'Format d&#039;encodage des caract&egrave;res&nbsp;';
 $lang['sendtestmailconfirm'] = 'Ceci va envoyer un message de test &agrave; l&#039;adresse sp&eacute;cifi&eacute;e. Si le processus d&#039;envoi s&#039;effectue avec succ&egrave;s, vous serez redirig&eacute; &agrave; nouveau vers cette page. Voulez-vous continuer&nbsp;?';
@@ -65,7 +70,7 @@ $lang['help'] = '<h3>Que fait ce module&nbsp;?</h3>
 <pre>
   $cmsmailer = $this->GetModuleInstance(&#039;CMSMailer&#039;);
   $cmsmailer->AddAddress(&#039;calguy1000@hotmail.com&#039;,&#039;calguy&#039;);
-  $cmsmailer->SetBody(&#039;<h4>Ceci est un message de test</h4>&#039;);
+  $cmsmailer->SetBody(&#039;<b>Ceci est un message de test</b>&#039;);
   $cmsmailer->IsHTML(true);
   $cmsmailer->SetSubject(&#039;Test message&#039;);
   $cmsmailer->Send();
@@ -304,20 +309,19 @@ $lang['help'] = '<h3>Que fait ce module&nbsp;?</h3>
 <h3>Support</h3>
 <p>Ce module ne contient aucun support commercial. Cependant, ces ressources sont disponibles pour vous aider&nbsp;:</p>
 <ul>
-<li>Pour la derni&egrave;re version de ce module, les FAQs, ou pour annoncer un bug, veuillez visiter la <a href=&#039;http://dev.cmsmadesimple.org/&#039; target=&#039;_blank&#039;>forge de CMS Made Simple</a>.</li>
-<li>Des discussions compl&eacute;mentaires relatives &agrave; ce module peuvent aussi &ecirc;tre trouv&eacute;es sur les <a href=&#039;http://forum.cmsmadesimple.org&#039; target=&#039;_blank&#039;>Forums CMS Made Simple</a>.</li>
+<li>Pour la derni&egrave;re version de ce module, les FAQs, ou pour annoncer un bug, veuillez visiter la <a href="http://dev.cmsmadesimple.org/" target="_blank">forge de CMS Made Simple</a>.</li>
+<li>Des discussions compl&eacute;mentaires relatives &agrave; ce module peuvent aussi &ecirc;tre trouv&eacute;es sur les <a href="http://forum.cmsmadesimple.org" target="_blank">Forums CMS Made Simple</a>.</li>
 <li>L&#039;auteur, Calguy1000, est souvent sur IRC sur canal #cms: irc.freenode.net/#cms.</li>
 <li>Et enfin, vous pouvez rencontrer un certain succ&egrave;s en envoyant un email directement &agrave; l&#039;auteur.</li>  
 </ul>
 <p>Conform&eacute;ment &agrave; la licence GPL, ce module est distribu&eacute; tel quel. Veuillez vous r&eacute;f&eacute;rer directement &agrave; la licence pour tout avis de non responsabilit&eacute;.</p>
 
 <h3>Copyright et Licence</h3>
-<p>Copyright &copy; 2005, Robert Campbell <a href=&#039;mailto:calguy1000@hotmail.com&#039;><calguy1000@hotmail.com></a>. Tous droits r&eacute;serv&eacute;s.</p>
-<p>Ce module est distribu&eacute; sous la licence <a href=&#039;http://www.gnu.org/licenses/licenses.html#GPL&#039; target=&#039;_blank&#039;>GNU Public License</a>. Vous devez agr&eacute;er aux termes de cette licence pour pouvoir utiliser ce module.</p>
+<p>Copyright &copy; 2005, Robert Campbell <a href="mailto:calguy1000@hotmail.com">calguy1000@hotmail.com</a>. Tous droits r&eacute;serv&eacute;s.</p>
+<p>Ce module est distribu&eacute; sous la licence <a href="http://www.gnu.org/licenses/licenses.html#GPL" target="_blank">GNU Public License</a>. Vous devez agr&eacute;er aux termes de cette licence pour pouvoir utiliser ce module.</p>
 ';
-$lang['utma'] = '156861353.3936683226868494000.1247055583.1253172677.1253192380.57';
-$lang['utmz'] = '156861353.1253192380.57.28.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/feature_request/list/740|utmcmd=referral';
-$lang['qca'] = '1246563679-91537581-2740096';
+$lang['qca'] = 'P0-1624099198-1262715852421';
+$lang['utma'] = '156861353.1881430788.1271753518.1271753518.1271753518.1';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
+$lang['utmz'] = '156861353.1271753518.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 ?>
\ No newline at end of file
