@@ -1,4 +1,9 @@
 <?php
+$lang['none'] = 'Nessuno';
+$lang['ssl'] = 'SSL ';
+$lang['tls'] = 'TLS ';
+$lang['secure'] = 'Meccanismo di criptazione';
+$lang['info_secure'] = 'Applicabile solo al metodo SMTP, questa opzione permette di specificare per la connessione differenti meccanismi di criptazione';
 $lang['info_cmsmailer'] = 'Questo modulo &egrave; usato da numerosi altri moduli per facilitare l&#039;invio di emai. Esso deve per&ograve; essere propriamente configurato secondo le richieste del Vostro provider. Si prega di utilizzare queste informazioni per configurare adeguatamente il modulo. Se non arriva il messaggio di test, dovete contattare l&#039;assistenza del Vostro provider.';
 $lang['charset'] = 'Insieme di caratteri';
 $lang['sendtestmailconfirm'] = 'Questo spedisce un messaggio di test all&#039;indirizzo specificato. Se la spedizione ha successo, dovreste ritornare a questa pagina. Vuoi procedere?';
@@ -9,7 +14,7 @@ Se ricevete questo messaggio significa che sta funzionando a dovere.';
 $lang['error_notestaddress'] = 'Errore: Indirizzo di test non specificato';
 $lang['prompt_testaddress'] = 'Indirizzo email di test';
 $lang['sendtest'] = 'Spedisci il messaggio di test';
-$lang['password'] = 'Password';
+$lang['password'] = 'Password ';
 $lang['username'] = 'Nome utente';
 $lang['smtpauth'] = 'Autenticazione SMTP';
 $lang['mailer'] = 'Metodo di spedizione';
@@ -31,7 +36,7 @@ $lang['info_timeout'] = 'Il numero di secondi nella conversazione SMTP prima che
 $lang['info_smtpauth'] = 'Se il server smtp richiede autenticazione (valido solo per il metodo di spedizione smtp)';
 $lang['info_username'] = 'Nome utente dell&#039;autenticazione SMTP (valido solo per il metodo di spedizione smtp, quando &egrave; selezionata l&#039;autenticazione smtp)';
 $lang['info_password'] = 'Password dell&#039;autenticazione SMTP (valido solo per il metodo di spedizione smtp, quando &egrave; selezionata l&#039;autenticazione smtp)';
-$lang['friendlyname'] = 'CMSMailer';
+$lang['friendlyname'] = 'CMSMailer ';
 $lang['postinstall'] = 'Il modulo CMSMailer &egrave; stato installato con successo';
 $lang['postuninstall'] = 'Disinstallazione del Modulo CMSMailer ...';
 $lang['uninstalled'] = 'Modulo disinstallato.';
@@ -314,8 +319,9 @@ $lang['help'] = '<h3>Che cosa fa?</h3>
 <h3>Copyright e licenza</h3>
 <p>Copyright &copy; 2005, Robert Campbell <a href=&#039;mailto:calguy1000@hotmail.com&#039;><calguy1000@hotmail.com></a>. Tutti i diritti sono riservati.</p>
 <p>Questo modulo &egrave; stato rilasciato sotto la <a href=&#039;http://www.gnu.org/licenses/licenses.html#GPL&#039;>GNU Public License</a>. Devi aderire a questa licenza prima di usare il modulo.</p>';
-$lang['utma'] = '156861353.880130626.1236353467.1240505117.1241641977.36';
-$lang['utmz'] = '156861353.1240505117.35.31.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['qca'] = 'P0-1187230324-1271659236866';
+$lang['utma'] = '156861353.976402040.1271759292.1276850904.1277118686.4';
+$lang['utmz'] = '156861353.1277118686.4.4.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
