@@ -1,7 +1,12 @@
 <?php
-$lang['info_cmsmailer'] = 'Deze module wordt door verschillende modules gebruikt voor het verzenden van de E-mails. Gebruik de informatie van host om de instellingen goed te zetten. Wanneer het verzenden van een testbericht niet lukt, zou je hulp kunnen vragen bij je host.';
+$lang['none'] = 'Geen';
+$lang['ssl'] = 'SSL ';
+$lang['tls'] = 'TLS ';
+$lang['secure'] = 'Encryptie mechanisme';
+$lang['info_secure'] = 'Alleen toepasbaar in de SMTP mailer methode, deze optie benoemt het te gebruiken encryptie mechanisme voor de verbinding';
+$lang['info_cmsmailer'] = 'Deze module wordt door verschillende modules gebruikt voor het verzenden van E-mail.<br />Gebruik de informatie van host om de instellingen goed te zetten.<br />Wanneer het verzenden van een test bericht niet lukt, zou u hulp kunnen vragen bij uw host.';
 $lang['charset'] = 'Karakterset';
-$lang['sendtestmailconfirm'] = 'Dit verstuurt een testbericht naar het opgegeven adres. Als het versturen succesvol verloopt, komt u weer op deze pagina terecht. Wilt u doorgaan?';
+$lang['sendtestmailconfirm'] = 'Dit verstuurt een test bericht naar het opgegeven adres. Als het versturen succesvol verloopt, komt u weer op deze pagina terecht. Wilt u doorgaan?';
 $lang['settingsconfirm'] = 'Huidige waarden wegschrijven naar de CMSMailer instellingen?';
 $lang['testsubject'] = 'CMSMailer Testbericht';
 $lang['testbody'] = 'Dit bericht is alleen bedoeld om te controleren of de CMSMailer-module goed is ingesteld. Als het bericht ontvangen wordt, werkt alles naar behoren.';
@@ -315,8 +320,9 @@ of the license for the full disclaimer.</p>
 <h3>Copyright and License</h3>
 <p>Copyright &amp;copy; 2005, Robert Campbell <a href=&#039;mailto:calguy1000@hotmail.com&#039;>&amp;lt;calguy1000@hotmail.com&amp;gt;</a>. All Rights Are Reserved.</p>
 <p>This module has been released under the <a href=&#039;http://www.gnu.org/licenses/licenses.html#GPL&#039;>GNU Public License</a>. You must agree to this license before using the module.</p>';
-$lang['utma'] = '156861353.799969050.1225024056.1244555916.1244572805.339';
-$lang['utmz'] = '156861353.1244550087.337.59.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,34493.new.html';
+$lang['utma'] = '156861353.295485234.1263563671.1272313485.1272349454.280';
+$lang['utmz'] = '156861353.1272029290.265.10.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,18827.0.html';
+$lang['qca'] = 'P0-1209344414-1263563671334';
+$lang['utmb'] = '156861353.1.10.1272349454';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
