@@ -1,4 +1,9 @@
 <?php
+$lang['none'] = 'Nie je ';
+$lang['ssl'] = 'SSL';
+$lang['tls'] = 'TLS';
+$lang['secure'] = '&Scaron;ifrovac&iacute; mechanizmus';
+$lang['info_secure'] = 'Použiteľn&eacute; iba pri nastaven&iacute; SMTP met&oacute;dy, povoľuje nastavenia in&eacute;ho &scaron;ifrovacie mechanizmu';
 $lang['info_cmsmailer'] = 'Modul, ktor&yacute; využ&iacute;vaj&uacute; ostatn&eacute; moduly na odosielanie e-mailov. Nastavte hodnoty, podľa možnost&iacute; v&aacute;&scaron;ho poskytovateľa web priestoru. V pr&iacute;pade, že sa v&aacute;m niž&scaron;ie nepodar&iacute; odoslať testovaciu spr&aacute;vu, sk&uacute;ste kontaktovať v&aacute;&scaron;ho administr&aacute;tora.';
 $lang['charset'] = 'K&oacute;dovanie';
 $lang['sendtestmailconfirm'] = 'Odo&scaron;le testovaciu spr&aacute;vu na zadan&uacute; adresu. Ak odosielanie prebehne v poriadku, vr&aacute;tite sa na t&uacute;to ist&uacute; str&aacute;nku.  Chcete pokračovať?';
@@ -428,8 +433,10 @@ of the license for the full disclaimer.</p>
  
 
 ﻿';
-$lang['utmz'] = '156861353.1228691676.223.15.utmccn=(referral)|utmcsr=burner.kuzmany.biz|utmcct=/install/upgrade.php|utmcmd=referral';
-$lang['utma'] = '156861353.158291335300466100.1221906470.1229195154.1229197788.231';
-$lang['utmc'] = '156861353';
+$lang['qca'] = 'P0-1608926040-1271144175783';
+$lang['utma'] = '156861353.786385904.1271157997.1279783450.1279798608.56';
+$lang['utmz'] = '156861353.1279639848.54.48.utmcsr=geekmoot.com|utmccn=(referral)|utmcmd=referral|utmcct=/2010/news/7/15/Call-for-Papers/';
+$lang['chartbeat2'] = '87v0u4nbwegh3lki';
 $lang['utmb'] = '156861353';
+$lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
