@@ -50,7 +50,7 @@ class FileManager extends CMSModule {
 	}
 
 	function GetVersion() {
-		return '1.0.1';
+		return '1.0.2';
 	}
 
 	function GetHelp() {
@@ -169,6 +169,18 @@ class FileManager extends CMSModule {
 		return "Error in Slash-function. Please report";
 	}
 
+  function ContainsIllegalChars($filename) {
+    
+    if (strpos($filename, "'")!==false) return true;
+    if (strpos($filename, "\"")!==false) return true;
+    if (strpos($filename, "/")!==false) return true;
+    if (strpos($filename, "\\")!==false) return true;
+    if (strpos($filename, "&")!==false) return true;
+    if (strpos($filename, "\$")!==false) return true;
+    if (strpos($filename, "+")!==false) return true;
+    return false;
+  }
+
 	
 	function FileManagerCompareFiles($a,$b,$forcesort="") {
 		$sortby=$this->GetPreference("sortby","nameasc");
