@@ -1,7 +1,7 @@
 <?php
 $lang['friendlyname']="File Manager";
-$lang['permission']="Usage of the the File Manager module";
-$lang['permissionadvanced']="Advanced usage of the the File Manager module";
+$lang['permission']="Usage of the File Manager module";
+$lang['permissionadvanced']="Advanced usage of the File Manager module";
 
 $lang['moddescription']="Handling of files and directories in the upload-filesection of cmsms";
 $lang['installed']="FileManager version %s installed";
@@ -111,6 +111,7 @@ $lang['unpacksuccess']="was successfully unpacked";
 $lang['unpackfail']=" failed with this error: ";
 $lang["packfileopenfail"]="Could not open the packed file for unpacking (non-supported format?)";
 $lang["packfilewritefail"]="Could not open the file %s for writing";
+$lang["containsillegalchars"]="Filename contains one or more illegal characters (',\",+,*,\\,/,&,$)";
 
 $lang["currentpath"]="Current path:";
 $lang['newdirname']="Create new directory:";
