@@ -1,13 +1,13 @@
 <?php
-$lang['friendlyname'] = 'Gestionnaire de Fichiers';
-$lang['permission'] = 'Utilisation du Gestionnaire de Fichiers';
-$lang['permissionadvanced'] = 'Utilisation avanc&eacute;e du Gestionnaire de Fichiers';
-$lang['moddescription'] = 'Gestion des fichiers et dossiers dans la section &quot;uploads&quot; de CMSMS';
-$lang['installed'] = 'La version %s du Gestionnaire de Fichiers a &eacute;t&eacute; install&eacute;e';
-$lang['postinstall'] = 'Le module Gestionnaire de Fichiers a &eacute;t&eacute; install&eacute;';
-$lang['uninstalled'] = 'Le module  Gestionnaire de Fichiers a &eacute;t&eacute; d&eacute;sinstall&eacute;';
-$lang['really_uninstall'] = '\312tes-vous s\373r de vouloir d\351sinstaller le module Gestionnaire de Fichiers ?';
-$lang['upgraded'] = 'Le module Gestionnaire de Fichiers a &eacute;t&eacute; mis &agrave; jour &agrave; la version %s';
+$lang['friendlyname'] = 'Gestionnaire de fichiers';
+$lang['permission'] = 'Utilisation du Gestionnaire de fichiers';
+$lang['permissionadvanced'] = 'Utilisation avanc&eacute;e du Gestionnaire de fichiers';
+$lang['moddescription'] = 'Gestion des fichiers et dossiers dans le dossier &quot;uploads&quot; de CMSMS';
+$lang['installed'] = 'La version %s du Gestionnaire de fichiers a &eacute;t&eacute; install&eacute;e';
+$lang['postinstall'] = 'Le module Gestionnaire de fichiers a &eacute;t&eacute; install&eacute;';
+$lang['uninstalled'] = 'Le module Gestionnaire de fichiers a &eacute;t&eacute; d&eacute;sinstall&eacute;';
+$lang['really_uninstall'] = '\312tes-vous s\373r(e) de vouloir d\351Le module Gestionnaire de fichiers a &eacute;t&eacute; d&eacute;sinstall&eacute;sinstaller le module Gestionnaire de fichiers ?';
+$lang['upgraded'] = 'Le module Gestionnaire de fichiers a &eacute;t&eacute; mis &agrave; jour &agrave; la version %s';
 $lang['fileview'] = 'Vue fichier';
 $lang['switchtofileview'] = 'Passer en visualisateur de fichier';
 $lang['settings'] = 'Param&egrave;tres';
@@ -23,7 +23,7 @@ $lang['delete'] = 'Supprimer';
 $lang['notwritable'] = '&Eacute;criture impossible';
 $lang['filetoobig'] = 'Taille trop grosse. T&eacute;l&eacute;chargement annul&eacute;.';
 $lang['unknown'] = 'Inconnu';
-$lang['fileoutsideuploads'] = 'Vous n&#039;&ecirc;tes pas autoris&eacute; &agrave; modifier des fichiers en dehors du dossier upload ! (Exige l&#039;autorisation d&#039;activer le mode avanc&eacute;)';
+$lang['fileoutsideuploads'] = 'Vous n&#039;&ecirc;tes pas autoris&eacute; &agrave; modifier des fichiers en dehors du dossier &quot;uploads&quot; ! (Exige l&#039;autorisation d&#039;activer le mode avanc&eacute;)';
 $lang['writable'] = '&Eacute;criture';
 $lang['writeprotected'] = 'Prot&eacute;g&eacute; en &eacute;criture';
 $lang['bytes'] = 'octets';
@@ -37,8 +37,8 @@ $lang['fileno'] = 'Fichier n&deg;&nbsp;';
 $lang['subdirs'] = 'sous-dossiers';
 $lang['subdir'] = 'sous-dossier';
 $lang['and'] = 'et';
-$lang['confirmsingledelete'] = '&Ecirc;tes-vous s&ucirc;r ?';
-$lang['confirmsingledirdelete'] = '&Ecirc;tes-vous s&ucirc;r de supprimer ce dossier ?';
+$lang['confirmsingledelete'] = '&Ecirc;tes-vous s&ucirc;r(e) ?';
+$lang['confirmsingledirdelete'] = '&Ecirc;tes-vous s&ucirc;r(e) de supprimer ce dossier ?';
 $lang['dirtreedeletesuccess'] = 'Le dossier a &eacute;t&eacute; supprim&eacute; avec succ&egrave;s';
 $lang['dirtreedeletefail'] = 'Une erreur est survenue lors de la suppression du dossier. Une partie des fichiers sont effac&eacute;s, cependant.';
 $lang['singlefiledeletesuccess'] = 'Le fichier a &eacute;t&eacute; supprim&eacute; avec succ&egrave;s';
@@ -48,8 +48,8 @@ $lang['filedeletefail'] = ' n&#039;a pas &eacute;t&eacute; supprim&eacute;, une
 $lang['singledirdeletesuccess'] = 'Le dossier a &eacute;t&eacute; supprim&eacute; avec succ&egrave;s';
 $lang['singledirdeletefail'] = 'Une erreur est survenue lors de la suppression du dossier (est-il vide?)';
 $lang['deleteselected'] = 'Supprimer les fichiers s&eacute;lectionn&eacute;s';
-$lang['confirmselected'] = '&Ecirc;tes-vous s&ucirc;r ?';
-$lang['confirmdeleteselected'] = '&Ecirc;tes-vous s&ucirc;r que les fichiers s&eacute;lectionn&eacute;s peuvent &ecirc;tre supprim&eacute;s ? ';
+$lang['confirmselected'] = '&Ecirc;tes-vous s&ucirc;r(e) ?';
+$lang['confirmdeleteselected'] = '&Ecirc;tes-vous s&ucirc;r(e) que les fichiers s&eacute;lectionn&eacute;s peuvent &ecirc;tre supprim&eacute;s ? ';
 $lang['deleteselectedcancelled'] = 'Annulation de la s&eacute;lection des fichiers';
 $lang['recursetext'] = 'R&eacute;cursion dans les sous-dossier';
 $lang['nofilesselected'] = 'Aucun fichier s&eacute;lectionn&eacute;';
@@ -96,6 +96,7 @@ $lang['unpacksuccess'] = 'Votre fichier a &eacute;t&eacute; correctement d&eacut
 $lang['unpackfail'] = 'Une erreur est survenue lors de la d&eacute;compression du fichier&nbsp;:';
 $lang['packfileopenfail'] = 'L&#039;ouverture du fichier archive n&#039;a pas pu s&#039;effectuer par d&eacute;compression (format non-support&eacute;)';
 $lang['packfilewritefail'] = 'L&#039;ouverture du fichier %s en &eacute;criture n&#039;a pas pu s&#039;effectuer';
+$lang['containsillegalchars'] = 'Le nom du fichier contient un ou plusieurs caract&egrave;res non autoris&eacute;s (&#039;,&quot;,+,*,\,/,&amp;,$)';
 $lang['currentpath'] = 'Chemin actuel&nbsp;:';
 $lang['newdirname'] = 'Cr&eacute;er un nouveau dossier&nbsp;:';
 $lang['newdirsuccess'] = 'Le dossier a &eacute;t&eacute; cr&eacute;&eacute; avec succ&egrave;s';
@@ -124,11 +125,12 @@ $lang['showhiddenfiles'] = 'Afficher les fichiers cach&eacute;s';
 $lang['settingsconfirmsingledelete'] = 'Confirmer la suppression d&#039;un fichier seul ?';
 $lang['settingssaved'] = 'Param&egrave;tres sauvegard&eacute;s';
 $lang['help'] = '		<h3>Que fait ce module ?</h3>
-		<p>Le module Gestionnaire de Fichiers (File Manager) offre des fonctions de gestion de fichiers, et esp&egrave;re remplacer avantageusement le Gestionnaire de Fichiers actuel</p>
+		<p>Le module Gestionnaire de fichiers (File Manager) offre des fonctions de gestion de fichiers</p>
 		<h3>Comment l&#039;utiliser ?</h3>
-		<p>S&eacute;lectionnez-le depuis le menu Contenu de l&#039;administration. Si l&#039;ancien gestionnaire de fichier est pr&eacute;sent, vous devriez trouver celui-ci un peu plus bas dans le menu.</p>';
-$lang['utma'] = '156861353.792492233.1240651490.1240651490.1240651490.1';
+		<p>S&eacute;lectionnez-le depuis le menu Contenu de l&#039;administration. Il vous servira &agrave; uploader, d&eacute;placer ou effacer les fichiers contenus dans le dossier &quot;uploads&quot; du site. En mode avanc&eacute;, vous aurez alors acc&egrave;s &agrave; tout les fichiers (non recommand&eacute;)</p>';
+$lang['qca'] = 'P0-1624099198-1262715852421';
+$lang['utma'] = '156861353.871440515.1266773941.1266773941.1266773941.1';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1240651490.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmz'] = '156861353.1266773941.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
