@@ -96,6 +96,7 @@ $lang['unpacksuccess'] = 'ble pakket ut';
 $lang['unpackfail'] = 'feilet med denne feilmeldingen:';
 $lang['packfileopenfail'] = 'Kunne ikke &aring;pne den pakkede filen for utpakking (format som ikke st&oslash;ttes?)';
 $lang['packfilewritefail'] = 'Kunne ikke &aring;pne filen %s for skriving';
+$lang['containsillegalchars'] = 'Filnavnet inneholder et eller flere ugyldige tegn (&#039;,&quot;,+,*,\,/,&amp;,$)';
 $lang['currentpath'] = 'Gjeldende bane:';
 $lang['newdirname'] = 'Opprett ny katalog:';
 $lang['newdirsuccess'] = 'Katalogen ble opprettet';
@@ -127,8 +128,9 @@ $lang['help'] = '		<h3>Hva gj&oslash;r denne?</h3>
 		<p>Denne modulen tilbyr filbehandlingsfunksjoner.</p>
 		<h3>Hvordan bruker jeg denne?</h3>
 		<p>Velg den fra innholdsmenyen i  administrasjon.</p>';
-$lang['utmz'] = '156861353.1243118268.1334.33.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
-$lang['utma'] = '156861353.179052623084110100.1210423577.1244328409.1244385106.1398';
+$lang['utmz'] = '156861353.1250297380.1752.42.utmccn=(referral)|utmcsr=helminsen.no|utmcct=/install/upgrade.php|utmcmd=referral';
+$lang['utma'] = '156861353.179052623084110100.1210423577.1255265025.1255273279.1976';
+$lang['qca'] = '1210971690-27308073-81952832';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1244385106';
+$lang['utmb'] = '156861353.3.10.1255273279';
 ?>
\ No newline at end of file
