@@ -96,10 +96,12 @@ $lang['unpacksuccess'] = 'je uspe&scaron;no ekstrahirana';
 $lang['unpackfail'] = ' neuspe&scaron;no z napako:';
 $lang['packfileopenfail'] = 'Ne morem odpreti kompresirane datoteke za ekstrahiranje (nepodprt format?)';
 $lang['packfilewritefail'] = 'Ne morem odpreti datoteke &amp;s za pisanje';
+$lang['containsillegalchars'] = 'Datoteka vsebuje nedovoljene znake (&#039;,&quot;,+,*,\,/,&amp;,$)';
 $lang['currentpath'] = 'Trenutna pot:';
 $lang['newdirname'] = 'Ustvari novo mapo:';
 $lang['newdirsuccess'] = 'Mapa je bila uspe&scaron;no ustvarjena';
 $lang['newdirfail'] = 'Napaka pri ustvarjanju nove mape';
+$lang['invalidnewdir'] = 'Ime mape ne sme vsebovati rezerviranih znakov, kot so  /, \ and &#039;..&#039; ';
 $lang['filedateformat'] = 'd.m.Y H:m:s';
 $lang['iconsize'] = 'Velikost ikone';
 $lang['smallicons'] = 'Majhne ikone';
@@ -126,8 +128,9 @@ $lang['help'] = '		<h3>Kaj to počne?</h3>
 		<p>Modul omogoča upravljanje z datotekami</p>
 		<h3>Kako to uporabim?</h3>
 		<p>Izberite iz menija vsebina v administraciji. </p>';
-$lang['utma'] = '156861353.946566493304929700.1236179099.1236861512.1239346306.7';
-$lang['utmz'] = '156861353.1236861512.6.5.utmccn=(referral)|utmcsr=jupiter.sinusiks.net|utmcct=/admin/addtemplate.php|utmcmd=referral';
-$lang['utmb'] = '156861353.2.10.1239346306';
+$lang['utma'] = '156861353.1722464354432002000.1251370098.1258962106.1259238241.16';
+$lang['utmz'] = '156861353.1259238241.16.15.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cms made simple';
+$lang['qca'] = 'P0-1580489763-1251370099388';
+$lang['utmb'] = '156861353.2.10.1259238241';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
