@@ -13,13 +13,7 @@
 $this->RemovePermission('Use Filemanager'); //Used in some old versions
 $this->RemovePermission('Use Filemanager Advanced');
 
-$this->RemovePreference("uploadboxes");
-$this->RemovePreference("iconsize");
-$this->RemovePreference("advancedmode");
-$this->RemovePreference("showhiddenfiles");
-$this->RemovePreference("confirmsingledelete");
-// remove the preference
-//$this->RemovePreference("sing_loudly");
+$this->RemovePreference();
 
 // put mention into the admin log
 $this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('uninstalled'));
