@@ -18,37 +18,42 @@ else if (isset($params['submit']) || isset($params['apply']))
 {
 	if ($newtemplate == '')
 	{
-		$error = $this->Lang('notemplatename');
+	  $error = $this->Lang('notemplatename');
 	}
 	else if( endswith($newtemplate,'.tpl') )
-	  {
-	    $error = $this->Lang('error_templatename');
-	  }
+	{
+	  $error = $this->Lang('error_templatename');
+	}
 	else if ($content == '')
 	{
-		$error = $this->Lang('nocontent');
+	  $error = $this->Lang('nocontent');
+	}
+	else if ($newtemplate != $tplname && $this->GetTemplate($newtemplate) != '')
+	{
+	  // template name changed, and new template already exists.
+	  $error = $this->Lang('templateexists');
 	}
 	else
 	{
-		if ($newtemplate != $tplname && $this->GetTemplate($newtemplate) != '')
-		{
-			$error = $this->Lang('templateexists');
-		}
-		else
-		{
-			if ($newtemplate != $tplname)
-			{
-				$this->DeleteTemplate($tplname);
-			}
-			$this->SetTemplate($newtemplate, $content);
-			$default_template = $this->GetPreference('default_template');
-			if( $tplname == $default_template )
-			  {
-			    $this->SetPreference('default_template',$newtemplate);
-			  }
-			if (isset($params['submit']))
-				$this->Redirect($id, 'defaultadmin', $returnid);
-		}
+	  if ($newtemplate != $tplname)
+	  {
+	    // template name changed, so delete the old one.
+	    $this->DeleteTemplate($tplname);
+	  }
+	  
+	  $this->SetTemplate($newtemplate, $content);
+	  $params['tplname'] = $newtemplate;
+	  
+	  $default_template = $this->GetPreference('default_template');
+	  if( $tplname == $default_template )
+	  {
+	    $this->SetPreference('default_template',$newtemplate);
+	  }
+	  
+	  if (isset($params['submit']))
+	  {
+	    $this->Redirect($id, 'defaultadmin', $returnid);
+	  }
 	}
 }
 else
