@@ -1,14 +1,17 @@
 <?php
+$lang['help_childrenof'] = 'Mit dieser Option werden nur die Men&uuml;-Eintr&auml;ge angezeigt, die der Seite mit der ausgew&auml;hlten Seiten-ID oder dem Seiten-Alias untergeordnet sind.  Beispiel: <code>{menu childrenof=$page_alias}</code> zeigt nur die untergeordneten Seiten der aktuell angezeigten Seite.';
+$lang['usage'] = 'Verwendung';
 $lang['help_loadprops'] = 'Wenn Sie in Ihrem Men&uuml;Manager-Template die erweiterten M&ouml;glichkeiten nutzen m&ouml;chten, sollten Sie diesen Parameter verwenden. Ist dieser Parameter gesetzt, werden alle Content-Eigenschaften (wie zum Beispiel extra1, image, thumbnail usw.) jedes $node-Objekts geladen. Damit steigen zwar die Anzahl der Datenbankabfragen und der Speicherbedarf dramatisch an, aber es er&ouml;ffnen sich damit weitere M&ouml;glichkeiten f&uuml;r noch ausgefeiltere Men&uuml;s.';
 $lang['readonly'] = 'Nur lesen';
 $lang['error_templatename'] = 'Sie k&ouml;nnen kein Template festlegen, dessen Name auf .tpl endet.';
 $lang['this_is_default'] = 'Voreingestelltes Men&uuml;-Template';
 $lang['set_as_default'] = 'Als voreingestelltes Men&uuml;-Template festlegen';
 $lang['default'] = 'Voreingestellt';
-$lang['templates'] = 'Templates';
+$lang['templates'] = 'Templates ';
 $lang['addtemplate'] = 'Template hinzuf&uuml;gen';
 $lang['areyousure'] = 'Wollen Sie dies wirklich l&ouml;schen?';
 $lang['changelog'] = '	<ul>
+<li>1.6.2 - Can no longer delete default template, fix problem with default database templates.</li>
 <li>1.6.1 - Add created and modified entries on each node.</li>
 <li>1.6 - Re-design admin interface, allow setting the default menu manager template.</li>
         <li>1.5.4 - Minor bugfix, now require CMS 1.5.3.</li>
@@ -90,8 +93,9 @@ $lang['notemplatefiles'] = 'Keine Template-Datei in %s';
 $lang['notemplatename'] = 'Es wurde kein Template-Name vergeben.';
 $lang['templatecontent'] = 'Template-Inhalt';
 $lang['templatenameexists'] = 'Ein Template mit diesem Namen existiert bereits.';
-$lang['utma'] = '156861353.1298823970.1246873322.1246873322.1246873322.1';
-$lang['utmb'] = '156861353';
+$lang['qca'] = 'P0-75091478-1268421814072';
+$lang['utmz'] = '156861353.1275330212.27.18.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['utma'] = '156861353.728989452.1268567475.1275424723.1275560971.29';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1246873322.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
