@@ -1,5 +1,7 @@
 <?php
-$lang['help_loadprops'] = 'Utiliser ce param&egrave;tre si des propri&eacute;t&eacute;s avanc&eacute;es sont utilis&eacute;es dans votre gabarit de gestionnaire de menu. Ce param&egrave;tre va forcer le chargement des toutes les propri&eacute;t&eacute;s des contenus de tous les n&oelig;uds (tel que extra1, image, thumbnail, etc). Ceci va augmenter tr&egrave;s fortement le nombre de requ&ecirc;tes pour construire un menu ainsi que la consommation en m&eacute;moire, mais permet de g&eacute;rer des menus plus avanc&eacute;s';
+$lang['help_childrenof'] = 'Cette option affichera le menu uniquement des &eacute;l&eacute;ments qui sont descendants de l&#039;ID de la page s&eacute;lectionn&eacute;e ou de l&#039;alias. par exemple : <code>{menu childrenof=$page_alias}</code> affichera uniquement les enfants de la page courante.';
+$lang['usage'] = 'Balise pour utiliser le menu';
+$lang['help_loadprops'] = 'Utiliser ce param&egrave;tre lorsque vous n&#039;utilisez PAS les propri&eacute;t&eacute;s avanc&eacute;es  dans votre gabarit de gestionnaire de menu. Ce param&egrave;tre permet de d&eacute;sactiver le chargement de toutes les propri&eacute;t&eacute;s des contenus de tous les n&oelig;uds (tel que extra1, image, thumbnail, etc). Cette op&eacute;ration r&eacute;duira consid&eacute;rablement le nombre de requ&ecirc;tes n&eacute;cessaires &agrave; la construction d&#039;un menu en contrepartie la consommation en m&eacute;moire augmente, mais cela permet de g&eacute;rer des menus plus avanc&eacute;s.';
 $lang['readonly'] = 'lecture seule';
 $lang['error_templatename'] = 'Vous ne pouvez pas sp&eacute;cifier un nom de gabarit qui se terminent par. tpl';
 $lang['this_is_default'] = 'Gabarit menu par d&eacute;faut ';
@@ -7,8 +9,9 @@ $lang['set_as_default'] = 'D&eacute;finir comme gabarit de menu par d&eacute;fau
 $lang['default'] = 'D&eacute;faut';
 $lang['templates'] = 'Gabarits';
 $lang['addtemplate'] = 'Ajouter un gabarit';
-$lang['areyousure'] = '&Ecirc;tes-vous s&ucirc;r de vouloir supprimer&nbsp;?';
+$lang['areyousure'] = '&Ecirc;tes-vous s&ucirc;r(e) de vouloir supprimer&nbsp;?';
 $lang['changelog'] = '	<ul>
+<li>1.6.3 - Adds usage column.</li>
 <li>1.6.2 - Can no longer delete default template, fix problem with default database templates.</li>
 <li>1.6.1 - Add created and modified entries on each node.</li>
 <li>1.6 - Re-design admin interface, allow setting the default menu manager template.</li>
@@ -70,12 +73,15 @@ $lang['help'] = '	<h3>Que fait ce module&nbsp;?</h3>
 <li>$node->raw_menutext -- Texte du menu sans convertir les entit&eacute;s html</li>
 			<li>$node->alias -- Alias de la page</li>
 
-			<li>$node->extra1 -- Applicable uniquement lorsque le param&egrave;tre loadprops est dans la balise (tag) menu, ce champ contient la valeur de la propri&eacute;t&eacute; de page extra1.</li>
-			<li>$node->extra2 -- Applicable uniquement lorsque le param&egrave;tre loadprops est dans la balise (tag) menu, ce champ contient la valeur de la propri&eacute;t&eacute; de page extra2.</li>
-			<li>$node->extra3 -- Applicable uniquement lorsque le param&egrave;tre loadprops est dans la balise (tag) menu, ce champ contient la valeur de la propri&eacute;t&eacute; de page extra3.</li>
-			<li>$node->image -- Applicable uniquement lorsque le param&egrave;tre loadprops est dans la balise (tag) menu, ce champ contient la valeur de la propri&eacute;t&eacute; de page de l&#039;image(si non vide).</li>
-			<li>$node->thumbnail -- Applicable uniquement lorsque le param&egrave;tre loadprops est dans la balise (tag) menu, ce champ contient la valeur de la propri&eacute;t&eacute; de page de la vignette del&#039;image(si non vide).</li>
-			<li>$node->target -- Applicable uniquement lorsque le param&egrave;tre loadprops est dans la balise (tag) menu, ce champ contient la cible du lien. Sera vide si le contenu n&#039;est pas d&eacute;fini.</li>
+			<li>$node->extra1 -- Ce champ contient la valeur de la propri&eacute;t&eacute; de page extra1, sauf si le param&egrave;tre loadprops, contenu dans la balise (tag) menu, est r&eacute;gl&eacute; pour ne PAS charger les propri&eacute;t&eacute;s.</li>
+
+			<li>$node->extra2 -- Ce champ contient la valeur de la propri&eacute;t&eacute; de page extra2, sauf si le param&egrave;tre loadprops , contenu dans la balise (tag) menu, est r&eacute;gl&eacute; pour ne PAS charger les propri&eacute;t&eacute;s.</li>
+
+			<li>$node->extra3 -- Ce champ contient la valeur de la propri&eacute;t&eacute; de page extra3, sauf si le param&egrave;tre loadprops , contenu dans la balise (tag) menu, est r&eacute;gl&eacute; pour ne PAS charger les propri&eacute;t&eacute;s.</li>
+
+			<li>$node->image -- Ce champ contient la valeur de la propri&eacute;t&eacute; de page de l&#039;image(si non vide), sauf si le param&egrave;tre loadprops , contenu dans la balise (tag) menu, est r&eacute;gl&eacute; pour ne PAS charger les propri&eacute;t&eacute;s.</li>
+			<li>$node->thumbnail -- Ce champ contient la valeur de la propri&eacute;t&eacute; de page de la vignette del&#039;image(si non vide), sauf si le param&egrave;tre loadprops , contenu dans la balise (tag) menu, est r&eacute;gl&eacute; pour ne PAS charger les propri&eacute;t&eacute;s.</li>
+			<li>$node->target -- Cette zone contient la cible du lien (si non vide), sauf si le param&egrave;tre loadprops , contenu dans la balise (tag) menu, est r&eacute;gl&eacute; pour ne PAS charger les propri&eacute;t&eacute;s.</li>
 
 			<li>$node->index -- Position de cet &eacute;l&eacute;ment dans le menu</li>
 			<li>$node->parent -- Renvoie true (vrai) si cet &eacute;l&eacute;ment est le parent de la page actuelle</li>
@@ -89,9 +95,9 @@ $lang['notemplatefiles'] = 'Aucun gabarit sous forme de fichier dans %s';
 $lang['notemplatename'] = 'Aucun nom de gabarit entr&eacute;';
 $lang['templatecontent'] = 'Contenu du gabarit&nbsp;';
 $lang['templatenameexists'] = 'Un gabarit du m&ecirc;me nom existe d&eacute;j&agrave;';
-$lang['utma'] = '156861353.3936683226868494000.1247055583.1253172677.1253192380.57';
-$lang['utmz'] = '156861353.1253192380.57.28.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/feature_request/list/740|utmcmd=referral';
-$lang['qca'] = '1246563679-91537581-2740096';
+$lang['qca'] = 'P0-607081841-1275030970801';
+$lang['utma'] = '156861353.930053595.1275069064.1275069064.1275069064.1';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1275069064.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
