@@ -1,4 +1,6 @@
 <?php
+$lang['help_childrenof'] = 'Nastavenie, ktor&eacute; zobraz&iacute; iba podraden&eacute; prvky položky (m&ocirc;že byť id str&aacute;nky, alias).  pr&iacute;klad: <code>{menu childrenof=$page_alias}</code>';
+$lang['usage'] = 'Použitie';
 $lang['help_loadprops'] = 'Use this parameter when using advanced properties in your menu manager template.  This parameeter will force the loading of all content properties for each node (such as extra1, image, thumbnail, etc).  and will dramatically increase the number of queries required to build a menu, and increase memory requirements, but will allow for much more advanced menus';
 $lang['readonly'] = 'iba na č&iacute;tanie';
 $lang['error_templatename'] = 'Nem&ocirc;žete zadať  n&aacute;zov &scaron;abl&oacute;ny s koncovkou tpl.';
@@ -78,8 +80,10 @@ $lang['notemplatefiles'] = 'Žiadny s&uacute;bor &scaron;abl&oacute;n v  %s';
 $lang['notemplatename'] = 'Nezadan&yacute; n&aacute;zov &scaron;abl&oacute;ny.';
 $lang['templatecontent'] = 'Obsah &scaron;abl&oacute;ny';
 $lang['templatenameexists'] = '&Scaron;abl&oacute;na s t&yacute;mto n&aacute;zvom existuje';
-$lang['utmz'] = '156861353.1242823757.727.119.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
-$lang['utma'] = '156861353.4300742689275601400.1213256953.1242818813.1242823757.727';
+$lang['qca'] = 'P0-1608926040-1271144175783';
+$lang['utma'] = '156861353.786385904.1271157997.1279783450.1279798608.56';
+$lang['utmz'] = '156861353.1279639848.54.48.utmcsr=geekmoot.com|utmccn=(referral)|utmcmd=referral|utmcct=/2010/news/7/15/Call-for-Papers/';
+$lang['chartbeat2'] = '87v0u4nbwegh3lki';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1242823757';
 ?>
\ No newline at end of file
