@@ -1,4 +1,5 @@
 <?php
+$lang['usage'] = 'Anv&auml;ndning';
 $lang['help_loadprops'] = 'Anv&auml;nd denna parameter n&auml;r du anv&auml;nder avancerade egenskaper i din meny managermall. Denna parameter tvingar laddningen av all inneh&aring;ll  f&ouml;r varje node (som EXTRA1, bild, miniatyrbilder, etc). och kommer att dramatiskt &ouml;ka antalet s&ouml;kfr&aring;gor som beh&ouml;vs f&ouml;r att bygga upp en meny och minne, men kommer att m&ouml;jligg&ouml;ra mer avancerade menyer.';
 $lang['readonly'] = 'Skrivskyddad';
 $lang['error_templatename'] = 'Du kan inte specificera en mall med fil&auml;ndelsen .tpl';
@@ -71,9 +72,9 @@ $lang['notemplatefiles'] = 'Inga filbaserade mallar i %s';
 $lang['notemplatename'] = 'Inget mallnamn angivet';
 $lang['templatecontent'] = 'Mallinneh&aring;ll';
 $lang['templatenameexists'] = 'En mall med detta namnet finns redan';
-$lang['utma'] = '156861353.1202846489.1249038202.1250445244.1250447762.35';
-$lang['utmz'] = '156861353.1250445244.34.5.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
-$lang['qca'] = '4a72d21a-ee785-21917-f08f8';
+$lang['utma'] = '156861353.906052642.1267835734.1278791483.1278872739.125';
+$lang['utmz'] = '156861353.1278791483.124.8.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/|utmcmd=referral';
+$lang['qca'] = 'P0-1605183070-1267835733865';
+$lang['utmb'] = '156861353.1.10.1278872739';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1250447762';
 ?>
\ No newline at end of file
