@@ -6,8 +6,19 @@ $lang['error_nomatchingmodules'] = 'Errore: non trovo nessun modulo nel reposito
 $lang['error_nomodules'] = 'Errore: could not retrieve list of installed modules';
 $lang['upgrade_available'] = 'Nuova versione aggiornata (%s), Vioi avete (%s)';
 $lang['newversions'] = 'Moduli Installati';
-$lang['error_depends'] = 'Una o pi&ugrave; dipendenze non sono installate. Voi dovete installare prima le dipendenze';
+$lang['notice_depends'] = '%s dipende dalla seguente azione. Click su &quot;Installa&quot; per andare avanti.';
+$lang['install_submit'] = 'Installa';
+$lang['depend_upgrade'] = 'Modulo %s necessita di essere aggiornato alla versione %s.';
+$lang['depend_install'] = 'Modulo %s (versione %s o seguente) necessita di essere installato.';
+$lang['depend_activate'] = 'Modulo %s necessita di essere attivato.';
+$lang['action_activated'] = 'Modulo %s &egrave; stato attivato.';
+$lang['action_installed'] = 'Modulo %s &egrave; stato installato con il seguente messaggi(o): %s';
+$lang['action_upgraded'] = 'Modulo %s &egrave; stato aggiornato';
+$lang['title_installation_complete'] = 'Processo di installazione completato!';
+$lang['install_with_deps'] = 'Valutazione di tutte le dipendenze e installazione';
 $lang['msg_nodependencies'] = 'Questo file non ha evidenziato nessuna dipendenza';
+$lang['error_upgrade'] = 'Aggiornamento del modulo %s fallito!';
+$lang['error_skipping'] = 'Tralascio l&#039;installazione/aggiornamento di %s per errori nelle dipendenze. Si prega di vedere il messaggio sottostante e riprovare.';
 $lang['dependstxt'] = 'Dipendenze';
 $lang['use_at_your_own_risk'] = 'Usate a Vostro rischio';
 $lang['compatibility_disclaimer'] = 'I moduli visualizzati sono contribuiti sia dagli sviluppatori del CMS che da terze parti indipendenti. Noi non garantiamo che i moduli disponibili siano funzionanti, testati o compatibili con il vostro sistema. Siete invitati a leggere le informazioni trovate nei collegamenti Aiuto e Informazioni di ciascun modulo prima di installarlo.';
@@ -25,7 +36,8 @@ $lang['prompt_dl_chunksize'] = 'Dimensione del pacchetto di scaricamento (Kb)';
 $lang['text_dl_chunksize'] = 'La quantit&agrave; massima di dati da scaricare dal server in un pacchetto (quando installi un modulo)';
 $lang['error_nofilesize'] = 'Nessun parametro dimensione file inserito';
 $lang['error_nofilename'] = 'Nessun parametro nome file inserito';
-$lang['error_checksum'] = 'Errore checksum. Indica probabilmente un file corrotto quando &egrave; stato inviato al repository o un problema nello scaricamento verso la vostra macchina.';
+$lang['error_unsatisfiable_dependency'] = 'Non posso trovare il modulo richiesto &quot;%s&quot; (versione %s o seguente) nel deposito moduli. E&#039; direttamente richiesto da %s; questo potrebbe indicare un problema con la versione di questo modulo. Si prega di contattare l&#039;autore del modulo.';
+$lang['error_checksum'] = 'Errore checksum. Indica probabilmente un file corrotto quando &egrave; stato inviato al deposito moduli o un problema nello scaricamento verso la vostra macchina.';
 $lang['cantdownload'] = 'Non posso scaricare';
 $lang['download'] = 'Scarica e Installa';
 $lang['error_moduleinstallfailed'] = 'Installazione Modulo fallita';
@@ -33,16 +45,20 @@ $lang['error_connectnomodules'] = 'Sebbene sia stata effettuata una connessione
 $lang['submit'] = 'Invia';
 $lang['text_repository_url'] = 'L&#039;indirizzo dovrebbe essere della forma http://www.mycmssite.com/path/soap.php?module=ModuleRepository';
 $lang['prompt_repository_url'] = 'Indirizzo del Deposito Moduli:';
+$lang['title_installation'] = 'Installazione';
 $lang['availmodules'] = 'Moduli Disponibili';
 $lang['preferences'] = 'Preferenze';
 $lang['preferencessaved'] = 'Preferenze salvate';
 $lang['repositorycount'] = 'Moduli trovati nel Deposito Moduli';
 $lang['instcount'] = 'Moduli attualmente installati';
 $lang['availablemodules'] = 'Stato attuale dei moduli disponibili dal Deposito Moduli attuale';
+$lang['time_warning'] = 'La lista di installazione ha pi&ugrave; di uno o due moduli. Prestare attenzione che l&#039;installazione potrebbe impiegare alcuni minuti. Si prega di essere pazienti!';
 $lang['helptxt'] = 'Aiuto';
 $lang['abouttxt'] = 'Informazioni';
 $lang['xmltext'] = 'File XML';
 $lang['nametext'] = 'Nome Modulo';
+$lang['mod_name_ver'] = '%s versione %s ';
+$lang['unknown'] = 'Sconosciuto';
 $lang['vertext'] = 'Versione';
 $lang['sizetext'] = 'Dimensione (Kilobytes)';
 $lang['statustext'] = 'Stato/Azione';
@@ -53,6 +69,7 @@ $lang['onlynewesttext'] = 'Mostra solo le nuove versioni';
 $lang['upgrade'] = 'Aggiorna';
 $lang['error_nosoapconnect'] = 'Non posso connettermi al server SOAP';
 $lang['error_soaperror'] = 'Problema SOAP';
+$lang['soaperror'] = 'Errore SOAP: %s';
 $lang['error_norepositoryurl'] = 'L&#039;indirizzo del Deposito Moduli non &egrave; stato specificato';
 $lang['friendlyname'] = 'Gestore Moduli';
 $lang['postinstall'] = 'Il Gestore Moduli &egrave; stato installato con successo.';
@@ -62,6 +79,7 @@ $lang['uninstalled'] = 'Modulo disinstallato.';
 $lang['installed'] = 'Versione del modulo %s installata.';
 $lang['upgraded'] = 'Modulo aggiornato alla versione %s.';
 $lang['moddescription'] = 'Un client per il Deposito Moduli, questo modulo permette di installare moduli da siti remoti senza la necessit&agrave; di ftp, o estarre archivi zip. I file moduli XML sono scaricati usando SOAP, verificati la loro integrit&agrave; e poi espansi automaticamente.';
+$lang['back_to_module_manager'] = '&laquo; Ritorna al Module Manager';
 $lang['error'] = 'Errore!';
 $lang['admindescription'] = 'Uno strumento per prelevare e installare moduli da server remoti.';
 $lang['accessdenied'] = 'Accesso negato. Si prega di controllare i vostri permessi.';
@@ -99,6 +117,19 @@ Added a warning message to the top of the admin display.
 <li>Version 1.3 May, 2009.<br/>
 Added dependency checking.
 </li>
+<li>Version 1.3.3 March, 2010.<br/>
+<ul>
+  <li>PHP 5.x improvements (specifically remove warnings for PHP 5.3)</li>
+  <li>Minor bug fixes.</li>
+</ul>
+</li>
+<li>Version 1.4 June, 2010.<br/>
+<ul>
+  <li>Implemented automatic dependency calculation, and one-click installation.</li>
+  <li>Assorted usability improvements.</li>
+  <li>Minor bug fixes.</li>
+</ul>
+</li>
 </ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>A client for the ModuleRepository, this module allows previewing, and installing modules from remote sites without the need for ftping, or unzipping archives.  Module XML files are downloaded using SOAP, integrity verified, and then expanded automatically.</p>
@@ -110,8 +141,9 @@ $lang['help'] = '<h3>What Does This Do?</h3>
 <h3>Copyright and License</h3>
 <p>Copyright &copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
 <p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';
-$lang['utma'] = '156861353.880130626.1236353467.1240505117.1241641977.36';
-$lang['utmz'] = '156861353.1240505117.35.31.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['qca'] = 'P0-1187230324-1271659236866';
+$lang['utma'] = '156861353.976402040.1271759292.1276850904.1277118686.4';
+$lang['utmz'] = '156861353.1277118686.4.4.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
