@@ -42,12 +42,12 @@ class News extends CMSModule
 
 	function GetVersion()
 	{
-		return '2.10.3';
+		return '2.10.6';
 	}
 
 	function MinimumCMSVersion()
 	{
-		return '1.6.1';
+		return '1.8-beta1';
 	}
 
 	function GetAdminDescription()
@@ -324,7 +324,63 @@ class News extends CMSModule
 	      $result[2] = $this->CreateLink('cntnt01', 'detail', $returnid, '', array('articleid' => $articleid) ,'', true, false, '', true, $prettyurl);
 	    }
 	}
-		
+	
+      return $result;
+    }
+
+
+    function SearchResultWithParams($returnid, $articleid, $attr = '', $params = '')
+    {
+      global $gCms;
+      $result = array();
+      
+      if ($attr == 'article')
+	{
+	  $db =& $this->GetDb();
+	  $q = "SELECT news_title FROM ".cms_db_prefix()."module_news WHERE news_id = ?";
+	  $dbresult = $db->Execute( $q, array( $articleid ) );
+	  
+	  if ($dbresult)
+	    {
+	      $row = $dbresult->FetchRow();
+	      
+	      //0 position is the prefix displayed in the list results.
+	      $result[0] = $this->GetFriendlyName();
+	      
+	      //1 position is the title
+	      $result[1] = $row['news_title'];
+	      
+	      //2 position is the URL to the title.
+	      $detailpage = $returnid;
+	      if( isset($params['detailpage']) )
+		{
+		  $manager = $gCms->GetHierarchyManager();
+		  $node = $manager->sureGetNodeByAlias($params['detailpage']);
+		  if (isset($node))
+		    {
+		      $detailpage = $node->getID();
+		    }
+		  else
+		    {
+		      $node = $manager->sureGetNodeById($params['detailpage']);
+		      if (isset($node))
+			{
+			  $detailpage = $params['detailpage'];
+			}
+		    }
+		}
+	      if( $detailpage == '' ) $detailpage = $returnid;
+
+	      $aliased_title = munge_string_to_url($row['news_title']);
+	      $prettyurl = 'news/' . $articleid.'/'.$detailpage."/$aliased_title";
+	      $miwdata = array('articleid' => $articleid);
+	      $parms = array();
+	      $parms['articleid'] = $articleid;
+	      
+	      $result[2] = $this->CreateLink('cntnt01', 'detail', $detailpage, '', $parms ,'', true, false, '', true, $prettyurl);
+	    }
+	}
+      
       return $result;
     }
 	
@@ -334,7 +390,7 @@ class News extends CMSModule
       $db =& $this->GetDb();
 		
       $query = 'SELECT * FROM '.cms_db_prefix().'module_news ORDER BY news_date';
-      $result = &$db->Execute($query);
+      $result = $db->Execute($query);
 
       while ($result && !$result->EOF)
 	{
@@ -707,6 +763,76 @@ class News extends CMSModule
     @$this->SendEvent('NewsArticleDeleted', array('news_id' => $articleid));
   }
 
+
+  function &get_categories($id, &$params, $returnid=-1)
+	{
+	global $gCms;
+	$db = $gCms->GetDb();
+	$depth = 1;
+
+	$query = '
+		SELECT news_category_id, news_category_name, hierarchy, long_name 
+		FROM ' .cms_db_prefix(). 'module_news_categories 
+		WHERE hierarchy not like \'\'
+	';
+	if (isset($params['category']) && $params['category'] != '')
+	{
+		$categories = explode(',', $params['category']);
+		$query .= ' AND (';
+		$count = 0;
+		foreach ($categories as $onecat)
+		{
+			if ($count > 0)
+			{
+				$query .= ' OR ';
+			}
+			if (strpos($onecat, '|') !== FALSE || strpos($onecat, '*') !== FALSE)
+				$query .= "upper(long_name) like upper('". trim(str_replace('*', '%', $onecat)) . "')";
+			else
+				$query .= "news_category_name = '" . trim($onecat). "'";
+			$count++;
+		}
+		$query .= ') ';
+	}
+	$query .= ' ORDER by hierarchy';
+	$dbresult = $db->Execute($query);
+
+	$rowcounter=0;
+	while ($dbresult && $row = $dbresult->FetchRow())
+	{
+		$q2 = "SELECT COUNT(news_id) as cnt FROM ".cms_db_prefix()."module_news WHERE news_category_id=?";
+	    	if (isset($params['showarchive']) && $params['showarchive'] == true) {
+		    $q2 .= " AND (end_time < ".$db->DBTimeStamp(time()).") ";
+		}
+		else
+		{
+		    $q2 .= " AND ((".$db->IfNull('end_time',$db->DBTimeStamp(1))." = ".$db->DBTimeStamp(1).") OR (end_time > ".$db->DBTimeStamp(time()).")) ";
+		}
+		$q2 .= ' AND status = \'published\'';
+
+		$dbres2 = $db->Execute($q2,array($row['news_category_id']));
+		$count = $dbres2->FetchRow();
+		$row['index']=$rowcounter++;
+		$row['count']= $count['cnt'];
+		$row['prevdepth'] = $depth;
+		$depth= count(explode('\.', $row['hierarchy']));
+		$row['depth']=$depth;
+
+		// changes so that parameters supplied to the tag
+		// gets carried down through the links
+		// screw pretty urls
+		$parms = $params;
+		unset($parms['browsecat']);
+		unset($parms['category']);
+		$parms['category_id'] = $row['news_category_id'];
+
+		$row['url'] = $this->CreateLink($id,'default',$params['detailpage']!= ''?$params['detailpage']:$returnid,$row['news_category_name'],$parms,'',true);
+		$items[] = $row;
+	}
+	return $items;
+	}
+
+
   function GetNotificationOutput($priority = 2)
   {
     // if this user has permission to change News articles from
