@@ -7,15 +7,15 @@ $config =& $gCms->GetConfig();
 $detailpage = '';
 if (isset($params['detailpage']))
   {
-    $manager =& $gCms->GetHierarchyManager();
-    $node =& $manager->sureGetNodeByAlias($params['detailpage']);
+    $manager = $gCms->GetHierarchyManager();
+    $node = $manager->sureGetNodeByAlias($params['detailpage']);
     if (isset($node))
       {
 	$detailpage = $node->getID();
       }
     else
       {
-	$node =& $manager->sureGetNodeById($params['detailpage']);
+	$node = $manager->sureGetNodeById($params['detailpage']);
 	if (isset($node))
 	  {
 	    $detailpage = $params['detailpage'];
@@ -63,8 +63,12 @@ $query2 = "
         ";
 
             
-
-if (isset($params["category"]) && $params["category"] != '')
+if( isset($params['category_id']) )
+  {
+    $query1 .= " ( mnc.news_category_id = '".$params['category_id']."' ) AND ";
+    $query2 .= " ( mnc.news_category_id = '".$params['category_id']."' ) AND ";
+  }
+else if (isset($params["category"]) && $params["category"] != '')
   {
     $category = cms_html_entity_decode(trim($params['category']));
     $categories = explode(',', $category);
@@ -93,11 +97,6 @@ if (isset($params["category"]) && $params["category"] != '')
     $query1 .= ") AND ";
     $query2 .= ") AND ";
   }
-else if( isset($params['category_id']) )
-  {
-    $query1 .= " ( mnc.news_category_id = '".$params['category_id']."' ) AND ";
-    $query2 .= " ( mnc.news_category_id = '".$params['category_id']."' ) AND ";
-  }
 
 $now = $db->DbTimeStamp(time());
 $query1 .= "(".$db->IfNull('start_time',$db->DBTimeStamp(1))." < ".$now.") ";
@@ -280,7 +279,7 @@ while ($dbresult && $row = $dbresult->FetchRow())
       }
     else
       {
-	$feu =& $this->GetModuleInstance('FrontEndUsers');
+	$feu = $this->GetModuleInstance('FrontEndUsers');
 	if( $feu ) {
 	  $uinfo = $feu->GetUserInfo($onerow->author_id * -1);
 	  if( $uinfo[0] )
@@ -355,6 +354,19 @@ while ($dbresult && $row = $dbresult->FetchRow())
 	$sendtoprint['lang'] = $params['lang'];
       }
 
+   if (isset($params['category_id']))
+      {
+		$sendtodetail['category_id'] = $params['category_id'];
+		$sendtoprint['category_id'] = $params['category_id'];
+      }
+
+   if (isset($params['pagelimit']))
+      {
+		$sendtodetail['pagelimit'] = $params['pagelimit'];
+		$sendtoprint['pagelimit'] = $params['pagelimit'];
+      }
+
+
 #CreateLink($id, $action, $returnid='', $contents='', $params=array(), $warn_message='', $onlyhref=false, $inline=false, $addttext='', $targetcontentonly=false, $prettyurl='')
     $onerow->link = $this->CreateLink($id, 'detail', $detailpage!=''?$detailpage:$returnid, '', $sendtodetail,'', true, false, '', true, $prettyurl);
     $onerow->titlelink = $this->CreateLink($id, 'detail', $detailpage!=''?$detailpage:$returnid, $row['news_title'], $sendtodetail, '', false, false, '', true, $prettyurl);
@@ -377,6 +389,23 @@ foreach( $params as $key => $value )
   $smarty->assign('param_'.$key,$value);
 }
 
+$catName = '';
+if (isset($params['category']))
+	{
+	$catName = $params['category'];
+	}
+else if (isset($params['category_id']))
+	{
+	$catName = $db->GetOne('SELECT news_category_name FROM '.cms_db_prefix() . 'module_news_categories where news_category_id=?',array($params['category_id']));		
+	}
+$smarty->assign('category_name',$catName);
+
+
+unset($params['pagenumber']);
+$items = $this->get_categories($id,$params,$returnid);
+$this->smarty->assign('count', count($items));
+$this->smarty->assign('cats', $items);
+
 #Display template
 echo "<!-- Displaying News Module -->\n";
 echo "<!-- News Categories: '".(isset($params['category'])?$params['category']:'')."' -->\n";
