@@ -20,6 +20,8 @@ $lang['expiry_date_desc'] = 'Expiry Date Descending';
 $lang['expiry_date_asc'] = 'Expiry Date Ascending';
 $lang['title_desc'] = 'Title Descending';
 $lang['title_asc'] = 'Title Ascending';
+$lang['status_desc'] = 'Status Descending';
+$lang['status_asc'] = 'Status Ascending';
 $lang['fesubmit_status'] = 'The status of news articles submitted via the frontend';
 $lang['error_invalidfiletype'] = 'Cannot upload this type of file';
 $lang['error_upload'] = 'Problem occurred uploading a file';
@@ -234,7 +236,7 @@ $lang['help_articleid'] = 'This parameter is only applicable to the detail view.
 $lang['helpnumber'] = 'Maximum number of items to display (per page) -- leaving empty will show all items.  This is a synonym for the pagelimit parameter.';
 $lang['helpstart'] = 'Start at the nth item -- leaving empty will start at the first item.';
 $lang['helpcategory'] = 'Used in the summary view to display only items for the specified categories. <b>Use * after the name to show children.</b>  Multiple categories can be used if separated with a comma. Leaving empty, will show all categories.  This parameter also works for the frontend submit action, however only a single category name is supported.';
-$lang['helpmoretext'] = 'Text to display at the end of a news item if it goes over the summary length.  Defaults to "more..."';
+$lang['helpmoretext'] = 'Text to display at the end of a news item if it goes over the summary length.  Defaults to "More"';
 $lang['helpsummarytemplate'] = 'Use a separate database template for displaying the article summary.  This template must exist and be visible in the summary template tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used.';
 $lang['helpformtemplate'] = 'Use a database template for displaying the article submission form. This template must exist and be visible in the form templates tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used.';
 $lang['helpbrowsecattemplate'] = 'Use a database template for displaying the category browser. This template must exist and be visible in the Browse Category Templates tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used.';
