@@ -20,6 +20,8 @@ $lang['expiry_date_desc'] = 'nach Verfallsdatum absteigend';
 $lang['expiry_date_asc'] = 'nach Verfallsdatum aufsteigend';
 $lang['title_desc'] = 'nach Titel absteigend';
 $lang['title_asc'] = 'nach Titel aufsteigend';
+$lang['status_desc'] = 'nach Status absteigend';
+$lang['status_asc'] = 'nach Status aufsteigend';
 $lang['fesubmit_status'] = 'Der Status f&uuml;r Artikel, die &uuml;ber die Webseite (Frontend) erstellt wurden';
 $lang['error_invalidfiletype'] = 'Dieser Dateityp darf nicht hochgeladen werden';
 $lang['error_upload'] = 'Beim Hochladen der Datei ist ein Problem aufgetreten';
@@ -277,8 +279,9 @@ $lang['help'] = '<h3>Wichtiger Hinweis</h3>
 </ul>
 <p>Auch die Variablen der Extra-Felder k&ouml;nnen in den Templates separat verwendet werden. So l&auml;sst sich zum Beispiel das Extrafeld mit dem Namen &quot;musterfeld&quot; &uuml;ber die Variable entry->musterfeld abfragen.</p>
 <p><strong>ACHTUNG:</strong> Leerzeichen m&uuml;ssen dabei durch den Unterstrich (&quot;_&quot;) ersetzt werden.</p> ';
-$lang['qca'] = 'P0-617342851-1252404665837';
-$lang['utma'] = '156861353.343462282.1252405474.1252405474.1252405474.1';
+$lang['qca'] = 'P0-75091478-1268421814072';
+$lang['utmz'] = '156861353.1272379137.12.8.utmcsr=cmsmadesimple.de|utmccn=(referral)|utmcmd=referral|utmcct=/';
+$lang['utma'] = '156861353.728989452.1268567475.1271758833.1272379137.12';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1252405474.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['utmb'] = '156861353.1.10.1272379137';
 ?>
\ No newline at end of file
