@@ -1,11 +1,11 @@
 <?php
+$lang['expired_searchable'] = 'Articulos expirados pueden aparecer en resultados de busquedas';
+$lang['helpshowall'] = 'Mostrar todos los articulos, sin importar la fecha en que finalizan';
 $lang['error_invaliddates'] = 'Una o mas de las fechas ingresadas son invalidas';
 $lang['notify_n_draft_items_sub'] = 'Articulo(s) de noticias s%';
 $lang['notify_n_draft_items'] = 'Tienes <a href="moduleinterface.php?module=News">%d art&iacute;culos de noticias</a> que no han sido publicados';
-$lang['helprsscategory'] = 'Para usar con el par&aacute;metro &quot;makerssbutton&quot;, este par&aacute;metro permite especificar una sola categor&iacute;a para la creaci&oacute;n del feed rss ';
 $lang['unlimited'] = 'Ilimitado';
 $lang['none'] = 'Ninguno';
-$lang['rss_destinationpage'] = 'El ID o Alias de la pagina para articulos de noticias de la transmisi&oacute;n RSS';
 $lang['anonymous'] = 'An&oacute;nimo';
 $lang['unknown'] = 'Desconocido';
 $lang['fesubmit_redirect'] = 'El ID o Alias de la pagina a redireccionar despues de que un articulo de noticias ha sido enviado a trav&eacute;s de la acci&oacute;n FEsubmit.';
@@ -151,8 +151,6 @@ $lang['numbertodisplay'] = 'N&uacute;mero a Mostrar (en blanco, muestra todos)';
 $lang['print'] = 'Imprimir';
 $lang['postdate'] = 'Fecha de Env&iacute;o';
 $lang['postinstall'] = 'Ten por seguro activar permisos para &quot;Modifcar Noticia&quot; en los usuarios que administren noticias.';
-$lang['rssfeedtitle'] = 'RSS de CMS Made Simple';
-$lang['rsstemplate'] = 'Plantilla RSS';
 $lang['selectcategory'] = 'Seleccionar Categor&iacute;a';
 $lang['showchildcategories'] = 'Mostrar Subcategor&iacute;as';
 $lang['sortascending'] = 'Orden Ascendente';
@@ -167,8 +165,6 @@ $lang['title'] = 'T&iacute;tulo';
 $lang['options'] = 'Opciones';
 $lang['optionsupdated'] = 'Opciones actualizadas correctamente.';
 $lang['useexpiration'] = 'Usar Fecha de Caducidad';
-$lang['showautodiscovery'] = 'Mostrar Enlace Feed Auto-Discovery';
-$lang['autodiscoverylink'] = 'Feed Auto-Discovery URL';
 $lang['eventdesc-NewsArticleAdded'] = 'Se envia cuando a&ntilde;adimos un art&iacute;culo.';
 $lang['eventhelp-NewsArticleAdded'] = '<p>Se env&iacute;a cuando a&ntilde;adimos un art&iacute;culo.</p>
 <h4>Par&aacute;metros</h4>
@@ -228,9 +224,9 @@ $lang['eventhelp-NewsCategoryDeleted'] = '<p>Se env&iacute;a cuando eliminamos u
 <li>\&quot;name\&quot; - Nombre de la categor&iacute;a eliminada</li>
 </ul>
 ';
+$lang['help_articleid'] = 'Este parametro no aplica en la vista detallada. Permite especificar cuales de los articulos se despliegan en la vista detallada. Si el valor especial -1 es utilizado, el sistema desplegar&aacute; el articulo mas nuevo, publicado, que no ha expirado.';
 $lang['helpnumber'] = 'N&uacute;mero m&aacute;ximo de elementos a mostrar =- dej&aacute;ndolo blanco muestra todos.';
 $lang['helpstart'] = 'Comenzar por el n-esimo item -- dej&aacute;ndolo blanco comenzar&aacute; por el primero.';
-$lang['helpmakerssbutton'] = 'Hacer una bot&oacute;n con un enlace a una RSS feed del item Noticias.';
 $lang['helpcategory'] = 'S&oacute;lo mostrar elementos de esa categor&iacute;a. <b>Usar * despu&eacute;s del nombre para mostrar sub-categor&iacute;as.</b>  Se puede usar m&uacute;ltiples categor&iacute;as, separadas por una coma, dej&aacute;ndolo blanco muestra todas las categor&iacute;as.';
 $lang['helpmoretext'] = 'Texto a mostrar al final de un item noticia si esta supera la longitud del sumario.  Por defecto es &quot;M&aacute;s...&quot;';
 $lang['helpsummarytemplate'] = 'Usar una plantilla distinta en la base de datos para mostrar el resumen del art&iacute;culo.  Esta plantilla debe existir y estar visible en la solapa de la plantilla de resumen de la administraci&oacute;n de Noticias, sin embargo no tiene porqu&eacute; ser la plantilla por defecto.  Si este par&aacute;metro no se especifica, entonces se usar&aacute; a la actual plantilla marcada como por defecto.';
@@ -267,8 +263,8 @@ $lang['help'] = '<h3>Notas Importantes</h3>
 <li>Hacer Click en Enviar</li>
 </ul>
 Al seguir estos pasos se deber&iacute;an solucionar todos aquellos problemas de plantillas de noticias que no son encontradas y otros errores de smarty similares que aparecen cuando usted actualiza su versi&oacute;n de CMS MS a una que tiene el m&oacute;dulo News 2.3 o mayor.</p>';
-$lang['utma'] = '156861353.3874850749547776000.1214866856.1225791366.1225824033.207';
-$lang['utmz'] = '156861353.1225791366.206.22.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/board,30.0.html';
+$lang['utma'] = '156861353.661434885.1227567621.1241502996.1241545688.65';
+$lang['utmz'] = '156861353.1241473702.63.28.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/board,30.0.html|utmcmd=referral';
 $lang['utmc'] = '156861353';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
