@@ -1,25 +1,27 @@
 <?php
 $lang['expired_searchable'] = 'Les articles expir&eacute;s peuvent appara&icirc;tre dans les r&eacute;sultats de recherche&nbsp;';
-$lang['helpshowall'] = 'Voir tous les articles, quelle que soit la date de fin';
+$lang['helpshowall'] = 'Si positionn&eacute; &agrave; 1 : affiche tous les articles, quelle que soit la date de fin';
 $lang['error_invaliddates'] = 'Une ou plusieurs dates entr&eacute;es sont invalides';
-$lang['notify_n_draft_items_sub'] = '%d Article(s)';
-$lang['notify_n_draft_items'] = 'Vous avez %s non publi&eacute;(s)';
+$lang['notify_n_draft_items_sub'] = '%d article(s)';
+$lang['notify_n_draft_items'] = 'Vous avez %s article(s) non publi&eacute;(s)';
 $lang['unlimited'] = 'Sans limite';
 $lang['none'] = 'Aucun';
 $lang['anonymous'] = 'Anonyme';
 $lang['unknown'] = 'Inconnu';
 $lang['fesubmit_redirect'] = 'PageID ou alias o&ugrave; se fera la redirection apr&egrave;s qu&#039;un article ait &eacute;t&eacute; soumis via l&#039;action fesubmit&nbsp;';
-$lang['allow_summary_wysiwyg'] = 'Autoriser l&#039;utilisation de l&#039;&eacute;diteur WYSIWYG dans le champ sommaire&nbsp;';
+$lang['allow_summary_wysiwyg'] = 'Autoriser l&#039;utilisation de l&#039;&eacute;diteur WYSIWYG dans le sommaire&nbsp;';
 $lang['title_browsecat_template'] = 'Gabarit de cat&eacute;gories';
 $lang['title_browsecat_sysdefault'] = 'Gabarit de cat&eacute;gories par d&eacute;faut';
 $lang['browsecattemplate'] = 'Gabarit de cat&eacute;gories';
 $lang['error_filesize'] = 'Un fichier upload&eacute; exc&egrave;de la taille maximum autoris&eacute;e';
-$lang['post_date_desc'] = 'Date article post&eacute; Descendante';
-$lang['post_date_asc'] = 'Date article post&eacute; Ascendante';
-$lang['expiry_date_desc'] = 'Date expiration Descendante';
-$lang['expiry_date_asc'] = 'Date expiration Ascendante';
-$lang['title_desc'] = 'Titre Descendant';
-$lang['title_asc'] = 'Titre Ascendant';
+$lang['post_date_desc'] = 'Date article post&eacute; descendante';
+$lang['post_date_asc'] = 'Date article post&eacute; ascendante';
+$lang['expiry_date_desc'] = 'Date expiration descendante';
+$lang['expiry_date_asc'] = 'Date expiration ascendante';
+$lang['title_desc'] = 'Titre descendant';
+$lang['title_asc'] = 'Titre ascendant';
+$lang['status_desc'] = 'Status descendant';
+$lang['status_asc'] = 'Status ascendant';
 $lang['fesubmit_status'] = 'Le statut des articles soumis via les pages du site (frontend)&nbsp;';
 $lang['error_invalidfiletype'] = 'Impossible de t&eacute;l&eacute;charger ce type de fichier';
 $lang['error_upload'] = 'Il y a eu un probl&egrave;me lors du t&eacute;l&eacute;chargement d&#039;un fichier';
@@ -29,13 +31,13 @@ $lang['expiry_interval'] = 'Le nombre de jours (par d&eacute;faut) avant qu&#039
 $lang['removed'] = 'Supprim&eacute;';
 $lang['msg_contenttype_removed'] = 'Le type de contenu News a &eacute;t&eacute; supprim&eacute;. Merci de remplacer les tags {news} avec les param&egrave;tres appropri&eacute;s dans vos gabarits ou vos pages pour remplacer cette fonctionnalit&eacute;.';
 $lang['delete_selected'] = 'Supprimer les articles s&eacute;lectionn&eacute;s';
-$lang['areyousure_deletemultiple'] = '&Ecirc;tes-vous s&ucirc;r de vouloir supprimer tous ces articles&nbsp;?\nCette action est d&eacute;finitive&nbsp;!';
+$lang['areyousure_deletemultiple'] = '&Ecirc;tes-vous s&ucirc;r(e) de vouloir supprimer tous ces articles&nbsp;?\nCette action est d&eacute;finitive&nbsp;!';
 $lang['error_templatenamexists'] = 'Un gabarit de ce nom existe d&eacute;j&agrave;';
 $lang['error_noarticlesselected'] = 'Aucun article s&eacute;lectionn&eacute;';
 $lang['reassign_category'] = 'Changer la cat&eacute;gorie par&nbsp;';
 $lang['select'] = 'S&eacute;lectionner';
-$lang['approve'] = 'Mettre le Status &agrave; &#039;Publi&eacute;&#039;';
-$lang['revert'] = 'Mettre le Status &agrave; &#039;&Eacute;bauche&#039;';
+$lang['approve'] = 'Mettre le status &agrave; &#039;Publi&eacute;&#039;';
+$lang['revert'] = 'Mettre le status &agrave; &#039;&Eacute;bauche&#039;';
 $lang['hide_summary_field'] = 'Cacher le champ sommaire lors de l&#039;ajout ou de la modification d&#039;articles&nbsp;';
 $lang['textbox'] = 'Champ de texte';
 $lang['checkbox'] = 'Case &agrave; cocher';
@@ -49,7 +51,7 @@ $lang['up'] = 'Haut';
 $lang['down'] = 'Bas';
 $lang['fielddefdeleted'] = 'La d&eacute;finition du champ a &eacute;t&eacute; supprim&eacute;e avec succ&egrave;s.';
 $lang['nameexists'] = 'Un champ de ce nom existe d&eacute;j&agrave;';
-$lang['notanumber'] = 'La Longueur maximale n&#039;est PAS un nombre';
+$lang['notanumber'] = 'La longueur maximale n&#039;est PAS un nombre';
 $lang['fielddef'] = 'D&eacute;finition champ';
 $lang['fielddefadded'] = 'La d&eacute;finition du champ a &eacute;t&eacute; ajout&eacute;e avec succ&egrave;s.';
 $lang['public'] = 'Publique&nbsp;';
@@ -75,7 +77,7 @@ $lang['prompt_template'] = 'Source du gabarit&nbsp;';
 $lang['title_form_sysdefault'] = 'Gabarit de soumission article par d&eacute;faut (frontend)';
 $lang['title_summary_sysdefault'] = 'Gabarit du sommaire par d&eacute;faut';
 $lang['title_detail_sysdefault'] = 'Gabarit du d&eacute;tail par d&eacute;faut';
-$lang['info_sysdefault2'] = '<strong>Note :</strong> Cette page contient des zones d&#039;&eacute;dition des gabarits qui sont disponibles quand vous cr&eacute;ez un &#039;Nouveau&#039; gabarit Sommaire, D&eacute;tail ou Soumission d&#039;article. Le fait de cliquer sur &#039;Envoyer&#039; les donn&eacute;es de cette page <strong>n&#039;aura aucun effet imm&eacute;diat sur l&#039;affichage d&eacute;j&agrave; existant</strong>.';
+$lang['info_sysdefault2'] = '<strong>Note :</strong> cette page contient des zones d&#039;&eacute;dition des gabarits qui sont disponibles quand vous cr&eacute;ez un &#039;Nouveau&#039; gabarit Sommaire, D&eacute;tail ou Soumission d&#039;article. Le fait de cliquer sur &#039;Envoyer&#039; les donn&eacute;es de cette page <strong>n&#039;aura aucun effet imm&eacute;diat sur l&#039;affichage d&eacute;j&agrave; existant</strong>.';
 $lang['info_sysdefault'] = '<em>(le gabarit utilis&eacute; par d&eacute;faut quand un nouveau gabarit est s&eacute;lectionn&eacute;)</em>';
 $lang['template'] = 'Gabarit&nbsp;';
 $lang['prompt_name'] = 'Nom';
@@ -88,7 +90,7 @@ $lang['prevpage'] = '<';
 $lang['nextpage'] = '>';
 $lang['lastpage'] = '>>';
 $lang['prompt_of'] = 'sur';
-$lang['prompt_pagelimit'] = 'Nombre de pages&nbsp;';
+$lang['prompt_pagelimit'] = 'Nombre par page&nbsp;';
 $lang['prompt_sorting'] = 'Tri&eacute; par&nbsp;';
 $lang['title_filter'] = 'Filtres';
 $lang['published'] = 'Publi&eacute;';
@@ -96,7 +98,7 @@ $lang['draft'] = '&Eacute;bauche';
 $lang['expired'] = 'Expir&eacute;';
 $lang['author'] = 'Auteur&nbsp;';
 $lang['sysdefaults'] = 'Restaurer les param&egrave;tres par d&eacute;faut';
-$lang['restoretodefaultsmsg'] = 'Cette op&eacute;ration restaurera les gabarits par d&eacute;faut. &Ecirc;tes-vous s&ucirc;r de vouloir continuer&nbsp;?';
+$lang['restoretodefaultsmsg'] = 'Cette op&eacute;ration restaurera les gabarits par d&eacute;faut. &Ecirc;tes-vous s&ucirc;r(e) de vouloir continuer&nbsp;?';
 $lang['addarticle'] = 'Ajouter un article';
 $lang['articleadded'] = 'L&#039;article a &eacute;t&eacute; ajout&eacute; avec succ&egrave;s.';
 $lang['articleupdated'] = 'L&#039;article a &eacute;t&eacute; mis &agrave; jour avec succ&egrave;s.';
@@ -108,7 +110,7 @@ $lang['categorydeleted'] = 'La cat&eacute;gorie a &eacute;t&eacute; supprim&eacu
 $lang['addnewsitem'] = 'Ajouter un article';
 $lang['allcategories'] = 'Toutes les cat&eacute;gories';
 $lang['allentries'] = 'Toutes les entr&eacute;es';
-$lang['areyousure'] = '&Ecirc;tes-vous s&ucirc;r de vouloir supprimer&nbsp;?';
+$lang['areyousure'] = '&Ecirc;tes-vous s&ucirc;r(e) de vouloir supprimer&nbsp;?';
 $lang['articles'] = 'Articles ';
 $lang['cancel'] = 'Annuler';
 $lang['category'] = 'Cat&eacute;gorie&nbsp;';
@@ -140,13 +142,13 @@ $lang['news_return'] = 'Retour';
 $lang['newcategory'] = 'Nouvelle cat&eacute;gorie';
 $lang['needpermission'] = 'Vous devez avoir la permission &#039;%s&#039; pour ex&eacute;cuter cette action.';
 $lang['nocategorygiven'] = 'Aucune cat&eacute;gorie entr&eacute;e';
-$lang['startdatetoolate'] = 'la date de d&eacute;but est pass&eacute;e (apr&egrave;s la Date de fin ?)';
+$lang['startdatetoolate'] = 'la date de d&eacute;but est pass&eacute;e (apr&egrave;s la date de fin ?)';
 $lang['nocontentgiven'] = 'Aucun contenu entr&eacute;';
 $lang['noitemsfound'] = '<strong>Aucun</strong> objet trouv&eacute; pour cette cat&eacute;gorie: %s';
 $lang['nopostdategiven'] = 'Il manque la date &agrave; laquelle l&#039;article sera post&eacute;';
-$lang['note'] = '<em>Note :</em> Les dates doivent &ecirc;tre entr&eacute;es dans ce format &#039;yyyy-mm-dd hh:mm:ss&#039;.';
-$lang['notitlegiven'] = 'Aucun titre entr&eacute;';
-$lang['nonamegiven'] = 'Aucun nom donn&eacute;';
+$lang['note'] = '<em>Note :</em> les dates doivent &ecirc;tre entr&eacute;es dans ce format &#039;yyyy-mm-dd hh:mm:ss&#039;.';
+$lang['notitlegiven'] = 'Aucun titre n&#039;est entr&eacute;';
+$lang['nonamegiven'] = 'Aucun nom n&#039;a &eacute;t&eacute; donn&eacute;';
 $lang['numbertodisplay'] = 'Nombre &agrave; afficher (vide = toutes les entr&eacute;es)&nbsp;';
 $lang['print'] = 'Imprimer';
 $lang['postdate'] = 'Date &agrave; laquelle l&#039;article sera post&eacute;&nbsp;';
@@ -231,7 +233,7 @@ $lang['help_articleid'] = 'Ce param&egrave;tre est applicable uniquement &agrave
 $lang['helpnumber'] = 'Le nombre maximal d&#039;articles &agrave; afficher -- laisser ce param&egrave;tre vide affichera tous les articles. C&#039;est identique au param&egrave;tre &quot;pagelimit&quot;.';
 $lang['helpstart'] = 'Commence au &eacute;ni&egrave;me article -- laisser ce param&egrave;tre vide commencera l&#039;affichage au premier article';
 $lang['helpcategory'] = 'Affiche les articles de cette cat&eacute;gorie seulement. Utiliser * pour afficher les sous-cat&eacute;gories. Des cat&eacute;gories multiples peuvent &ecirc;tre affich&eacute;es en les s&eacute;parant par une virgule. Laisser ce param&egrave;tre vide affichera tous les articles.';
-$lang['helpmoretext'] = 'Texte &agrave; afficher &agrave; la fin d&#039;un article qui d&eacute;passe la longueur d&eacute;finie du sommaire.  D&eacute;faut = &quot;more...&quot;';
+$lang['helpmoretext'] = 'Texte &agrave; afficher &agrave; la fin d&#039;un article qui d&eacute;passe la longueur d&eacute;finie du sommaire. Par d&eacute;faut = &quot;Plus&quot;';
 $lang['helpsummarytemplate'] = 'Utilise la base de donn&eacute;e pour afficher le formulaire de soumission du sommaire des articles. Ce gabarit doit exister et, est visible dans l&#039;onglet &#039;Gabarit du sommaire article&#039; de Contenu/Articles, et n&#039;est pas n&eacute;cessaire par d&eacute;faut. Si ce param&egrave;tre n&#039;est pas sp&eacute;cifi&eacute; le gabarit par d&eacute;faut est utilis&eacute;.';
 $lang['helpformtemplate'] = 'Utilise la base de donn&eacute;e pour afficher le formulaire de soumission de l&#039;article. Ce gabarit doit exister et, est visible dans l&#039;onglet &#039;Gabarit soumission article&#039; de Contenu/Articles, et n&#039;est pas n&eacute;cessaire par d&eacute;faut. Si ce param&egrave;tre n&#039;est pas sp&eacute;cifi&eacute; le gabarit par d&eacute;faut est utilis&eacute;.';
 $lang['helpbrowsecattemplate'] = 'Utilise la base de donn&eacute;e pour afficher les gabarits de cat&eacute;gories. Ce gabarit doit exister et, est visible dans l&#039;onglet &#039;Gabarit de cat&eacute;gories&#039; de Contenu/Articles, et n&#039;est pas n&eacute;cessaire par d&eacute;faut. Si ce param&egrave;tre n&#039;est pas sp&eacute;cifi&eacute; le gabarit par d&eacute;faut est utilis&eacute;.';
@@ -242,17 +244,18 @@ $lang['helpdetailpage'] = 'Page dans laquelle afficher le d&eacute;tail des arti
 $lang['helpshowarchive'] = 'Afficher seulement les articles expir&eacute;s.';
 $lang['helpbrowsecat'] = 'Afficher une liste navigable de cat&eacute;gories';
 $lang['helpaction'] = 'Outrepasse l&#039;action par d&eacute;faut. Les valeurs possibles sont :
+<ul>
 <li>&quot;detail&quot; - pour afficher l&#039;article en mode d&eacute;tail.</li>
 <li>&quot;default&quot; - pour afficher le sommaire de l&#039;article</li>
-<li>&quot;fesubmit&quot; - pour afficher le gabarit de soumission (frontend) d&#039;articles des visiteurs dans les pages du site.</li>
+<li>&quot;fesubmit&quot; - pour afficher le gabarit de soumission (frontend) d&#039;articles des utilisateurs dans les pages du site.</li>
 <li>&quot;browsecat&quot; - pour afficher une liste de cat&eacute;gories.</li>
 </ul>
 
 ';
 $lang['help'] = '<h3>Notes Importantes</h3>
 <p>la Version 2.9 a supprim&eacute; le format &quot;formatpostdate&quot; des gabarits, et a &eacute;galement supprim&eacute; le param&egrave;tre &quot;dateformat&quot;. Vous devez utiliser le param&egrave;tre &quot;cms_date_format&quot; (comme indiqu&eacute; dans les gabarits par d&eacute;faut) pour les format des dates, et devrait utiliser entry->postdate au lieu de entry->formatpostdate dans vos gabarits.</p>
-<h3>Que fait ce module&nbsp;?</h3>
-	<p>Article est un module pour afficher des articles sur vos pages, de fa&ccedil;on similaire &agrave; un blog, mais avec plus de fonctions ! D&egrave;s que le module est install&eacute;, une page de gestion des articles est ajout&eacute;e au menu d&#039;administration qui vous permettra de s&eacute;lectionner ou ajouter des cat&eacute;gories d&#039;articles. D&egrave;s qu&#039;une cat&eacute;gorie d&#039;article est s&eacute;lectionn&eacute;e ou cr&eacute;&eacute;e, une liste des articles pour cette cat&eacute;gorie est affich&eacute;e. Depuis l&agrave;, vous pouvez ajouter, &eacute;diter ou supprimer les articles dans cette cat&eacute;gorie.</p>
+<h3>Que fait ce module ?</h3>
+	<p>Articles (News en anglais) est un module qui sert &agrave; afficher des articles sur vos pages, de fa&ccedil;on similaire &agrave; un blog, mais avec plus de fonctions ! D&egrave;s que le module est install&eacute;, une page de gestion des articles est ajout&eacute;e au menu d&#039;administration qui vous permettra de s&eacute;lectionner ou ajouter des cat&eacute;gories d&#039;articles. D&egrave;s qu&#039;une cat&eacute;gorie d&#039;article est s&eacute;lectionn&eacute;e ou cr&eacute;&eacute;e, une liste des articles pour cette cat&eacute;gorie est affich&eacute;e. Depuis l&agrave;, vous pouvez ajouter, &eacute;diter ou supprimer les articles dans cette cat&eacute;gorie.</p>
 <h4>Champs personnalis&eacute;s</h4>
 <p>Le module permet de d&eacute;finir de nombreux champs personnalis&eacute;s (y compris les fichiers et images) qui vous permettront de joindre des fichiers PDF ou de nombreuses images &agrave; vos articles.</p>
             <h4>Cat&eacute;gories</h4>
@@ -275,8 +278,9 @@ $lang['help'] = '<h3>Notes Importantes</h3>
 <li>Cliquer sur le bouton Envoyer</li>
 </ul>
 <p>Ces diff&eacute;rentes &eacute;tapes r&eacute;solvent le probl&egrave;me de ces nouveaux gabarits afin d&#039;&eacute;viter les diff&eacute;rentes erreurs de Smarty quand vous mettez &agrave; jour vers une version de CMS avec un module de News version 2.3 ou sup&eacute;rieure.</p>';
-$lang['utmz'] = '156861353.1234686030.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/topic,18584.msg146491.html|utmcmd=referral';
-$lang['utma'] = '156861353.1770932664.1234686030.1234715253.1234721522.3';
+$lang['utma'] = '156861353.2003866910.1245652859.1281456650.1281561723.184';
+$lang['utmz'] = '156861353.1281561723.184.168.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
+$lang['qca'] = '4a3d1b41-5eb36-c9570-f49ea';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
+$lang['utmb'] = '156861353.1.10.1281561723';
 ?>
\ No newline at end of file
