@@ -20,6 +20,8 @@ $lang['expiry_date_desc'] = 'Data di scadenza discendente';
 $lang['expiry_date_asc'] = 'Data di scadenza ascendente';
 $lang['title_desc'] = 'Titolo discendente';
 $lang['title_asc'] = 'Titolo ascendente';
+$lang['status_desc'] = 'Stato discendente';
+$lang['status_asc'] = 'Stato ascendente';
 $lang['fesubmit_status'] = 'Lo stato dell&#039;articolo inviato via frontend';
 $lang['error_invalidfiletype'] = 'Non posso inviare questo tipo di file';
 $lang['error_upload'] = 'Problemi occorsi all&#039;invio del file';
@@ -40,7 +42,7 @@ $lang['hide_summary_field'] = 'Nasconde il campo sommario quando aggiungi o modi
 $lang['textbox'] = 'Textinput';
 $lang['checkbox'] = 'Check';
 $lang['textarea'] = 'Textarea';
-$lang['file'] = 'File';
+$lang['file'] = 'File ';
 $lang['auto_create_thumbnails'] = 'Automaticamente crea miniature per i file con queste estensioni';
 $lang['allowed_upload_types'] = 'Permettere l&#039;invio solo di file con le seguenti estensioni';
 $lang['fielddefupdated'] = 'Definizione del campo aggiornata';
@@ -63,7 +65,7 @@ $lang['subject_newnews'] = 'Un nuovo articolo &egrave; stato pubblicato';
 $lang['email_subject'] = 'L&#039;Oggetto della email di uscita';
 $lang['email_template'] = 'Il formato del messaggio di email';
 $lang['formsubmit_emailaddress'] = 'Indirizzo email che ricever&agrave; notifica di inserimenti';
-$lang['extra'] = 'Extra';
+$lang['extra'] = 'Extra ';
 $lang['uploadscategory'] = 'Categoria di Upload';
 $lang['title_available_templates'] = 'Modelli utilizzabili';
 $lang['resettodefault'] = 'Reset ai valori predefiniti';
@@ -135,7 +137,7 @@ $lang['category_label'] = 'Categoria:';
 $lang['author_label'] = 'Postato da:';
 $lang['moretext'] = 'Altro testo';
 $lang['name'] = 'Nome';
-$lang['news'] = 'News';
+$lang['news'] = 'News ';
 $lang['news_return'] = 'Ritorna';
 $lang['newcategory'] = 'Nuova categoria';
 $lang['needpermission'] = 'Hai bisogno del permesso &#039;%s&#039; per usufruire di questa funzione.';
@@ -271,8 +273,9 @@ $lang['help'] = '<h3>Note Importanti</h3>
 <li>Premere Invio</li>
 </ul>
 Seguendo questi passi si dovrebbe risolvere il problema dei nuovi modelli non trovati e altri errori similari di smarty quando aggiorni ad una versione di CMS che contiene News 2.3 o maggiore.</p>';
-$lang['utma'] = '156861353.880130626.1236353467.1240505117.1241641977.36';
-$lang['utmz'] = '156861353.1240505117.35.31.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['qca'] = 'P0-1187230324-1271659236866';
+$lang['utma'] = '156861353.976402040.1271759292.1276850904.1277118686.4';
+$lang['utmz'] = '156861353.1277118686.4.4.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
