@@ -20,6 +20,8 @@ $lang['expiry_date_desc'] = 'Utl&oslash;per dato synkende';
 $lang['expiry_date_asc'] = 'Utl&oslash;per dato stigende';
 $lang['title_desc'] = 'Tittel synkende';
 $lang['title_asc'] = 'Tittel stigende';
+$lang['status_desc'] = 'Status synkende';
+$lang['status_asc'] = 'Status stigende';
 $lang['fesubmit_status'] = 'Status for nyhetensartiklene som er innsendt via frontenden';
 $lang['error_invalidfiletype'] = 'Kan ikke laste opp denne filtypen';
 $lang['error_upload'] = 'Et problem oppstod under opplasting av fil';
@@ -255,7 +257,7 @@ $lang['help'] = '<h3>Viktige merknader</h3>
 N&aring;r modulen er installert, blir det lagt til en administrasjonsside for Nyheter i administrasjonsmenyen, som vil tillate deg &aring; velg og  legge til nyhetskategori.  
 	N&aring;r en nyhetskategori er opprettet eller valgt, vil det vises en liste med nyhetsartikler for den kategorien.  
 Herfra kan du legge til, redigere eller slette nyheter for kategorien.</p>
-        <h4>Mange visnings m&aring;ter</h4>
+        <h4>Mange visningsm&aring;ter</h4>
 	<p>Parameterne som er st&oslash;ttet av nyhets modulen, og st&oslash;tte for mange maler p&aring; en gang vil si at dine muligheter for &aring; vise nyhetsartikler er ubegrenset.</p>
         <h4>Egendefinerte felter</h4>
 	<p>Nyhetsmodulen tillater definering av mange egendefinerte felter (inkludert filer og bilder) som vil tillate deg &aring; koble pdf filer eller flere bilders til dine artikler.</p>
@@ -283,8 +285,9 @@ Dette vil sette inn modulen i din mal eller side hvor du m&aring;tte &oslash;nsk
 </ul>
 
 <p>Dersom du f&oslash;lger disse trinnene skulle det l&oslash;se problemet med at dine nyhetsamaler ikke blir funnet og lignende smarty feil, n&aring;r du oppgraderer til en versjon av CMS som har News 2.3 eller h&oslash;yere.</p>';
-$lang['utmz'] = '156861353.1243118268.1334.33.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
-$lang['utma'] = '156861353.179052623084110100.1210423577.1244280118.1244298455.1393';
+$lang['utmz'] = '156861353.1272675501.2656.57.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/files/6';
+$lang['utma'] = '156861353.179052623084110100.1210423577.1272720219.1272726637.2660';
+$lang['qca'] = '1210971690-27308073-81952832';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.2.10.1244298455';
+$lang['utmb'] = '156861353.1.10.1272726637';
 ?>
\ No newline at end of file
