@@ -20,6 +20,8 @@ $lang['expiry_date_desc'] = 'Verloopdatum aflopend';
 $lang['expiry_date_asc'] = 'Verloopdatum oplopend';
 $lang['title_desc'] = 'Titel aflopend';
 $lang['title_asc'] = 'Titel oplopend';
+$lang['status_desc'] = 'Status Oplopend';
+$lang['status_asc'] = 'Status Aflopend';
 $lang['fesubmit_status'] = 'De status van nieuwsberichten ingediend via de frontend';
 $lang['error_invalidfiletype'] = 'Kan dit type bestand niet uploaden';
 $lang['error_upload'] = 'Probleem opgetreden tijdens uploaden bestand';
@@ -83,10 +85,10 @@ $lang['prompt_default'] = 'Standaard';
 $lang['prompt_newtemplate'] = 'Maak een nieuw sjabloon aan';
 $lang['help_pagelimit'] = 'Maximum aantal te tonen items (per pagina).  Als deze parameter niet is opgegeven, zullen alle resulterende items worden getoond. Als er een maximum is opgegeven, zal er bij meer resultaten dan opgegeven een tekst en link verschijnen om door de resultaten te kunnen scrollen.';
 $lang['prompt_page'] = 'Pagina';
-$lang['firstpage'] = '<< ';
-$lang['prevpage'] = '< ';
-$lang['nextpage'] = '> ';
-$lang['lastpage'] = '>> ';
+$lang['firstpage'] = '<<';
+$lang['prevpage'] = '<';
+$lang['nextpage'] = '>';
+$lang['lastpage'] = '>>';
 $lang['prompt_of'] = 'van';
 $lang['prompt_pagelimit'] = 'Paginalimiet';
 $lang['prompt_sorting'] = 'Sorteren op';
@@ -227,11 +229,11 @@ $lang['eventhelp-NewsCategoryDeleted'] = '<p>Verzonden als een categorie is verw
 <li>\&quot;name\&quot; - Naam van de verwijderde categorie</li>
 </ul>
 ';
-$lang['help_articleid'] = 'Deze parameter is alleen van toepassing op het detail overzicht. Het specificeerd welk nieuws artikel wordt getoond in het detail overzicht. Als de speciale waarde &#039;-1&#039; wordt  gebruikt dan zal de module het nieuwste, gepubliceerde en niet verlopen artikel tonen';
+$lang['help_articleid'] = 'Deze parameter is alleen van toepassing op het detail overzicht. Het specificeert welk nieuws artikel wordt getoond in het detail overzicht. Als de speciale waarde &#039;-1&#039; wordt  gebruikt dan zal de module het nieuwste, gepubliceerde en niet verlopen artikel tonen';
 $lang['helpnumber'] = 'Maximum aantal te tonen items -- door dit leeg te laten worden alle items getoond. Het is een synoniem voor de pagina limiet parameter.';
 $lang['helpstart'] = 'Begin bij het zoveelste... item -- geen waarde ingevoerd start dan bij het eerste item.';
 $lang['helpcategory'] = 'Toon alleen items van die categorie. <b>Gebruik * achter de naam om onderliggende items te tonen</b>. Meerdere categorie&euml;n scheiden met een komma. Geen waarde laat alle categorie&euml;n zien. Deze parameter kan ook gebruikt worden bij een frontend actie, maar dan kan alleen &eacute;&eacute;n categorie naam worden gebruikt.';
-$lang['helpmoretext'] = 'Tekst die wordt getoond aan het eind van een nieuwsbericht als de samenvatting te lang is. Standaard &quot;meer...&quot;';
+$lang['helpmoretext'] = 'Tekst die wordt getoond aan het eind van een nieuwsbericht als de samenvatting te lang is. Standaard &quot;Meer&quot;';
 $lang['helpsummarytemplate'] = 'Gebruik een ander sjabloon voor het tonen van het samengevatte bericht. Dit sjabloon moet bestaan en zichtbaar zijn in het samenvattingssjabloon-tabblad van de News-beheerscherm. Het hoeft niet de standaard keuze te zijn. Als deze parameter niet opgegeven is, dan wordt het sjabloon gebruikt wat als standaard ingesteld is.';
 $lang['helpformtemplate'] = 'Gebruik een database-sjabloon om het artikelinzendingsformulier te tonen. Dit sjabloon moet bestaan en zichtbaar zijn in het formuliersjablonentabblad van de News-beheerscherm. Het hoeft niet de standaard keuze te zijn. Als deze parameter niet opgegeven is, dan wordt het sjabloon gebruikt wat als standaard ingesteld is.';
 $lang['helpbrowsecattemplate'] = 'Gebruik een database-sjabloon om de categorie-browser te tonen. Dit sjabloon moet bestaan en zichtbaar zijn in het formuliersjablonentabblad van de News-beheerscherm. Het hoeft niet de standaard keuze te zijn. Als deze parameter niet opgegeven is, dan wordt het sjabloon gebruikt wat als standaard ingesteld is.';
@@ -277,9 +279,9 @@ $lang['help'] = '<h3>Belangrijke opmerkingen</h3>
 <li>Klik Versturen</li>
 </ul>
 Het uitvoeren van bovenstaande stappen moet het probleem oplossen van verdwenen nieuwssjablonen en vergelijkbare smarty-fouten als u upgrade naar een versie van CMSMS die de News-module versie 2.3 of nieuwer heeft.</p>';
-$lang['utma'] = '156861353.1764090269059867100.1239886062.1251546993.1251625156.65';
-$lang['utmz'] = '156861353.1251392261.61.11.utmccn=(referral)|utmcsr=classic-motorcycle-demo-team.nl|utmcct=/admin/addcontent.php|utmcmd=referral';
-$lang['qca'] = '4824ac14-af799-a4257-f4cde';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.1269027775.1259416186.1273854185.1273860758.784';
+$lang['utmz'] = '156861353.1273667738.769.136.utmccn=(referral)|utmcsr=lgsbv.oke-webdesign.nl|utmcct=/admin/moduleinterface.php|utmcmd=referral';
+$lang['qca'] = 'P0-431297011-1259416186230';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353.9.10.1273860758';
 ?>
\ No newline at end of file
