@@ -20,6 +20,8 @@ $lang['expiry_date_desc'] = 'Data terminare descrescator';
 $lang['expiry_date_asc'] = 'Data terminare crescator';
 $lang['title_desc'] = 'Titlu descrescator';
 $lang['title_asc'] = 'Titlu crescator';
+$lang['status_desc'] = 'Status descrescator';
+$lang['status_asc'] = 'Status crescator';
 $lang['fesubmit_status'] = 'Starea articolelor noutati adăugate prin frontend';
 $lang['error_invalidfiletype'] = 'Nu se poate &icirc;ncărca acest tip de fişier';
 $lang['error_upload'] = 'A survenit o problemă &icirc;ncărc&acirc;nd un fişier';
@@ -278,9 +280,9 @@ $lang['help'] = '<h3>Note importante</h3>
 <li>Hit Submit</li>
 </ul>
 <p>Following these steps should solve the problem of your news templates not being found and other similar smarty errors when you upgrade to a version of CMS that has News 2.3 or greater.</p>';
-$lang['utma'] = '156861353.746927255.1254134407.1254555814.1254567020.20';
-$lang['utmz'] = '156861353.1254567020.20.8.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/list_tagged/translation center';
-$lang['qca'] = 'P0-1102331689-1254134406867';
+$lang['utma'] = '156861353.1477009656.1272913798.1272913798.1274603745.2';
+$lang['utmz'] = '156861353.1274603746.2.3.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cms ms';
+$lang['qca'] = 'P0-1739349973-1272913798681';
+$lang['utmb'] = '156861353.2.10.1274603745';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1254567020';
 ?>
\ No newline at end of file
