@@ -18,8 +18,10 @@ $lang['post_date_desc'] = 'Дате (Новые вверху)';
 $lang['post_date_asc'] = 'Дате (Новые ввнизу)';
 $lang['expiry_date_desc'] = 'Дате окончания (Истекшие внизу)';
 $lang['expiry_date_asc'] = 'Дате окончания (Истекшие вверху)';
-$lang['title_desc'] = 'Заголовоку (от Я до А)';
-$lang['title_asc'] = 'Заголовоку (от А до Я)';
+$lang['title_desc'] = 'Заголовку (от Я до А)';
+$lang['title_asc'] = 'Заголовку (от А до Я)';
+$lang['status_desc'] = 'Статусу (от Я до А)';
+$lang['status_asc'] = 'Статус (от А до Я)';
 $lang['fesubmit_status'] = 'Статус новостей представленных через интерфейс';
 $lang['error_invalidfiletype'] = 'Не удается загрузить этот тип файла';
 $lang['error_upload'] = 'Произошла проблема при загрузке файла';
@@ -272,9 +274,5 @@ $lang['help'] = '<h3>Important Notes</h3>
 <li>Hit Submit</li>
 </ul>
 <p>Following these steps should solve the problem of your news templates not being found and other similar smarty errors when you upgrade to a version of CMS that has News 2.3 or greater.</p>';
-$lang['utmz'] = '156861353.1249691644.74.46.utmccn=(referral)|utmcsr=localhost|utmcct=/msnew/install/index.php|utmcmd=referral';
-$lang['utma'] = '156861353.1512485689.1236874721.1249691644.1250401334.75';
-$lang['utmc'] = '156861353';
-$lang['qca'] = 'P0-738804097-1250401341499';
-$lang['utmb'] = '156861353.1.10.1250401334';
+$lang['qca'] = 'P0-137572696-1265912509436';
 ?>
\ No newline at end of file
