@@ -20,6 +20,8 @@ $lang['expiry_date_desc'] = 'D&aacute;tum expir&aacute;cie - zostupne';
 $lang['expiry_date_asc'] = 'D&aacute;tum expir&aacute;cie - vzostupne';
 $lang['title_desc'] = 'Nadpis - zostupne';
 $lang['title_asc'] = 'Nadpis - vzostupne';
+$lang['status_desc'] = 'Stav vzostupne';
+$lang['status_asc'] = 'Stav zostupne';
 $lang['fesubmit_status'] = 'Stav novinky po odoslan&iacute; cez front-end';
 $lang['error_invalidfiletype'] = 'Nie je možn&eacute; nahrať tento typ s&uacute;boru';
 $lang['error_upload'] = 'Probl&eacute;m pri nahr&aacute;van&iacute; s&uacute;boru';
@@ -278,8 +280,10 @@ $lang['help'] = '<h3>D&ocirc;ležit&eacute; upozornenie</h3>
 <li>Hit Submit</li>
 </ul>
 <p>Following these steps should solve the problem of your news templates not being found and other similar smarty errors when you upgrade to a version of CMS that has News 2.3 or greater.</p>';
-$lang['utmz'] = '156861353.1242823757.727.119.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
-$lang['utma'] = '156861353.4300742689275601400.1213256953.1242818813.1242823757.727';
+$lang['qca'] = 'P0-1608926040-1271144175783';
+$lang['utma'] = '156861353.786385904.1271157997.1279783450.1279798608.56';
+$lang['utmz'] = '156861353.1279639848.54.48.utmcsr=geekmoot.com|utmccn=(referral)|utmcmd=referral|utmcct=/2010/news/7/15/Call-for-Papers/';
+$lang['chartbeat2'] = '87v0u4nbwegh3lki';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1242823757';
 ?>
\ No newline at end of file
