@@ -1,37 +1,39 @@
 <?php
-$lang['expired_searchable'] = 'S&uuml;resi bitmiş makaleler arama sonu&ccedil;larında &ccedil;ıkabilsin';
-$lang['helpshowall'] = 'T&uuml;m makaleleri g&ouml;ster, Bititş tarihine bakılmaksızın';
-$lang['error_invaliddates'] = 'Bir yada daha fazla Tarih yanlış girirldi';
+$lang['expired_searchable'] = 'S&uuml;resi bitmiş haberler arama sonu&ccedil;larında &ccedil;ıkabilsin';
+$lang['helpshowall'] = 'Bitiş tarihine bakılmaksızın t&uuml;m haberleri g&ouml;ster';
+$lang['error_invaliddates'] = 'Bir yada daha fazla tarih yanlış girirldi';
 $lang['notify_n_draft_items_sub'] = '%d Haber Yazıları(s)';
-$lang['notify_n_draft_items'] = 'You have %s that is/are not published';
+$lang['notify_n_draft_items'] = '%s sayıda yayınalnmamış haber var';
 $lang['unlimited'] = 'Limitsiz';
 $lang['none'] = 'Yok';
 $lang['anonymous'] = 'Anonim';
 $lang['unknown'] = 'Bilinmiyor';
 $lang['fesubmit_redirect'] = 'PageID or alias to redirect to after a news article has been submitted via the fesubmit action';
-$lang['allow_summary_wysiwyg'] = 'Allow using a WYSIWYG editor on the summary field';
+$lang['allow_summary_wysiwyg'] = '&Ouml;zet alanında WYSIWYG editore izin ver';
 $lang['title_browsecat_template'] = 'Browse Category Template Editor';
 $lang['title_browsecat_sysdefault'] = 'Default Browse category Template';
 $lang['browsecattemplate'] = 'Kategori şablonları';
-$lang['error_filesize'] = 'An uploaded file exceeded the maximum allowed size';
-$lang['post_date_desc'] = 'Post Date Descending';
-$lang['post_date_asc'] = 'Post Date Ascending';
-$lang['expiry_date_desc'] = 'Expiry Date Descending';
-$lang['expiry_date_asc'] = 'Expiry Date Ascending';
+$lang['error_filesize'] = 'Y&uuml;klenen dosyanın boyutu izin verilen dosya boyutundan fazla';
+$lang['post_date_desc'] = 'G&ouml;nderim Tarihi Azalan';
+$lang['post_date_asc'] = 'G&ouml;nderim Tarihi Artan';
+$lang['expiry_date_desc'] = 'Ge&ccedil;erlilik Tarihi Azalan';
+$lang['expiry_date_asc'] = 'Ger&ccedil;erlilik Tarihi Artan';
 $lang['title_desc'] = 'Başlığa G&ouml;re Azalan';
 $lang['title_asc'] = 'Başlığa G&ouml;re Artan';
+$lang['status_desc'] = 'Duruma G&ouml;re Azalan';
+$lang['status_asc'] = 'Durum G&ouml;re Azalan';
 $lang['fesubmit_status'] = 'The status of news articles submitted via the frontend';
-$lang['error_invalidfiletype'] = 'Cannot upload this type of file';
-$lang['error_upload'] = 'Problem occurred uploading a file';
-$lang['error_movefile'] = 'Could not create file: %s';
-$lang['error_mkdir'] = 'Could not create directory: %s';
+$lang['error_invalidfiletype'] = 'Bu dosya tipini y&uuml;kleyemezsiniz';
+$lang['error_upload'] = 'Dosya y&uuml;kleme hatası oluştu';
+$lang['error_movefile'] = 'Dosya oluşturulamadı: %s';
+$lang['error_mkdir'] = 'Klas&ouml;r oluşturulamadı: %s';
 $lang['expiry_interval'] = 'The number of days (by default) before an article expires (if expiry is selected)';
 $lang['removed'] = 'Geri Alındı';
 $lang['msg_contenttype_removed'] = 'The news content type has been removed.  Please place {news} tags with appropriate parameters into your page template or into your page content to replace this functionality.';
-$lang['delete_selected'] = 'Se&ccedil;ilen Makaleleri Sil';
+$lang['delete_selected'] = 'Se&ccedil;ilen Haberleri Sil';
 $lang['areyousure_deletemultiple'] = 'Se&ccedil;ilen haberleri kalıcı olarak silmek istediğinize emin misiniz? Bu durum geri alınamaz!';
 $lang['error_templatenamexists'] = 'Şablon adı zaten var';
-$lang['error_noarticlesselected'] = 'Hi&ccedil; Makale Se&ccedil;ilmedi';
+$lang['error_noarticlesselected'] = 'Hi&ccedil; Haber Se&ccedil;ilmedi';
 $lang['reassign_category'] = 'Kategori değiştir';
 $lang['select'] = 'Se&ccedil;iniz';
 $lang['approve'] = 'Durumu &#039;Yayınlandı&#039; olarak değiştir';
@@ -97,10 +99,10 @@ $lang['expired'] = 'S&uuml;resi Dolmuş';
 $lang['author'] = 'Yazar';
 $lang['sysdefaults'] = 'Varsayılanlara d&ouml;n';
 $lang['restoretodefaultsmsg'] = 'Bu işlem şablon i&ccedil;eriğini sistem varsayılanlarına &ccedil;evirecektir. Devam etmek istediğinizden emin misiniz?';
-$lang['addarticle'] = 'Makale Ekle';
-$lang['articleadded'] = 'Makale başarılı olarak eklendi.';
-$lang['articleupdated'] = 'Makale başarılı olarak g&uuml;ncellendi.';
-$lang['articledeleted'] = 'Makale başarılı olarak silindi.';
+$lang['addarticle'] = 'Haber Ekle';
+$lang['articleadded'] = 'Haber başarılı olarak eklendi.';
+$lang['articleupdated'] = 'Haber başarılı olarak g&uuml;ncellendi.';
+$lang['articledeleted'] = 'Haber başarılı olarak silindi.';
 $lang['addcategory'] = 'Kategori Ekle';
 $lang['categoryadded'] = 'Kategori başarılı olarak eklendi.';
 $lang['categoryupdated'] = 'Kategori başarılı olarak g&uuml;ncellendi.';
@@ -109,7 +111,7 @@ $lang['addnewsitem'] = 'Haber &Ouml;ğesi Ekle';
 $lang['allcategories'] = 'T&uuml;m Kategoriler';
 $lang['allentries'] = 'T&uuml;m Girdiler';
 $lang['areyousure'] = 'Silmek istediğinizden emin misiniz?';
-$lang['articles'] = 'Makaleler';
+$lang['articles'] = 'Haberler';
 $lang['cancel'] = 'Vazge&ccedil;';
 $lang['category'] = 'Kategori';
 $lang['categories'] = 'Kategoriler';
@@ -165,7 +167,7 @@ $lang['title'] = 'Başlık';
 $lang['options'] = 'Se&ccedil;enekler';
 $lang['optionsupdated'] = 'Se&ccedil;enekler başarılı olarak g&uuml;ncellendi.';
 $lang['useexpiration'] = 'S&uuml;resi ge&ccedil;me tarihini kullan';
-$lang['eventdesc-NewsArticleAdded'] = 'Makale eklendiğinde g&ouml;nderildi.';
+$lang['eventdesc-NewsArticleAdded'] = 'Haber eklendiğinde g&ouml;nderildi.';
 $lang['eventhelp-NewsArticleAdded'] = '<p>Sent when an article is added.</p>
 <h4>Parameters</h4>
 <ul>
@@ -180,7 +182,7 @@ $lang['eventhelp-NewsArticleAdded'] = '<p>Sent when an article is added.</p>
 <li>\&quot;useexp\&quot; - Whether the expiration date should be ignored or not</li>
 </ul>
 ';
-$lang['eventdesc-NewsArticleEdited'] = 'Makale d&uuml;zenlendiğinde g&ouml;nderildi.';
+$lang['eventdesc-NewsArticleEdited'] = 'Haber d&uuml;zenlendiğinde g&ouml;nderildi.';
 $lang['eventhelp-NewsArticleEdited'] = '<p>Sent when an article is edited.</p>
 <h4>Parameters</h4>
 <ul>
@@ -195,7 +197,7 @@ $lang['eventhelp-NewsArticleEdited'] = '<p>Sent when an article is edited.</p>
 <li>\&quot;useexp\&quot; - Whether the expiration date should be ignored or not</li>
 </ul>
 ';
-$lang['eventdesc-NewsArticleDeleted'] = 'Makale silindiğinde g&ouml;nderildi.';
+$lang['eventdesc-NewsArticleDeleted'] = 'Haber silindiğinde g&ouml;nderildi.';
 $lang['eventhelp-NewsArticleDeleted'] = '<p>Sent when an article is deleted.</p>
 <h4>Parameters</h4>
 <ul>
@@ -239,7 +241,7 @@ $lang['helpdetailtemplate'] = 'Use a separate template for displaying the articl
 $lang['helpsortby'] = 'Field to sort by.  Options are: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;.  Defaults to &quot;news_date&quot;.';
 $lang['helpsortasc'] = 'Sort news items in ascending date order rather than descending.';
 $lang['helpdetailpage'] = 'Page to display News details in.  This can either be a page alias or an id. Used to allow details to be displayed in a different template from the summary.';
-$lang['helpshowarchive'] = 'Sadece s&uuml;resi ge&ccedil;miş haber makalelerini g&ouml;ster.';
+$lang['helpshowarchive'] = 'Sadece s&uuml;resi ge&ccedil;miş haberleri g&ouml;ster.';
 $lang['helpbrowsecat'] = 'Taranabilir kategori listesini g&ouml;ster.';
 $lang['helpaction'] = 'Override the default action.  Possible values are &#039;default&#039; to display the summary view, and &#039;fesubmit&#039; to display the frontend form for allowing users to submit news articles on the front end.';
 $lang['help'] = '	<h3>What does this do?</h3>
@@ -255,8 +257,9 @@ $lang['help'] = '	<h3>What does this do?</h3>
 	<p>In order to edit the global news preferences, the user must belong to a group with the &#039;Modify Site Preferences&#039; permission.</p>
 	<h3>How do I use it?</h3>
 	<p>The easiest way to use it is with the {news} wrapper tag (wraps the module in a tag, to simplify the syntax).  This will insert the module into your template or page anywhere you wish, and display news items.  The code would look something like: <code>{news number=&#039;5&#039;}</code></p>';
-$lang['utma'] = '156861353.896187631.1236676121.1245834903.1245853554.34';
-$lang['utmz'] = '156861353.1244804747.30.11.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/search';
+$lang['utma'] = '156861353.1664897565.1272759163.1277761254.1277765691.32';
+$lang['utmz'] = '156861353.1277765691.32.5.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/project/files/250|utmcmd=referral';
+$lang['qca'] = 'P0-1960756361-1272759163370';
 $lang['utmc'] = '156861353';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
