@@ -59,7 +59,7 @@ visitor to a version of the page better suited for printing. It can also link
 to an basic on-the-fly-generated pdf version of the page.
 <br/>
 Please note that unless the parameter <i>includetemplate=true</i> is used, only the main output of the page is outputted. And note
-that the pdf-file outputted may not have much resemblance with you page, but should provide the content.
+that the pdf-file outputted may not have much resemblance with your page, but should provide the content.
 <br/><br/>
 <b>How do I use this module?</b>
 <br/>
@@ -75,10 +75,6 @@ or simply
 {print <i>params</i>}
 </pre>
 using the print-plugin
-<br/>
-';
-$lang['utma'] = '156861353.1700396481762948400.1243519364.1244791859.1245048249.9';
-$lang['utmz'] = '156861353.1245048249.9.6.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
-$lang['utmb'] = '156861353.1.10.1245048249';
-$lang['utmc'] = '156861353';
+<br/>';
+$lang['qca'] = 'P0-250679722-1271187168764';
 ?>
\ No newline at end of file
