@@ -1,5 +1,8 @@
 <?php
-$lang['search_method'] = 'Die Kompatibilit&auml;t f&uuml;r Pretty URLs f&uuml;r die POST-Methode, der voreingestellte Wert ist immer GET, damit dies funktioniert, verwenden Sie <code>{search search_method=&#039;post&#039;}</code>';
+$lang['use_or'] = 'Ergebnisse finden, die in irgend einem Wort enthalten sind';
+$lang['param_detailpage'] = 'Kann nur f&uuml;r Ergebnisse von Modulen verwendet werden, mit diesem Parameter kann eine abweichende Detailseite f&uuml;r die Ergebnisse festgelegt werden. Dies ist zum Beispiel dann n&uuml;tzlich, wenn Sie  die Detailansicht auf einer Seite mit einem anderen Template angezeigt werden soll.  <em>(<strong>Hinweis:</strong> Module haben die M&ouml;glichkeit, diesen Parameter zu &uuml;berschreiben.)</em>';
+$lang['prompt_resultpage'] = 'Die Seite f&uuml;r individuelle Modul-Ergebnisse <em>(Hinweis: Diese Einstellung kann optional von Modulen &uuml;berschrieben werden)</em>';
+$lang['search_method'] = 'Kompatibilit&auml;t f&uuml;r Pretty URLs f&uuml;r die POST-Methode, der voreingestellte Wert ist immer GET, damit dies funktioniert, verwenden Sie <code>{search search_method=&#039;post&#039;}</code>';
 $lang['export_to_csv'] = 'Als CSV-Datei exportieren';
 $lang['prompt_savephrases'] = 'Nach Wortgruppen suchen (nicht nach einzelnen W&ouml;rtern)';
 $lang['word'] = 'Wort';
@@ -85,8 +88,8 @@ $lang['help'] = '<h3>Was macht dieses Modul?</h3>
 <p>Das Search-Modul durchsucht grunds&auml;tzlich keine &quot;inaktiven&quot; Seiten. Wenn Sie (aus welchen Gr&uuml;nden auch immer) das CustomContent-Modul oder andere Smarty-Logik verwenden, um verschiedenen Nutzergruppen verschiedene Inhalte anzuzeigen, kann es erforderlich sein, die gesamte Seite von der Indizierung auszuschlie&szlig;en.</p>
 <p>Daf&uuml;r m&uuml;ssen Sie lediglich den folgenden Tag irgendwo in Ihrer Seite aufrufen <pre><!-- pageAttribute: NotSearchable --></pre></p>
 <p>Wenn das Search-Modul diesen Tag auf einer Seite findet, wird deren Inhalt nicht indiziert. Dieser Tag kann auch in Templates eingesetzt werden. In diesem Fall werden diejenigen Seiten, die dieses Template verwenden, nicht indiziert. Wird der Tag entfernt, erfolgt eine Neuindizierung dieser Seiten.</p>';
-$lang['utma'] = '156861353.717462736.1147511856.1247992807.1248000403.337';
-$lang['utmz'] = '156861353.1247989612.335.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utma'] = '156861353.230875029.1281005888.1281005888.1281005888.1';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1281005888.1.1.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
 ?>
\ No newline at end of file
