@@ -1,4 +1,7 @@
 <?php
+$lang['use_or'] = 'Risultati trovati che corrispondenti ad OGNI parola';
+$lang['param_detailpage'] = 'Usato solo per risultati corrispondenti dai moduli, questo parametro permette specificare una differente pagina per i risultati. Questo &egrave; utile se, per esampio, voi visualizzate sempre le vedute di dettaglio in una pagina con un differente template.  <em>(<strong>Nota:</strong> moduli hanno la possibilit&agrave; di sovrascrivere questo parametro.)</em>';
+$lang['prompt_resultpage'] = 'Pagina per risultati di moduli individuali <em>(Nota che i moduli possono opzionalmente sovrascrive questo)</em>';
 $lang['search_method'] = 'Compatibilit&agrave; Pretty Urls via metodo POST, valore predefinito &egrave; sempre GET, per utilizzarlo dovete mettere {search search_method=&quot;post&quot;}';
 $lang['export_to_csv'] = 'Esporta a CSV';
 $lang['prompt_savephrases'] = 'Traccia Frasi ricercate, non Parole Individuali';
@@ -84,8 +87,5 @@ $lang['help'] = '<h3>What does this do?</h3>
 <h4>How do i prevent certain content from being indexed</h4>
 <p>The search module will not search any &quot;inactive&quot; pages. However on occasion, when you are using the CustomContent module, or other smarty logic to show different content to different groups of users, it may be advisiable to prevent the entire page from being indexed even when it is live.  To do this include the following tag anywhere on the page <em>&amp;lt;!-- pageAttribute: NotSearchable --&amp;gt;</em> When the search module sees this tag in the page it will not index any content for that page.</p>
 <p>The <em>&amp;lt;!-- pageAttribute: NotSearchable --&amp;gt;</em> tag can be placed in the template as well.  if this is done, none of the pages attached to that template will be indexed.  Those pages will be re-indexed if the tag is removed</p>';
-$lang['utma'] = '156861353.880130626.1236353467.1240505117.1241641977.36';
-$lang['utmz'] = '156861353.1240505117.35.31.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
-$lang['utmb'] = '156861353';
-$lang['utmc'] = '156861353';
+$lang['qca'] = 'P0-250679722-1271187168764';
 ?>
\ No newline at end of file
