@@ -1,11 +1,13 @@
 <?php
+$lang['param_detailpage'] = 'Folosit numai pentru potrivirea rezultatelor din module, acest parametru permite specificarea unei pagini de detalii diferita pentru rezultate. Este util daca, de exemplu, tot timpul afisati detaliile intr-o pagina cu un template diferit.  <em>(<strong>Nota:</strong> modulele au posibilitatea de a suprascrie acest parametru.)</em>';
+$lang['prompt_resultpage'] = 'Pagina pentru rezultate module individuale <em>(Nota: modulele pot optional sa suprascrie acest parametru)</em>';
 $lang['search_method'] = 'Compatibilitate URL-uri frumoase via metoda POST, valoarea implicita este intotdeauna GET, pentru a face lucrurile sa functioneze puneti {search search_method=&quot;post&quot;} ';
 $lang['export_to_csv'] = 'Export format CSV';
 $lang['prompt_savephrases'] = 'Urmarire expresii cautare, nu cuvinte individuale';
 $lang['word'] = 'Cuvant';
 $lang['count'] = 'Numara';
 $lang['confirm_clearstats'] = 'Esti sigur(a) ca vrei sa cureti permanent statisticile';
-$lang['clear'] = 'Curata';
+$lang['clear'] = 'Curatare';
 $lang['statistics'] = 'Statistici';
 $lang['param_action'] = 'Specifica modul de operare a modulului. Valorile acceptate sunt &#039;lipsa&#039; si &#039;cuvintecheie&#039;. Actiunea Cuvintelorcheie poate fi folosita sa genereze o lista de virgule separate a cuvintelor potrivite pentru folosirea cuvintelorcheie meta ethicheta.';
 $lang['param_count'] = 'Folosit cu actiunea cuvantcheie, aceste parametru va limita productia la numerele specifice la cuvintelor.';
@@ -85,10 +87,9 @@ $lang['help'] = '<h3>What does this do?</h3>
 <p>The search module will not search any &quot;inactive&quot; pages. However on occasion, when you are using the CustomContent module, or other smarty logic to show different content to different groups of users, it may be advisiable to prevent the entire page from being indexed even when it is live.  To do this include the following tag anywhere on the page <em><!-- pageAttribute: NotSearchable --></em> When the search module sees this tag in the page it will not index any content for that page.</p>
 <p>The <em><!-- pageAttribute: NotSearchable --></em> tag can be placed in the template as well.  if this is done, none of the pages attached to that template will be indexed.  Those pages will be re-indexed if the tag is removed</p>
 ';
+$lang['utma'] = '156861353.912274264.1270642313.1270642313.1270642313.1';
+$lang['utmb'] = '156861353.1.10.1270642313';
 $lang['utmc'] = '156861353';
-$lang['utma'] = '156861353.3573843717708992500.1250056267.1250078602.1250085508.6';
-$lang['qcb'] = '1912438266';
-$lang['qca'] = '1249980835-92593492-79567608';
-$lang['utmz'] = '156861353.1250056267.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
-$lang['utmb'] = '156861353';
+$lang['utmz'] = '156861353.1270642313.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['qca'] = 'P0-1330130568-1270642313682';
 ?>
\ No newline at end of file
