@@ -1,4 +1,6 @@
 <?php
+$lang['param_detailpage'] = 'Used only for matching results from modules, this parameter allows specifying a different detail page for the results.  This is useful if, for example, you always display your detail views in a page with a different template.  <em>(<strong>Note:</strong> modules have the ability to override this parameter.)</em>';
+$lang['prompt_resultpage'] = 'Page for individual module results <em>(Note modules may optionally override this)</em>';
 $lang['search_method'] = 'Pretty Urls Compatibility via Method POST, default value is always GET, to make this work just put {search search_method=&quot;post&quot;} ';
 $lang['export_to_csv'] = 'Export CVS';
 $lang['prompt_savephrases'] = 'Track Search Phrases, not Individual Words';
@@ -19,7 +21,7 @@ $lang['param_submit'] = 'G&ouml;nder d&uuml;ğmesine konulacak yazı';
 $lang['param_searchtext'] = 'Arama kutusuna konulacak yazı';
 $lang['prompt_searchtext'] = 'Varsayılan Arama Yazısı';
 $lang['param_resultpage'] = 'Arama sonu&ccedil;larının g&ouml;sterileceği sayfa.  This can either be a page alias or an id.  Used to allow search results to be displayed in a different template from the search form';
-$lang['prompt_alpharesults'] = 'Sort results alphabetically instead of by weight';
+$lang['prompt_alpharesults'] = 'Arama sonu&ccedil;larını alfabetik olarak sırala';
 $lang['description'] = 'Module for search site and other module&#039;s contents.';
 $lang['reindexallcontent'] = 'T&uuml;m i&ccedil;eriği yeniden dizinle';
 $lang['reindexcomplete'] = 'Dizinleme Tamamlandı!';
@@ -85,8 +87,9 @@ $lang['help'] = '<h3>What does this do?</h3>
 <p>The search module will not search any &quot;inactive&quot; pages. However on occasion, when you are using the CustomContent module, or other smarty logic to show different content to different groups of users, it may be advisiable to prevent the entire page from being indexed even when it is live.  To do this include the following tag anywhere on the page <em><!-- pageAttribute: NotSearchable --></em> When the search module sees this tag in the page it will not index any content for that page.</p>
 <p>The <em><!-- pageAttribute: NotSearchable --></em> tag can be placed in the template as well.  if this is done, none of the pages attached to that template will be indexed.  Those pages will be re-indexed if the tag is removed</p>
 ';
-$lang['utma'] = '156861353.896187631.1236676121.1248713169.1249387646.41';
-$lang['utmz'] = '156861353.1249387646.41.17.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/list/module';
-$lang['utmb'] = '156861353.1.10.1249387646';
+$lang['utma'] = '156861353.1664897565.1272759163.1277761254.1277765691.32';
+$lang['utmz'] = '156861353.1277765691.32.5.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/project/files/250|utmcmd=referral';
+$lang['qca'] = 'P0-1960756361-1272759163370';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
