@@ -1,5 +1,5 @@
 <?php
-
+if (!isset($gCms)) exit;
 if (!$this->VisibleToAdminUser()) $this->Redirect($id,"defaultadmin",$returnid);
 
 if (isset($params["resetsettings"])) {
@@ -37,6 +37,9 @@ if (isset($params['editor_height'])) {
 }
 if (isset($params['editor_height_unit'])) $this->SetPreference('editor_height_unit', $params['editor_height_unit'] );
 
+if (isset($params['allowresizing'])) $this->SetPreference('allowresizing', $params['allowresizing'] );
+
+
 if (isset($params['filepickerstyle'])) $this->SetPreference('filepickerstyle', $params['filepickerstyle'] );
 
 if (isset($params['fpwidth'])) {
@@ -58,6 +61,10 @@ if (isset($params['scalingwidth'])) {
   if (is_numeric($params["scalingwidth"])) $this->SetPreference('scalingwidth', $params['scalingwidth'] );
 }
 
+if (isset($params['makethumbnail']))
+$this->SetPreference('makethumbnail', 1 );
+else
+$this->SetPreference('makethumbnail', 0 );
 
 
 if (isset($params['dateformat'])) $this->SetPreference('dateformat', $params['dateformat'] );
