@@ -20,6 +20,7 @@ $lang['allowuploadtext'] = 'Tillad upload og mappe-oprettelse i Filv&aelig;lger'
 $lang['allowscalingtext'] = 'Tillad on-the-fly skalering af upload&#039;ede billeder';
 $lang['scalingdimensionstext'] = 'Standard dimensioner';
 $lang['resizeto'] = 'Skal&eacute;r til:';
+$lang['makethumbnail'] = 'Lav billedeksempel n&aring;r et billede upload&#039;es';
 $lang['useadvancedprofile'] = 'Tillad avanceret TinyMCE-profil';
 $lang['saveprofile'] = 'Gem profil';
 $lang['profilesaved'] = 'Profilen blev gemt';
@@ -29,9 +30,16 @@ $lang['savestyles'] = 'Gem stilarter';
 $lang['allowadvancedprofile'] = 'Tillad brug af den avancerede profil i TinyMCE';
 $lang['showfilemanagement'] = 'Vis filh&aring;ndterings muligheder';
 $lang['showfilemanagementhelp'] = 'Viser filh&aring;ndtering muligheder s&aring;som upload, mkdir og sletning af filer i FilV&aelig;lgeren';
+$lang['restrictdirs'] = 'Begr&aelig;ns brugeres mappe adgang';
+$lang['restrictdirshelp'] = 'Dette vil begr&aelig;nse de filh&aring;ndterings muligheder en bruger har til kun at d&aelig;kke en undermappe til &#039;uploads&#039; som har det samme navn som brugerens login. Hvis mappen ikke eksisterer vil den blive oprettet. Bem&aelig;rk at dette kun virker med standard mappenavnene, uploads/images. Dette &aelig;ndres muligvis i fremtiden.';
 $lang['deleteconfirmation'] = 'Er du sikker p&aring; denne fil skal slettes?';
 $lang['deletefilesuccess'] = 'blev slettet';
-$lang['deletefilefila'] = 'kunne ikke slettes';
+$lang['deletefilefailed'] = 'kunne ikke slettes';
+$lang['deletesubdirfailed'] = 'kunne ikke slettes';
+$lang['deletesubdirsuccess'] = 'blev slettets';
+$lang['deletedirconfirmation'] = 'Er du sikker p&aring; denne tomme mappe skal slettes?';
+$lang['deletedir'] = 'Slet tom mappe';
+$lang['deletefile'] = 'Slet fil';
 $lang['cannotreadconfig'] = 'Kan ikke l&aelig;se tinyconfig.php direkte, s&aring; TinyMCE vil formentlig ikke virke. Du skal kontrollere rettigheder p&aring; denne fil og mappen den ligger i, disse b&oslash;r tillade l&aelig;sning, men kun skrivning for ejeren.';
 $lang['filenameonly'] = 'Vis filnavne';
 $lang['thumbnailsonly'] = 'Vis billedeeksempler';
@@ -53,12 +61,16 @@ $lang['editor_width_text'] = 'Editor feltets bredde';
 $lang['editor_height_text'] = 'Editor feltets h&oslash;jde';
 $lang['auto'] = 'Automatisk';
 $lang['or'] = 'eller';
+$lang['allowresizing'] = 'Tillad at editor feltets st&oslash;rrelse kan &aelig;ndres';
+$lang['resizenone'] = 'Tillad ikke &aelig;ndring af st&oslash;rrelsen';
+$lang['resizeboth'] = 'Tillad &aelig;ndringer af st&oslash;rrelsen i begge retninger';
+$lang['resizeheight'] = 'Tillad kun &aelig;ndring af h&oslash;jden';
 $lang['datetimeformat_text'] = 'Dato/Tid format';
 $lang['timetext'] = 'Tid';
 $lang['datetext'] = 'Dato';
 $lang['datetimeformat_help'] = 'Klik her for at hvordan dato/tid formateres';
 $lang['extraconfigtext'] = 'Ekstra konfiguration';
-$lang['extraconfighelp'] = 'En kommando pr. linie, ingen kommaer, tak. Se TinyMCE-wiki for instruktioner.';
+$lang['extraconfighelp2'] = 'En kommando pr. linie, kommaer vil blive tilf&oslash;je f&oslash;r og efter dette indhold. Se  TinyMCE-wiki&#039;en for n&aelig;rmere instruktioner.';
 $lang['customdropdowntext'] = 'Brugerdefineret menu';
 $lang['customdropdownhelp'] = 'Giver mulighed for at brugerdefinerede stumper kode kan inds&aelig;ttes ved at v&aelig;lge i en menu. Man kunne forstille sig nem inds&aelig;ttelse af tags mm. Menuen placeres i v&aelig;rkt&oslash;jslinien ved at inds&aelig;tte &#039;customdropdown&#039;.';
 $lang['startenabledtext'] = 'Sl&aring;et til fra starten';
@@ -78,6 +90,8 @@ $lang['includeonlyscreencss_help'] = 'Hvis dette er sl&aring;et til inkluderes k
 $lang['usestaticconfigtext'] = 'Benyt statisk konfiguration';
 $lang['usestaticconfighelp'] = 'Dette kan hj&aelig;lpe med at f&aring; Tiny til at virke p&aring; systemer hvor hosting&#039;en automatisk tilf&oslash;jer ting til filerne, hvilket kan &oslash;del&aelig;gge f.eks. dynamisk genererede javascript-filer.';
 $lang['usestaticconfigwarning'] = 'Advarsel! Du har statisk konfiguration sl&aring;et til men der kan ikke skrives til /tmp/. Dette g&oslash;r det umuligt for modelet at gemme den statistk konfigurations-fil og vil h&oslash;jst sandsynligt g&oslash;re at TinyMCE ikke virker.';
+$lang['ignoremodifyfilestext'] = 'Ignor&eacute;r &#039;Modify Files&#039; tilladelsen for FilV&aelig;lgeren';
+$lang['ignoremodifyfileshelp'] = 'Advarsel! Dette giver mulighed for nogle fil-&aelig;ndrende handlinger selv om &#039;Modify Files&#039; tilladelsen ikke er sat for den aktuelle brugergruppe. Dette er is&aelig;r brugbart sammen med muligheden for at begr&aelig;nse brugerens adgang til sin egen mappe.';
 $lang['showtogglebutton_text'] = 'Vis checkbox til at sl&aring; wysiwyg til/fra';
 $lang['togglewysiwyg'] = 'Sl&aring; WYSIWYG til/fra';
 $lang['styles_tab'] = 'CSS stilarter';
@@ -110,7 +124,11 @@ $lang['plugins_tab'] = 'Udvidelser';
 $lang['plugins_help'] = 'V&aelig;lg de udvidelser du &oslash;nsker at aktivere. Dokumentation kan findes  <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">her</a>';
 $lang['plugins_text'] = 'Udvidelser';
 $lang['saveplugins'] = 'Gem udvidelser';
-$lang['pluginssaved'] = 'Udvidelser gemt';
+$lang['plugins_module'] = 'Modul udvidelser';
+$lang['plugins_common'] = 'Almindelige udvidelser';
+$lang['module'] = 'Modul';
+$lang['description'] = 'Beskrivelse';
+$lang['plugin'] = 'Udvidelse';
 $lang['youareintext'] = 'Du er i';
 $lang['loadstylesheettext'] = 'Indl&aelig;s stylesheet for indholdet (anbefalet)';
 $lang['extrastylestext'] = 'Tilf&oslash;jelser til stylesheet';
@@ -125,6 +143,7 @@ $lang['newdircreated'] = 'Mappen blev oprettet';
 $lang['newdirfailed'] = 'Der skete en fejl ved oprettelse af mappen';
 $lang['nofile'] = 'Ingen fil blev upload&#039;et';
 $lang['filetoobig'] = 'Den upload&#039;ede fil er for stor';
+$lang['containsillegalchars'] = 'Filnavnet indeholder et eller flere ugyldige tegn (&#039;,&quot;,+,*,\,/,&amp;,$)';
 $lang['uploadfailed'] = 'Der skete en fejl ved flytning af den upload&#039;ede fil';
 $lang['fileuploaded'] = 'Filen blev upload&#039;et';
 $lang['filepickertitle'] = 'CMS MadeSimple Fil V&aelig;lger';
@@ -138,6 +157,8 @@ $lang['help'] = '	<h3>Hvad g&oslash;r dette modul?</h3>
 	<p>Tillader at TinyMCE kan bruges som WYSIWYG-editor.</p>
 	<h3>Hvordan bruger jeg det??</h3>
 	<p>Install&eacute;r det, g&aring; til bruger indstillinger og v&aelig;lg TinyMCE som det &oslash;nskede WYSIWYG-system.</p>
+  <h3>Spellchecker</h3>
+  <p>Fra og med version 2.6.0, har TinyMCE f&aring;et en online stavekontrol. Men bem&aelig;rk venligst at SSL skal v&aelig;re sl&aring;et til p&aring; serveren for at dette virker. P&aring; nogle installationer hedder denn konfiguration php_openssl men det kan v&aelig;re anderledes.</p>
 
 <h3>Probleml&oslash;sning</h3>
 	Nogle brugere har problemer med at Tiny ikke viser sig efter installation eller opgradering. Her er en liste af ting der kan pr&oslash;ves f&oslash;r udviklerne kontaktes.
@@ -151,8 +172,9 @@ $lang['help'] = '	<h3>Hvad g&oslash;r dette modul?</h3>
 	<br/>
 		
 ';
-$lang['utma'] = '156861353.2039886585.1231713618.1247618697.1247670804.57';
-$lang['utmz'] = '156861353.1247618697.56.10.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
-$lang['utmc'] = '156861353';
+$lang['utma'] = '156861353.2039886585.1231713618.1271171160.1271510355.119';
+$lang['utmz'] = '156861353.1271089804.117.25.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/list_tagged/content2';
+$lang['qca'] = '1229601790-85243197-43260713';
 $lang['utmb'] = '156861353';
+$lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
