@@ -20,6 +20,7 @@ $lang['allowuploadtext'] = 'Das Hochladen und die Erstellung von Verzeichnissen
 $lang['allowscalingtext'] = 'Eine sofortige Gr&ouml;&szlig;en&auml;nderungen der hochgeladenen Bilddateien erlauben';
 $lang['scalingdimensionstext'] = 'Voreingestellte Abmessungen';
 $lang['resizeto'] = 'Gr&ouml;&szlig;e &auml;ndern auf:';
+$lang['makethumbnail'] = 'Vorschaubilder erstellen, wenn Bilder hochgeladen werden';
 $lang['useadvancedprofile'] = 'Erweitertes TinyMCE-Profil verwenden';
 $lang['saveprofile'] = 'Profil speichern';
 $lang['profilesaved'] = 'Das Profil wurde gespeichert';
@@ -29,9 +30,16 @@ $lang['savestyles'] = 'Styles speichern';
 $lang['allowadvancedprofile'] = 'Die Verwendung von erweiterten Profilen im TinyMCE erlauben';
 $lang['showfilemanagement'] = 'Optionen zur Dateiverwaltung anzeigen';
 $lang['showfilemanagementhelp'] = 'Optionen zur Dateiverwaltung wie Hochladen, Verzeichnis erstellen und Dateien l&ouml;schen anzeigen (falls dem Benutzer das Ausf&uuml;hren dieser Aktionen erlaubt ist)';
+$lang['restrictdirs'] = 'Benutzer-Zugriff auf Verzeichnisse beschr&auml;nken';
+$lang['restrictdirshelp'] = 'Hiermit k&ouml;nnen die M&ouml;glichkeiten eines Benutzers zur Verwaltung von Dateien auf ein Unterverzeichnis von&#039;uploads&#039; beschr&auml;nkt werden, dessen Name identisch mit dem Benutzernamen ist. Wenn dieses Unterverzeichnis nicht existiert, wird es erstellt. Bitte beachten Sie, dass dies aktuell nur mit den Standard-Verzeichnisnamen uploads/images funktioniert. Dies soll sich aber in Zukunft &auml;ndern.';
 $lang['deleteconfirmation'] = 'Wollen Sie diese Datei wirklich l&ouml;schen?';
 $lang['deletefilesuccess'] = 'wurde erfolgreich gel&ouml;scht';
-$lang['deletefilefila'] = 'konnte nicht gel&ouml;scht werden';
+$lang['deletefilefailed'] = 'konnte nicht gel&ouml;scht werden';
+$lang['deletesubdirfailed'] = 'konnte nicht gel&ouml;scht werden';
+$lang['deletesubdirsuccess'] = 'wurde gel&ouml;scht';
+$lang['deletedirconfirmation'] = 'Wollen Sie wirklich das leere Unterverzeichnis l&ouml;schen?';
+$lang['deletedir'] = 'Leeres Unterverzeichnis l&ouml;schen';
+$lang['deletefile'] = 'Datei l&ouml;schen';
 $lang['cannotreadconfig'] = 'Konnte die Datei tinyconfig.php nicht auslesen, so dass TinyMCE m&ouml;glicherweise nicht funktioniert. Pr&uuml;fen Sie die Berechtigungen der Datei und des &uuml;bergeordneten Verzeichnisses . Diese sollten lesbar f&uuml;r alle, aber nur f&uuml;r Eigent&uuml;mer beschreibbar sein.';
 $lang['filenameonly'] = 'Dateinamen anzeigen';
 $lang['thumbnailsonly'] = 'Vorschaubilder anzeigen';
@@ -53,12 +61,16 @@ $lang['editor_width_text'] = 'Breite des Editor-Feldes';
 $lang['editor_height_text'] = 'H&ouml;he des Editor-Feldes';
 $lang['auto'] = 'Automatisch';
 $lang['or'] = 'oder';
+$lang['allowresizing'] = 'Erlaubt die Gr&ouml;&szlig;en&auml;nderung von Bildern innerhalb des Editorfeldes';
+$lang['resizenone'] = 'Keine &Auml;nderungen erlauben';
+$lang['resizeboth'] = '&Auml;nderungen in beide Richtungen erlauben';
+$lang['resizeheight'] = 'Nur &Auml;nderungen der Bildh&ouml;he erlauben';
 $lang['datetimeformat_text'] = 'Datums-/Zeit-Format';
 $lang['timetext'] = 'Zeit';
 $lang['datetext'] = 'Datum';
 $lang['datetimeformat_help'] = 'Klicken Sie hier f&uuml;r eine Hilfe, wie Sie die Ausgabe von Datum und Zeit formatieren k&ouml;nnen';
 $lang['extraconfigtext'] = 'Weitere Optionen';
-$lang['extraconfighelp'] = 'Weitere Informationen dazu finden Sie im <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Configuration" target="_blank">TinyMCE-Wiki</a>.';
+$lang['extraconfighelp2'] = 'Eine Vorgabe pro Zeile, Kommatas werden vor dem nach diesem Inhalt hinzugef&uuml;gt. F&uuml;r weitere Informationen schauen Sie ins Wiki auf der TinyMCE-Webseite.';
 $lang['customdropdowntext'] = 'Benutzerdefiniertes Listenfeld';
 $lang['customdropdownhelp'] = 'Hiermit k&ouml;nnen zuvor definierte Code- oder Text-Schnipsel &uuml;ber ein Listenfeld-Men&uuml; eingef&uuml;gt werden. Eine naheliegende Anwendung w&auml;re zum Beispiel der einfache Zugriff auf h&auml;ufig verwendete Tags usw. Das Men&uuml; wird &uuml;ber &#039;customdropdown&#039; in die Werkzeugleiste eingef&uuml;gt.';
 $lang['startenabledtext'] = 'WYSIWYG aktiviert';
@@ -78,6 +90,8 @@ $lang['includeonlyscreencss_help'] = 'Wenn Sie diese Option ausw&auml;hlen, werd
 $lang['usestaticconfigtext'] = 'Eine statische Konfigurationsdatei verwenden';
 $lang['usestaticconfighelp'] = 'Diese Option kann helfen, TinyMCE auf Hosting-Accounts lauff&auml;hig zu bekommen, bei denen der Hoster diverse Sachen wie Statistiken und &auml;hnliches in die Ausgabe einbindet, wodurch jedoch eine dynamisch via Javascript erzeugte Konfigurationsdatei zerst&ouml;rt wird.';
 $lang['usestaticconfigwarning'] = 'Warnung! Sie haben die Option f&uuml;r eine statische Konfigurationsdatei aktiviert, aber Ihr /tmp-Verzeichnis ist nicht beschreibbar. Dies hindert das Modul an der Speicherung der statischen Konfigurationsdatei, wodurch TinyMCE h&ouml;chstwahrscheinlich nicht funktionieren wird.';
+$lang['ignoremodifyfilestext'] = 'Die Berechtigung &#039;Modify Files&#039; f&uuml;r den FilePicker ignorieren';
+$lang['ignoremodifyfileshelp'] = 'Warnung! Damit erlauben Sie einige Optionen zur Dateiverwaltung, obwohl die Berechtigung &#039;Modify Files&#039; f&uuml;r die aktuelle Benutzergruppe nicht gesetzt wurde. Dies kann effizient mit der Option zur Beschr&auml;nkung der Verzeichnisberechtigungen eingesetzt werden.';
 $lang['showtogglebutton_text'] = 'Kontrollfeld zum Aktiveren/Deaktivieren der WYSIWYG-Option anzeigen';
 $lang['togglewysiwyg'] = 'WYSIWYG aktivieren/deaktivieren';
 $lang['styles_tab'] = 'CSS-Stile';
@@ -111,9 +125,14 @@ $lang['backend_toolbars'] = 'Einstellungen f&uuml;r die Werkzeugleiste in der Ad
 $lang['frontend_toolbars'] = 'Einstellungen f&uuml;r die Werkzeugleiste auf der Webseite';
 $lang['plugins_tab'] = 'Erweiterungen';
 $lang['plugins_help'] = 'W&auml;hlen sie hier die TinyMCE-Erweiterungen aus, die sie aktivieren m&ouml;chten. F&uuml;r weitere Informationen lesen sie bitte die <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">Dokumentation</a>.';
-$lang['plugins_text'] = 'Erweiterungen';
-$lang['saveplugins'] = 'Erweiterungsauswahl speichern';
-$lang['pluginssaved'] = 'Die Erweiterungen wurden gespeichert.';
+$lang['plugins_text'] = 'Plugins ';
+$lang['saveplugins'] = 'Plugin-Auswahl speichern';
+$lang['pluginssaved'] = 'Plugin-Auswahl gespeicht';
+$lang['plugins_module'] = 'Modul-Plugins';
+$lang['plugins_common'] = 'Andere Plugins';
+$lang['module'] = 'Modul';
+$lang['description'] = 'Beschreibung';
+$lang['plugin'] = 'Plugin ';
 $lang['youareintext'] = 'Sie sind in ';
 $lang['loadstylesheettext'] = 'Das Stylesheet f&uuml;r den Inhalt laden (empfohlen)';
 $lang['extrastylestext'] = 'Das Stylesheet erg&auml;nzen mit';
@@ -128,6 +147,7 @@ $lang['newdircreated'] = 'Das neue Verzeichnis wurde erstellt';
 $lang['newdirfailed'] = 'Bei der Erstellung des Verzeichnisses ist ein Fehler aufgetreten';
 $lang['nofile'] = 'Es wurde keine Datei hochgeladen';
 $lang['filetoobig'] = 'Die hochgeladene Datei ist zu gro&szlig;';
+$lang['containsillegalchars'] = 'Der Dateiname enth&auml;lt ein oder mehrere nicht erlaubte Zeichen (&#039;,&quot;,+,*,\,/,&amp;,$)';
 $lang['uploadfailed'] = 'Beim Verschieben der hochgeladenen Datei an die vorgegebene Stelle ist ein Fehler aufgetreten.';
 $lang['fileuploaded'] = 'Die Datei wurde hochgeladen';
 $lang['filepickertitle'] = 'CMS-Made-Simple-Dateiauswahl';
@@ -137,11 +157,12 @@ $lang['thousanddelimiter'] = ', ';
 $lang['size'] = 'Gr&ouml;&szlig;e';
 $lang['dimensions'] = 'BxH';
 $lang['advanced_tab'] = 'Weitere Optionen';
-$lang['help'] = '<h3>Was macht dieses Modul?</h3>
+$lang['help'] = '       <h3>Was macht dieses Modul?</h3>
 	<p>Es stellt den TinyMCE als WYSIWYG-Editor zur Verf&uuml;gung.</p>
 	<h3>Wie wird es benutzt?</h3>
 	<p>Nach der Installation k&ouml;nnen Sie in der Administration im Men&uuml; &bdquo;Meine Einstellungen -> Benutzerspezifische Einstellungen&ldquo; TinyMCE als WYSIWYG-Editor ausw&auml;hlen.</p>
-	<p>F&uuml;r die Benutzergruppe, die die Einstellungen von TinyMCE &auml;ndern darf, muss die entsprechende Berechtigung gesetzt werden.</p>
+  <h3>Sprachpr&uuml;fung</h3>
+  <p>Seit Version 2.6.0 enth&auml;lt TinyMCE eine online Sprachpr&uuml;fung. Bitte beachten Sie, dass in Ihrer Server-Konfiguration SSL aktiviert sein muss, damit dies funktioniert. Bei einigen Installationen wird diese Option php_openssl genannt, dies kann aber auch davon abweichen.</p>
 	<h3>Fehlersuche</h3>
 	<p>Einige Anwender haben Probleme mit der Anzeige des TinyMCE nach der Installation oder Aktualisierung. Im folgenden finden Sie eine Checkliste, 
 	die Sie abarbeiten sollten, bevor Sie mich um Unterst&uuml;tzung bitten.</p>
@@ -151,9 +172,9 @@ $lang['help'] = '<h3>Was macht dieses Modul?</h3>
 	<li>Falls Sie das Modul aktualisiert haben, versuchen Sie, s&auml;mtliche Einstellungen auf die programmseitigen Vorgaben zur&uuml;ckzusetzen. Ich wei&szlig;, dass das nicht gerade sch&ouml;n ist, wenn Sie TinyMCE bereits individuell angepasst hatten, aber mit der Umstellung des Moduls von 2.3.x auf 2.4.x sind eine Menge &Auml;nderungen erfolgt.</li>
 	<li>Versuchen Sie, in der Registerkarte &bdquo;Weitere Optionen&ldquo; die Option zur Verwendung einer statischen Konfigurationsdatei zu verwenden. Auf manchen (CGI-basierten) Systemen funktioniert dies besser.</li>
 	</ol>';
-$lang['qca'] = 'P0-2023103406-1252991699666';
-$lang['utma'] = '156861353.1242236626.1252994908.1252994908.1252994908.1';
-$lang['utmb'] = '156861353';
+$lang['qca'] = 'P0-75091478-1268421814072';
+$lang['utmz'] = '156861353.1276509051.33.21.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['utma'] = '156861353.728989452.1268567475.1276509051.1276511098.34';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1252994908.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
