@@ -1,5 +1,5 @@
 <?php
-$lang['friendlyname'] = 'TinyMCE WYSIWYG B&aacute;sico';
+$lang['friendlyname'] = 'Editor WYSIWYG TinyMCE ';
 $lang['uninstalled'] = 'Modulo Desinstalado.';
 $lang['installed'] = 'Versi&oacute;n %s instalada.';
 $lang['stripbackgroundtags'] = 'Quitar etiquetas del fondo del CSS';
@@ -20,6 +20,7 @@ $lang['allowuploadtext'] = 'Permitir subir y crear directorios en el Seleccionad
 $lang['allowscalingtext'] = 'Permitir cambio de tama&ntilde;o instantaneamente al subir imagenes';
 $lang['scalingdimensionstext'] = 'Dimensiones por defecto';
 $lang['resizeto'] = 'Cambia tama&ntilde;o a:';
+$lang['makethumbnail'] = 'Crear miniatura cuando se suban imagenes';
 $lang['useadvancedprofile'] = 'Usar perfil avanzado de TinyMCE';
 $lang['saveprofile'] = 'Guardar perfil';
 $lang['profilesaved'] = 'El perfil fue guardado';
@@ -29,9 +30,15 @@ $lang['savestyles'] = 'Guarar estilos';
 $lang['allowadvancedprofile'] = 'Permitir uso de perfiles avanzados en TinyMCE';
 $lang['showfilemanagement'] = 'Mostrar opciones de administraci&oacute;n de archivos';
 $lang['showfilemanagementhelp'] = 'Mostrar opciones de administraci&oacute;n de archivos como subir, crear directorio, eliminar archivos en FilePicker, si el usuaro tiene permiso de ejecutar estas acciones';
+$lang['restrictdirs'] = 'Restringir permisos de acceso a directorios';
+$lang['restrictdirshelp'] = 'Esto restringir&aacute; la administraci&oacute;n de archivos del usuario a un sub-directorio de &#039;uploads&#039; que tendr&aacute; el mismo nombre que el nombre de usuario.  Si el sub-directorio no existe, posiblemente ser&aacute; creado. Nota: Esto es un trabajo en proceso y solo funciona con nombres estandar de directorios, uploads/images. Esto puede que cambie en un futuro.';
 $lang['deleteconfirmation'] = '&iquest;Est&aacute; seguro que quiere borrar el archivo?';
 $lang['deletefilesuccess'] = 'fue borrado';
-$lang['deletefilefila'] = 'no se pudo borrar';
+$lang['deletefilefailed'] = 'no se pudo borrar';
+$lang['deletesubdirfailed'] = 'no se pudo borrar';
+$lang['deletesubdirsuccess'] = 'se borr&oacute; exitosamente';
+$lang['deletedirconfirmation'] = '&iquest;Esta seguro de borrar el directorio vac&iacute;o?';
+$lang['deletedir'] = 'Borrar directorio vacio';
 $lang['cannotreadconfig'] = 'No se pudo leeer el archivo tinyconfig.php directamente, por lo que TinyMCE no funcionara. Deber&aacute; revisar los permisos de dicho archivo y de los directorios origen, los cuales deben tener permisos de lectura para todos y de escritura para el propietario.';
 $lang['filenameonly'] = 'Mostrar nombres de archivo';
 $lang['thumbnailsonly'] = 'Mostrar vistas miniatura';
@@ -52,34 +59,34 @@ $lang['toolbarhelptext'] = 'Haga click aqui para ver intrucciones sobre la barra
 $lang['editor_width_text'] = 'Ancho del campo de edici&oacute;n';
 $lang['editor_height_text'] = 'Altura del campo de edici&oacute;n';
 $lang['auto'] = 'Automatico';
-$lang['or'] = 'o';
+$lang['or'] = '&oacute;';
 $lang['datetimeformat_text'] = 'Formato Fecha/Hora';
 $lang['timetext'] = 'Hora';
 $lang['datetext'] = 'Fecha';
 $lang['datetimeformat_help'] = 'Haga clic aqui para ayuda sobre como formatear la fecha/hora';
 $lang['extraconfigtext'] = 'Configuraci&oacute;n extra';
-$lang['extraconfighelp'] = 'Consultar el wiki de TinyMCE para instrucciones';
+$lang['extraconfighelp2'] = 'Una declaraci&oacute;n por linea, comas ser&aacute;n agregadas antes y despues. Por favor revise el wiki de TinyMCE para mas instrucciones.';
 $lang['customdropdowntext'] = 'Men&uacute; desplegable personalizado';
 $lang['customdropdownhelp'] = 'Inserta fragmentos personalizados de c&oacute;digo/texto a trav&eacute;s de selecc&iacute;on de un men&uacute; desplegable. Por ejemplo acceso f&aacute;cil a etiquetas, etc. El men&uacute; es insertado en la barra de herramientas usando &#039;customdropdown&#039;.';
 $lang['startenabledtext'] = 'Inicio activado';
-$lang['startenabledhelp'] = 'Desabilitando esto inicia los editores TinyMCE de forma desabilitada. Se debe utilizar junto con la caja de Abrir/Cerrar WYSIWYG';
-$lang['loadcmslinkertext'] = 'Cargar el CMSmslinker';
+$lang['startenabledhelp'] = 'Al desabilitar esto, se iniciar&aacute;n los editores TinyMCE de forma oculta. Se debe utilizar junto con la caja de Mostrar/Ocultar WYSIWYG';
+$lang['loadcmslinkertext'] = 'Cargar el CMS-linker';
 $lang['loadcmslinkerhelp'] = 'Esto genera el codigo de javascript necesario para permitir que &#039;cmslinker&#039; sea agregado a la barra de herramientas.';
 $lang['cmslinkerstyletext'] = 'Estilo de enlaces CMS-linker';
 $lang['cmsselflinkstyle'] = 'Estilo {cms_selflink}(con soporte para URLs amigables)';
-$lang['ahrefstyle'] = '<a href>-style (not supporting pretty urls)';
+$lang['ahrefstyle'] = 'estilo <a href>(sin soporte de a URLs amigables)';
 $lang['relativeurlstext'] = 'Generar URLs relativos';
 $lang['forcecleanpastetext'] = 'Forzar limpieza al pegar';
 $lang['forcecleanpastehelp'] = 'Esto deberia de estar habilitado para remover codigos extra&ntilde;os de formato cuando se pega contenido de Word, etc.';
-$lang['bodycss_text'] = 'Tag CSS del Body';
+$lang['bodycss_text'] = 'CSS para etiqueta Body';
 $lang['bodycss_help'] = 'deje BLANK o establezca DEFAULT para usar PAGE CSS. Nota: Para que el fondo del editor sea de color blanco ponga lo siguiente en el blank: background-color:white;';
 $lang['includeonlyscreencss_text'] = 'Incluir solo CSS de pantalla';
 $lang['includeonlyscreencss_help'] = 'Seleccionar esto permite que solo plantillas de estilos que tienen el medio:pantalla seleccionado, sean incluidos en los estilos que TinyMCE maneja.';
 $lang['usestaticconfigtext'] = 'Usar un archivo de configuraci&oacute;n est&aacute;tico';
 $lang['usestaticconfighelp'] = 'Esto puede ayudar a que TinyMCE funcione en sistemas en los que las facilidades de hospedaje a&ntilde;aden cosas como estadisticas etc, lo cual rompe el archivo de configuracion javascript creado dinamicamente.';
 $lang['usestaticconfigwarning'] = 'Advertencia! Tiene la opci&oacute;n de Archivo de Configuraci&oacute;n Estatico habilitada pero el directorio /tmp/ no tiene permiso de escritura. Esto previene al modulo de guardar el archivo estatico y es muy probable que TinyMCE no funcione.';
-$lang['showtogglebutton_text'] = 'Mostrar caja de tildar para abrir/cerrar wysiwyg';
-$lang['togglewysiwyg'] = 'Abrir/Cerrar WYSIWYG';
+$lang['showtogglebutton_text'] = 'Mostrar caja de tildar para abrir/cerrar WYSIWYG';
+$lang['togglewysiwyg'] = 'Mostrar/Ocultar WYSIWYG';
 $lang['styles_tab'] = 'Estilos CSS';
 $lang['styles_help'] = 'Si usted deja el campo vac&iacute;o, TinyMCE va a parsear su archivo CSS y listar los estilos contenidos en &eacute;l, al usuario. Si usted lo que desea es s&oacute;lo presentar al usuario algunos estilos, especifique a ellos de la forma &quot;Style 1=style1; Style 2=style2&quot; en el primer campo de abajo. En los campos restantes, usted puede especificar los estilos CSS para Tablas, Filas, y Celdas que son utilizados en los correspondientes di&aacute;logos. Para un campo vac&iacute;o, se usar&aacute; el estilo del estilo general.';
 $lang['css_styles_text'] = 'General';
@@ -111,7 +118,7 @@ $lang['plugins_help'] = 'Seleccionar que plugins desea activar. La documentaci&o
 $lang['plugins_text'] = 'Plugins ';
 $lang['saveplugins'] = 'Guardar plugins';
 $lang['pluginssaved'] = 'Plugins guardados';
-$lang['youareintext'] = 'Ud. est&aacute; en';
+$lang['youareintext'] = 'Usted est&aacute; en';
 $lang['loadstylesheettext'] = 'Cargar hoja de estilos para el contenido (se recomienda)';
 $lang['extrastylestext'] = 'Adiciones a la plantilla de estilos';
 $lang['extrastyleshelp'] = 'Estilos CSS ingresados aqui seran a&ntilde;adidos a la plantilla de estilos leidos por TinyMCE despues de que recibe los estilos de CMSms.';
@@ -125,6 +132,7 @@ $lang['newdircreated'] = 'Nuevo directorio fue creado';
 $lang['newdirfailed'] = 'Ocurri&oacute; un error al tratar de crear el directorio';
 $lang['nofile'] = 'No se subi&oacute; ning&uacute;n archivo';
 $lang['filetoobig'] = 'El archivo subido es demasiado grande';
+$lang['containsillegalchars'] = 'El nombre de archivo contiene caracteres inv&aacute;lidos (&#039;,&quot;,+,*,\,/,&amp;,$)';
 $lang['uploadfailed'] = 'Error al mover el archivo subido';
 $lang['fileuploaded'] = 'El archivo fue subido con exito';
 $lang['filepickertitle'] = 'CMSMadeSimple Seleccion de Archivo';
@@ -138,8 +146,9 @@ $lang['help'] = '	<h3>&iquest;Que hace esto?</h3>
 	<p>Permite usar a TinyMCE como editor WYSIWYG de sus p&aacute;ginas.</p>
 	<h3>&iquest;Como lo uso?</h3>
 	<p>Instalar el m&oacute;dulo, luego ir a preferencias de usuario y elegir a TinyMCE como el editor wysiwyg de su elecci&oacute;n.</p>';
-$lang['utma'] = '156861353.661434885.1227567621.1241554232.1242674634.67';
-$lang['utmz'] = '156861353.1241473702.63.28.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/board,30.0.html|utmcmd=referral';
-$lang['utmb'] = '156861353';
+$lang['qca'] = 'P0-2096054370-1259803615939';
+$lang['utma'] = '156861353.238606854.1259804368.1267940197.1267946953.72';
+$lang['utmz'] = '156861353.1267925726.70.33.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
