@@ -20,6 +20,7 @@ $lang['allowuploadtext'] = 'Permitir o carregamento de imagens, bem como, criar
 $lang['allowscalingtext'] = 'Permitir autom&aacute;ticamente redimensionamento de imagens';
 $lang['scalingdimensionstext'] = 'Dimens&otilde;es padr&atilde;o';
 $lang['resizeto'] = 'Redimensionar para:';
+$lang['makethumbnail'] = 'Fazer uma miniatura quando carregar imagens';
 $lang['useadvancedprofile'] = 'Usar Perfis do TinyMCE avan&ccedil;ados';
 $lang['saveprofile'] = 'Guardar Perfile';
 $lang['profilesaved'] = 'O Perfile fio guardado';
@@ -29,9 +30,16 @@ $lang['savestyles'] = 'Guardar estilos';
 $lang['allowadvancedprofile'] = 'Permitir o uso de perfis avan&ccedil;ados no TinyMCE';
 $lang['showfilemanagement'] = 'Mostrar op&ccedil;&otilde;es no gestor de ficheiros';
 $lang['showfilemanagementhelp'] = 'Mostrar no gestor de ficheiros  op&ccedil;&otilde;es como carregar ficheiros, e fazer a elimina&ccedil;&atilde;o de pastas e ficheiros no Gestor de Ficheiros, se o utilizador estiver autorizado a executar as mesmas.';
+$lang['restrictdirs'] = 'Restricto o acesso &agrave; directoria do username';
+$lang['restrictdirshelp'] = 'Isto vai restringir o Gestor de Ficheiros  do usu&aacute;rio para um ver dentro dos &quot;/uploads&quot;, que tem o mesmo nome de login do username. Se o subdiret&oacute;rio n&atilde;o existir, ser&aacute;, criado. Por favor note que  trabalha actualmente apenas com o nome do direct&oacute;rio padr&atilde;o, uploads/imagens. Isto pode mudar no futuro.';
 $lang['deleteconfirmation'] = 'Tem certeza de que o arquivo deve ser apagado?';
 $lang['deletefilesuccess'] = 'foi eliminado com sucesso';
-$lang['deletefilefila'] = 'n&atilde;o pode ser eliminado';
+$lang['deletefilefailed'] = 'n&atilde;o p&ocirc;de ser exclu&iacute;do';
+$lang['deletesubdirfailed'] = 'n&atilde;o p&ocirc;de ser exclu&iacute;do';
+$lang['deletesubdirsuccess'] = 'foi removido com sucesso';
+$lang['deletedirconfirmation'] = 'Tem certeza que os sub direct&oacute;rios vazios devem ser exclu&iacute;dos?';
+$lang['deletedir'] = 'Excluir sub direct&oacute;rio vazio';
+$lang['deletefile'] = 'Eliminar ficheiro';
 $lang['cannotreadconfig'] = 'N&atilde;o &eacute; poss&iacute;vel ler o arquivo  tinyconfig.php directamente o TinyMCE provavelmente n&atilde;o funcionar&aacute;. Deve verificar as permiss&otilde;es do arquivo e da root dirs, que deveria ser lido por todos, mas apenas para o propriet&aacute;rio de escrita.';
 $lang['filenameonly'] = 'Mostrar nomes dos ficheiros';
 $lang['thumbnailsonly'] = 'Mostrar miniaturas';
@@ -53,12 +61,16 @@ $lang['editor_width_text'] = 'Largura do editor';
 $lang['editor_height_text'] = 'Altura do editor';
 $lang['auto'] = 'Autom&aacute;tico';
 $lang['or'] = 'ou';
+$lang['allowresizing'] = 'Permitir redimensionamento no lugar de editor de campo';
+$lang['resizenone'] = 'N&atilde;o permitir o redimensionamento';
+$lang['resizeboth'] = 'Permitir redimensionamento em ambos os sentidos';
+$lang['resizeheight'] = 'Permitir redimensionamento apenas da altura';
 $lang['datetimeformat_text'] = 'Data/Hora formato';
 $lang['timetext'] = 'Hora';
 $lang['datetext'] = 'Data';
 $lang['datetimeformat_help'] = 'Clique aqui para obter ajuda sobre como formatar a data/hora';
 $lang['extraconfigtext'] = 'Configura&ccedil;&atilde;o extra';
-$lang['extraconfighelp'] = 'Verifique o TinyMCE-wiki para mais instru&ccedil;&otilde;es';
+$lang['extraconfighelp2'] = 'Uma declara&ccedil;&atilde;o por linha, uma v&iacute;rgula ser&aacute; adicionada antes e ap&oacute;s esse conte&uacute;do. Verifique TinyMCE-wiki para obter mais instru&ccedil;&otilde;es.';
 $lang['customdropdowntext'] = 'Menu Suspenso Personalizado';
 $lang['customdropdownhelp'] = 'Insere peda&ccedil;os de c&oacute;digo/texto personaliz&aacute;veis na selec&ccedil;&atilde;o em um menu suspenso.
 Acesso a tag&#039;s etc. O menu &eacute; inserido na barra usando &#039;customdropdown&#039;.';
@@ -79,6 +91,8 @@ $lang['includeonlyscreencss_help'] = 'Esta selec&ccedil;&atilde;o s&oacute; perm
 $lang['usestaticconfigtext'] = 'Use arquivo est&aacute;tico de config';
 $lang['usestaticconfighelp'] = 'Isso pode ajudar o Tiny a trabalhar em sistemas onde tem a instala&ccedil;&atilde;o de hospedagem, acrescenta varias pe&ccedil;as como  todas as estat&iacute;sticas de produ&ccedil;&atilde;o etc., quebrando dinamicamente o criado arquivo de config-javascript';
 $lang['usestaticconfigwarning'] = 'Aten&ccedil;&atilde;o! Tem a op&ccedil;&atilde;o est&aacute;tica config-file habilitado mas seu /tmp/dir n&atilde;o tem permiss&otilde;es de escrita. Isso ir&aacute; evitar que o m&oacute;dulo possa salvar no arquivo config-est&aacute;tico e muito provavelmente ir&aacute; tornar o TinyMCE inoperacional.';
+$lang['ignoremodifyfilestext'] = 'Ignorar a &quot;permiss&atilde;o Modificar Ficheiros&quot; para o Filepicker';
+$lang['ignoremodifyfileshelp'] = 'Aten&ccedil;&atilde;o! Isso permite que se altere algum arquivo, mesmo que a &quot;permiss&atilde;o Modificar Ficheiros &#039;n&atilde;o estiver definido para o grupo de usernames actuais. Isso pode efetivamente ser utilizada em conjunto com a op&ccedil;&atilde;o de restringir o acesso do usu&aacute;rio do diret&oacute;rio.';
 $lang['showtogglebutton_text'] = 'Mostrar checkbox para colocar wysiwyg on/off';
 $lang['togglewysiwyg'] = 'Colocar Editor on/off';
 $lang['styles_tab'] = 'Estilos CSS';
@@ -113,7 +127,12 @@ $lang['plugins_tab'] = 'Plugins (extras)';
 $lang['plugins_help'] = 'Escolha os plugins que pretende activar. Documenta&ccedil;&atilde;o pode ser encontrada em http://wiki.moxiecode.com/index.php/TinyMCE:Plugins';
 $lang['plugins_text'] = 'Plugins (extras)';
 $lang['saveplugins'] = 'Salvar Plugins';
-$lang['pluginssaved'] = 'Plugins Salvos';
+$lang['pluginssaved'] = 'Plugins guardados';
+$lang['plugins_module'] = 'Modulo Plugins ';
+$lang['plugins_common'] = 'Plugins Comuns';
+$lang['module'] = 'Modulo';
+$lang['description'] = 'Descri&ccedil;&atilde;o';
+$lang['plugin'] = 'Plugin ';
 $lang['youareintext'] = 'Est&aacute; localizado em';
 $lang['loadstylesheettext'] = 'Cargar css do conte&uacute;do (recomendado)';
 $lang['extrastylestext'] = 'Adi&ccedil;&otilde;es ao estilo';
@@ -128,6 +147,7 @@ $lang['newdircreated'] = 'Pasta criada com sucesso';
 $lang['newdirfailed'] = 'Ocorreu um erro ao criar a pasta';
 $lang['nofile'] = 'N&atilde;o foi carregado nenhum ficheiro';
 $lang['filetoobig'] = 'O tamanho do ficheiro ultrapassa o permitido';
+$lang['containsillegalchars'] = 'Nome do arquivo cont&eacute;m um ou mais caracteres ilegais (&#039;,&quot;,+,*,\,/,&amp;,$)';
 $lang['uploadfailed'] = 'Erro ao tentar mover para este local';
 $lang['fileuploaded'] = 'Ficheiro carregado com sucesso';
 $lang['filepickertitle'] = 'CMS Selec&ccedil;&atilde;o de Ficheiros';
@@ -141,20 +161,29 @@ $lang['help'] = '	<h3>What does this do?</h3>
 	<p>Enables a TinyMCE to be used as a WYSIWYG.</p>
 	<h3>How do I use it?</h3>
 	<p>Install it, then go to User Preferences and Set TinyMCE to be your wysiwyg of choice.</p>
+  <h3>Spellchecker</h3>
+  <p>As of version 2.6.0, TinyMCE includes an online spellchecker. Please notice that SSL must be turned on in your server-configuration in order for this to work. On some setups this option is called php_openssl but that may vary</p>
 	<h3>Troubleshooting</h3>
 	Some people have trouble with tiny not showing up upon installation or upgrading. Here is a checklist of 
 	things you can try before contacting me for further support.
 	<br/>
 	<ul>
-	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You&#039;d be amazed how many times this has helped people.</li>
-	<li>2. Try to switch on the Static Config option. Note that this requires your /tmp/-dir to be writable by the webserver</li>
-	<li>3. If upgrading, please try to reset all settings. Not nice if you&#039;ve done a lot of customization, I know, but a lot of things changes from 2.3.x to 2.4.x series of the module.
-	<li>4. Try enabling the static config option in advanced settings. This works better on some systems (like CGI-based)
+	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You&#039;d be amazed how many times this has helped people.</li>	
+	<li>2. If upgrading, please try to reset all settings. Not nice if you&#039;ve done a lot of customization, I know, but a lot of things changed from 2.3.x to 2.4.x series of the module.
+	<li>3. Try enabling the static config option in advanced settings. This works better on some systems (like CGI-based), Note that this requires your /tmp/-dir to be writable by the webserver
 	</ul>
 	<br/>
+  <h3>Plugin development</h3>
+  As of version 2.7.0 the TinyMCE-module has the ability to allow other modules to register extensions for it. Could be a custom icon allowing you to insert
+  content from some module, like Gallery etc. How to do this is pretty tech stuff, but if you are a module developer and interested in checking it out
+  please look in the TinyMCE/docs-dir for further instructions.
+
+	<br/>
+		
 ';
-$lang['utma'] = '156861353.3089450601847726600.1241711306.1242653258.1242681672.52';
-$lang['utmz'] = '156861353.1242681672.52.18.utmcsr=patriciavaz.nunodev.homelinux.com|utmccn=(referral)|utmcmd=referral|utmcct=/site/';
+$lang['qca'] = 'P0-1236842016-1276975567163';
+$lang['utma'] = '156861353.1127963369.1277311597.1278072220.1278188876.23';
+$lang['utmz'] = '156861353.1277858169.17.5.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
+$lang['utmb'] = '156861353.1.10.1278188876';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1242681672';
 ?>
\ No newline at end of file
