@@ -20,6 +20,7 @@ $lang['allowuploadtext'] = 'Till&aring;t uppladdning och skapande av mappar i Fi
 $lang['allowscalingtext'] = 'Allow on-the-fly resizing of uploaded files';
 $lang['scalingdimensionstext'] = 'Standard dimensioner';
 $lang['resizeto'] = '&Auml;ndra storlek till:';
+$lang['makethumbnail'] = 'Skapa en tumnagelbild vid uppladdning av bilder';
 $lang['useadvancedprofile'] = 'Anv&auml;nd avancerad TinyMCE-profil';
 $lang['saveprofile'] = 'Spara profil';
 $lang['profilesaved'] = 'Profilen sparades';
@@ -29,9 +30,16 @@ $lang['savestyles'] = 'Spara stilar';
 $lang['allowadvancedprofile'] = 'Till&aring;t anv&auml;ndning av avancerade profiler i TinyMCE';
 $lang['showfilemanagement'] = 'Visa inst&auml;llningar f&ouml;r filhantering';
 $lang['showfilemanagementhelp'] = 'Visa filhantering i tillvalen f&ouml;r uppladdning, skapa mapp och borttagning av fil i Filv&auml;ljaren, om anv&auml;ndaren har r&auml;tt att g&ouml;ra detta.';
+$lang['restrictdirs'] = 'Restrict user&#039;s dir access';
+$lang['restrictdirshelp'] = 'This will restrict the filemanagement-capabilities of the user to a subdir to &#039;uploads&#039; which have the same name as the user&#039;s login. If the subdir does not exist, it will possibly be created. Please note, this currently only works with the standard dirnames, uploads/images. This may change in the future.';
 $lang['deleteconfirmation'] = '&Auml;r du s&auml;ker p&aring; att den h&auml;r filen ska raderas?';
 $lang['deletefilesuccess'] = 'Blev framg&aring;ngsrikt raderad';
-$lang['deletefilefila'] = 'Kunde inte raderas';
+$lang['deletefilefailed'] = 'kunde inte raderas';
+$lang['deletesubdirfailed'] = 'kunde inte raderas';
+$lang['deletesubdirsuccess'] = 'raderades';
+$lang['deletedirconfirmation'] = '&Auml;r du s&auml;ker p&aring; att du vill radera denna tomma subdir?';
+$lang['deletedir'] = 'Radera tom subdir';
+$lang['deletefile'] = 'Radera fil';
 $lang['cannotreadconfig'] = 'Kan inte l&auml;sa filen tinyconfig.php direkt, s&aring; TinyMCE kommer antagligen inte att fungera. Du b&ouml;r kontrollera r&auml;ttigheterna f&ouml;r den filen och dess &ouml;verliggande mappar, som alla b&ouml;r vara l&auml;sbara f&ouml;r alla men bara skrivbar f&ouml;r &auml;garen.';
 $lang['filenameonly'] = 'Visa filnamn';
 $lang['thumbnailsonly'] = 'Visa tumnagelbilder';
@@ -53,12 +61,16 @@ $lang['editor_width_text'] = 'Bredd p&aring; redigeringsf&auml;ltet';
 $lang['editor_height_text'] = 'H&ouml;jd f&ouml;r redigeringsf&auml;ltet';
 $lang['auto'] = 'Automatiskt';
 $lang['or'] = 'eller';
+$lang['allowresizing'] = 'Allow inplace resizing of editor field';
+$lang['resizenone'] = 'Till&aring;t inte &auml;ndring av storlek';
+$lang['resizeboth'] = 'Till&aring;t &auml;ndring av storlek i b&aring;da riktningarna';
+$lang['resizeheight'] = 'Till&aring;t &auml;ndring av storlek bara p&aring; h&ouml;jden';
 $lang['datetimeformat_text'] = 'Format f&ouml;r datum/tid';
 $lang['timetext'] = 'Tid';
 $lang['datetext'] = 'Datum';
 $lang['datetimeformat_help'] = 'Klicka h&auml;r f&ouml;r hj&auml;lp om hur du formatterar datum/tid';
 $lang['extraconfigtext'] = 'Extrainst&auml;llningar';
-$lang['extraconfighelp'] = 'Kolla TinyMCE-wikin f&ouml;r instruktioner';
+$lang['extraconfighelp2'] = 'En uppgift per rad, kommatecken kommer att l&auml;ggas till f&ouml;re och efter detta inneh&aring;ll. Se TinyMCE-wiki f&ouml;r instruktioner.';
 $lang['customdropdowntext'] = 'Anpassad dropdown';
 $lang['customdropdownhelp'] = 'Inserts customizable snippets of code/text by selection in a dropdown menu. 
 Obvious uses are easy access to tag&#039;s etc. The menu is inserted into toolbar using &#039;customdropdown&#039;.';
@@ -79,6 +91,8 @@ $lang['includeonlyscreencss_help'] = 'Om detta v&auml;ljs till&aring;ts enbart d
 $lang['usestaticconfigtext'] = 'Anv&auml;nd statisk konfigurationsfil';
 $lang['usestaticconfighelp'] = 'Detta kan vara bra f&ouml;r att Tiny ska fungera p&aring; system d&auml;r webbservern l&auml;gger till s&aring;nt som statistik mm till all output, vilket bryter den dynamiskt skapade javascriptskonfigurationsfilen';
 $lang['usestaticconfigwarning'] = 'Varning! Du har aktiverat statisk konfigurationsfil, men din /tmp/-mapp &auml;r inte skrivbar. Dett hindrar modulen fr&aring;n att spara den statiska konfigurationsfilen och kommer troligen g&ouml;ra TinyMCE obrukbar.';
+$lang['ignoremodifyfilestext'] = 'Ignorera &#039;Modify Files&#039; r&auml;ttigheten f&ouml;r FilePicker';
+$lang['ignoremodifyfileshelp'] = 'Warning! This allows some file-altering operations even if the &#039;Modify Files&#039; permission is not set for the current usergroup. This can effectively be used together with the option to restrict user&#039;s directory access.';
 $lang['showtogglebutton_text'] = 'Visa knapp f&ouml;r att s&auml;tta p&aring;/st&auml;nga av WYSIWYG';
 $lang['togglewysiwyg'] = 'S&auml;tt p&aring;/st&auml;ng av WYSIWYG';
 $lang['styles_tab'] = 'CSS-stilar';
@@ -111,7 +125,11 @@ $lang['plugins_tab'] = 'Till&auml;gg';
 $lang['plugins_help'] = 'V&auml;lj vilka till&auml;gg som du vill aktivera. Dokumentation finns <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">h&auml;r</a>';
 $lang['plugins_text'] = 'Till&auml;gg';
 $lang['saveplugins'] = 'Spara till&auml;gg';
-$lang['pluginssaved'] = 'Till&auml;gg sparade';
+$lang['plugins_module'] = 'Modul Plugins';
+$lang['plugins_common'] = 'Vanliga insticksprogram';
+$lang['module'] = 'Modul';
+$lang['description'] = 'Beskrivning';
+$lang['plugin'] = 'Insticksprogram';
 $lang['youareintext'] = 'Du &auml;r p&aring;';
 $lang['loadstylesheettext'] = 'Ladda stilmall f&ouml;r inneh&aring;ll (rekommenderat)';
 $lang['extrastylestext'] = 'Till&auml;gg till stilmallar';
@@ -126,6 +144,7 @@ $lang['newdircreated'] = 'Ny mapp skapad';
 $lang['newdirfailed'] = 'Ett fel intr&auml;ffade n&auml;r mappen skulle skapas';
 $lang['nofile'] = 'Ingen fil laddades upp';
 $lang['filetoobig'] = 'Den uppladdade filen &auml;r f&ouml;r stor';
+$lang['containsillegalchars'] = 'Filnamn inneh&aring;ller ett eller flera otill&aring;tna tecken (&#039;,&quot;,+,*,\,/,&amp;,$)';
 $lang['uploadfailed'] = 'Fel vid flytt av den uppladdade filen';
 $lang['fileuploaded'] = 'Filen uppladdad';
 $lang['filepickertitle'] = 'Filval f&ouml;r CMS Made Simple';
@@ -150,8 +169,9 @@ $lang['help'] = '<h3>What does this do?</h3>
 	<li>4. Try enabling the static config option in advanced settings. This works better on some systems (like CGI-based)
 	</ul>
 	<br/>';
+$lang['utma'] = '156861353.906052642.1267835734.1278791483.1278872739.125';
+$lang['utmz'] = '156861353.1278791483.124.8.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/|utmcmd=referral';
+$lang['qca'] = 'P0-1605183070-1267835733865';
+$lang['utmb'] = '156861353.1.10.1278872739';
 $lang['utmc'] = '156861353';
-$lang['utma'] = '156861353.415365204.1233508366.1239119741.1242658766.11';
-$lang['utmz'] = '156861353.1242658766.11.8.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
-$lang['utmb'] = '156861353.1.10.1242658766';
 ?>
\ No newline at end of file
