@@ -121,7 +121,8 @@ if ( isset($params['urlparams']) && ( strlen($params['urlparams'] > 0 ) ) ) {
 		$lang = get_site_preference('frontendlang','en');
 		if (isset($params['lang']))
 		{
-		  $lang = $params['lang'];
+		  $lang = trim($params['lang']);
+                  if( !$lang ) $lang = '0';
 		}
 		switch ($lang)
 		  {
@@ -131,6 +132,11 @@ if ( isset($params['urlparams']) && ( strlen($params['urlparams'] > 0 ) ) ) {
 		    $Prev_label = "Forrige side: ";
 		    $Next_label = "N&aelig;ste side: ";
 		    break;
+                  case 'de':
+                  case 'de_DE':
+                    $Prev_label = "Vorherige Seite: ";
+                    $Next_label = "N&auml;chste Seite: ";
+		    break;
 		  case 'nl':
 		  case 'nl_NL':
 		    $Prev_label = "Vorige pagina: ";
@@ -436,7 +442,7 @@ if ( isset($params['urlparams']) && ( strlen($params['urlparams'] > 0 ) ) ) {
 				$linktext = $name; // mbv - 21-06-2005
 			}
 
-			$linktext = cms_htmlentities($linktext);
+			//$linktext = cms_htmlentities($linktext);
 
 			if (isset($params['image']) && ! empty($params['image'])) {
 				$alt = (isset($params['alt']) && ! empty($params['alt'])) ? $params['alt'] : '';
