@@ -28,40 +28,40 @@ function smarty_cms_prefilter_precompilefunc($tpl_output, &$smarty)
 		switch ($result[0])
 		{
 			case "content":
-				foreach($gCms->modules as $key=>$value)
-				{
-					if ($gCms->modules[$key]['installed'] == true &&
-						$gCms->modules[$key]['active'] == true)
-					{
-						$gCms->modules[$key]['object']->ContentPreCompile($tpl_output);
-					}
-				}
+// 				foreach($gCms->modules as $key=>$value)
+// 				{
+// 					if ($gCms->modules[$key]['installed'] == true &&
+// 						$gCms->modules[$key]['active'] == true)
+// 					{
+// 						$gCms->modules[$key]['object']->ContentPreCompile($tpl_output);
+// 					}
+// 				}
 				
 				Events::SendEvent('Core', 'ContentPreCompile', array('content' => &$tpl_output));
 				
 				break;
 			case "template":
-				foreach($gCms->modules as $key=>$value)
-				{
-					if ($gCms->modules[$key]['installed'] == true &&
-						$gCms->modules[$key]['active'] == true)
-					{
-						$gCms->modules[$key]['object']->TemplatePreCompile($tpl_output);
-					}
-				}
+// 				foreach($gCms->modules as $key=>$value)
+// 				{
+// 					if ($gCms->modules[$key]['installed'] == true &&
+// 						$gCms->modules[$key]['active'] == true)
+// 					{
+// 						$gCms->modules[$key]['object']->TemplatePreCompile($tpl_output);
+// 					}
+// 				}
 				
 				Events::SendEvent('Core', 'TemplatePreCompile', array('template' => &$tpl_output));
 				
 				break;
 			case "globalcontent":
-				foreach($gCms->modules as $key=>$value)
-				{
-					if ($gCms->modules[$key]['installed'] == true &&
-						$gCms->modules[$key]['active'] == true)
-					{
-						$gCms->modules[$key]['object']->GlobalContentPreCompile($tpl_output);
-					}
-				}
+// 				foreach($gCms->modules as $key=>$value)
+// 				{
+// 					if ($gCms->modules[$key]['installed'] == true &&
+// 						$gCms->modules[$key]['active'] == true)
+// 					{
+// 						$gCms->modules[$key]['object']->GlobalContentPreCompile($tpl_output);
+// 					}
+// 				}
 				
 				Events::SendEvent('Core', 'GlobalContentPreCompile', array('global_content' => &$tpl_output));
 				
